@@ -22,23 +22,20 @@
  */
 
 #include "modules/adminapi/cluster/add_replica_instance.h"
+
 #include <cassert>
 #include <exception>
 #include <memory>
+
 #include "modules/adminapi/cluster/cluster_impl.h"
-#include "modules/adminapi/cluster_set/cluster_set_impl.h"
 #include "modules/adminapi/common/async_topology.h"
-#include "modules/adminapi/common/cluster_topology_executor.h"
 #include "modules/adminapi/common/common.h"
 #include "modules/adminapi/common/dba_errors.h"
 #include "modules/adminapi/common/instance_validations.h"
 #include "modules/adminapi/common/metadata_storage.h"
-#include "modules/adminapi/common/preconditions.h"
 #include "modules/adminapi/common/undo.h"
 #include "mysqlshdk/include/scripting/types.h"
 #include "mysqlshdk/include/shellcore/console.h"
-#include "mysqlshdk/libs/mysql/clone.h"
-#include "mysqlshdk/libs/utils/debug.h"
 #include "mysqlshdk/libs/utils/logger.h"
 
 namespace mysqlsh::dba::cluster {
@@ -489,7 +486,8 @@ void Add_replica_instance::do_run() {
 
       m_cluster_impl->get_metadata_storage()->update_instance_attribute(
           m_target_instance->get_uuid(), k_instance_attribute_join_time,
-          shcore::Value(join_begin_time), add_read_replica_trx_undo.get());
+          shcore::Value(join_begin_time), false,
+          add_read_replica_trx_undo.get());
 
       // Store the replication account
       m_cluster_impl->get_metadata_storage()->update_read_replica_repl_account(
@@ -543,7 +541,8 @@ void Add_replica_instance::do_run() {
       m_cluster_impl->get_metadata_storage()->update_instance_attribute(
           m_target_instance->get_uuid(),
           k_instance_attribute_read_replica_replication_sources,
-          shcore::Value(source_list_md), add_read_replica_trx_undo.get());
+          shcore::Value(source_list_md), false,
+          add_read_replica_trx_undo.get());
 
       trx.commit();
       log_debug("addReplicaInstance() metadata updates done");
