@@ -52,6 +52,7 @@ namespace dba {
 namespace cluster {
 
 namespace {
+
 template <typename R>
 inline bool set_uint(shcore::Dictionary_t dict, const std::string &prop,
                      const R &row, const std::string &field) {
@@ -255,7 +256,7 @@ const Instance_metadata *Status::instance_with_uuid(const std::string &uuid) {
   return nullptr;
 }
 
-Member_stats_map Status::query_member_stats() {
+Status::Member_stats_map Status::query_member_stats() {
   Member_stats_map stats;
   auto group_instance = m_cluster->get_cluster_server();
 
@@ -945,7 +946,7 @@ void check_unrecognized_channels(shcore::Array_t issues, Instance *instance,
 }
 
 void check_host_metadata(shcore::Array_t issues, Instance *instance,
-                         const Instance_metadata_info &instance_md) {
+                         const Status::Instance_metadata_info &instance_md) {
   auto address = instance->get_canonical_address();
 
   if (!mysqlshdk::utils::are_endpoints_equal(instance_md.md.endpoint,
@@ -1021,12 +1022,12 @@ void check_auth_type_instance_ssl(shcore::Array_t issues,
   // check if instance user was created correctly
   bool has_issuer{false}, has_subject{false};
   {
-    auto instance_repl_account =
-        cluster.get_metadata_storage()->get_instance_repl_account(
+    auto instance_repl_account_user =
+        cluster.get_metadata_storage()->get_instance_repl_account_user(
             instance.get_uuid(), Cluster_type::GROUP_REPLICATION,
             Replica_type::GROUP_MEMBER);
 
-    if (std::get<0>(instance_repl_account).empty()) {
+    if (instance_repl_account_user.empty()) {
       // if this happens, a warning is already shown to the user in
       // validate_instance_recovery_user(), so there's no point showing a second
       // error message related to the same thing, even though it almost surely
@@ -1038,7 +1039,7 @@ void check_auth_type_instance_ssl(shcore::Array_t issues,
       auto res = server->queryf(
           "SELECT coalesce(length(x509_issuer)), "
           "coalesce(length(x509_subject)) FROM mysql.user WHERE (user = ?)",
-          std::get<0>(instance_repl_account));
+          instance_repl_account_user);
 
       if (auto row = res->fetch_one()) {
         has_issuer = row->get_int(0) > 0;
@@ -1087,7 +1088,7 @@ void check_auth_type_instance_ssl(shcore::Array_t issues,
 
 shcore::Array_t instance_diagnostics(
     Instance *instance, const Cluster_impl *cluster,
-    const Instance_metadata_info &instance_md,
+    const Status::Instance_metadata_info &instance_md,
     const mysqlshdk::mysql::Replication_channel &recovery_channel,
     const mysqlshdk::mysql::Replication_channel &applier_channel,
     std::optional<bool> super_read_only, const mysqlshdk::gr::Member &minfo,
@@ -1155,7 +1156,7 @@ shcore::Array_t instance_diagnostics(
 
   try {
     mysqlshdk::utils::split_host_and_port(instance_md.md.grendpoint);
-  } catch (const std::invalid_argument &e) {
+  } catch (const std::invalid_argument &) {
     issues->push_back(shcore::Value(
         "ERROR: Invalid or missing information of Group Replication's network "
         "address in metadata. Use Cluster.rescan() to update the metadata."));
@@ -1448,36 +1449,38 @@ shcore::Dictionary_t Status::get_topology(
       instances.emplace_back(std::move(mdi));
     }
   }
+
   // look for instances in MD but not in group
   for (const auto &i : m_instances) {
     bool found = false;
+
+    if (i.instance_type == Instance_type::READ_REPLICA) {
+      Read_replica_info read_replica = {};
+
+      read_replica.md = i;
+
+      Replication_sources replication_sources =
+          m_cluster->get_read_replica_replication_sources(i.uuid);
+
+      if (replication_sources.source_type != Source_type::CUSTOM) {
+        read_replica.managed_channel_info.automatic_sources = true;
+      } else {
+        read_replica.managed_channel_info.sources.swap(
+            replication_sources.replication_sources);
+      }
+
+      read_replicas.emplace_back(std::move(read_replica));
+
+      continue;
+    }
+
     for (const auto &m : member_info) {
-      if (i.instance_type == Instance_type::READ_REPLICA) {
-        Read_replica_info read_replica = {};
-
-        read_replica.md = i;
-
-        Replication_sources replication_sources =
-            m_cluster->get_read_replica_replication_sources(i.uuid);
-
-        if (replication_sources.source_type != Source_type::CUSTOM) {
-          read_replica.managed_channel_info.automatic_sources = true;
-        } else {
-          read_replica.managed_channel_info.sources.swap(
-              replication_sources.replication_sources);
-        }
-
-        read_replicas.emplace_back(read_replica);
+      if (m.uuid == i.uuid ||
+          mysqlshdk::utils::are_endpoints_equal(
+              i.endpoint,
+              mysqlshdk::utils::make_host_and_port(m.host, m.port))) {
         found = true;
         break;
-      } else {
-        if (m.uuid == i.uuid ||
-            mysqlshdk::utils::are_endpoints_equal(
-                i.endpoint,
-                mysqlshdk::utils::make_host_and_port(m.host, m.port))) {
-          found = true;
-          break;
-        }
       }
     }
     if (!found) {
@@ -1495,6 +1498,7 @@ shcore::Dictionary_t Status::get_topology(
         // the instance
         mdi.actual_server_uuid = i.uuid;
       }
+
       instances.emplace_back(std::move(mdi));
     }
   }
@@ -1887,12 +1891,19 @@ shcore::Dictionary_t Status::collect_replicaset_status() {
             &value)) {
       issues->push_back(
           shcore::Value("WARNING: Cluster's transaction size limit is not "
-                        "registered in the metadata. Use "
-                        "cluster.rescan() to update the metadata."));
+                        "registered in the metadata. Use cluster.rescan() to "
+                        "update the metadata."));
 
     } else {
       m_cluster_transaction_size_limit = value.as_int();
     }
+  } else {
+    if (!validate_instances_repl_options())
+      issues->push_back(shcore::Value(
+          "WARNING: The effective ClusterSet replication channel "
+          "configurations do not match the configured ones (to see the "
+          "affected options, use Cluster.options()). Please call "
+          "ClusterSet.rejoinCluster() to update them."));
   }
 
   // If the cluster is operating in multi-primary mode and paxosSingleLeader
@@ -1941,6 +1952,33 @@ shcore::Array_t Status::validate_recovery_accounts_unused(
   return issues;
 }
 
+bool Status::validate_instances_repl_options() {
+  assert(m_cluster->is_cluster_set_member());
+  assert(!m_cluster->is_primary_cluster());
+
+  auto cluster_set = m_cluster->get_cluster_set_object();
+
+  bool has_null_options;
+  Async_replication_options ar_options;
+  cluster_set->read_cluster_replication_options(m_cluster->get_id(),
+                                                &ar_options, &has_null_options);
+
+  if (has_null_options) return false;
+
+  for (const auto &member : m_member_sessions) {
+    mysqlshdk::mysql::Replication_channel_master_info channel_info;
+    mysqlshdk::mysql::get_channel_info(*(member.second),
+                                       k_clusterset_async_channel_name,
+                                       &channel_info, nullptr);
+
+    auto options_to_update = async_merge_repl_options(ar_options, channel_info);
+
+    if (options_to_update.has_value()) return false;
+  }
+
+  return true;
+}
+
 shcore::Array_t Status::read_replica_diagnostics(
     Instance *instance, const Read_replica_info &rr_info,
     bool is_primary) const {
@@ -2137,15 +2175,15 @@ shcore::Dictionary_t Status::feed_read_replica_info(const Read_replica_info &rr,
 
     // SSL info
     if (rr_instance) {
-      auto instance_repl_account =
-          m_cluster->get_metadata_storage()->get_instance_repl_account(
+      auto instance_repl_account_user =
+          m_cluster->get_metadata_storage()->get_instance_repl_account_user(
               rr_instance->get_uuid(), Cluster_type::GROUP_REPLICATION,
               Replica_type::READ_REPLICA);
 
       std::string ssl_cipher, ssl_version;
       mysqlshdk::mysql::iterate_thread_variables(
           *(m_cluster->get_metadata_storage()->get_md_server()),
-          "Binlog Dump GTID", instance_repl_account.first, "Ssl%",
+          "Binlog Dump GTID", instance_repl_account_user, "Ssl%",
           [&ssl_cipher, &ssl_version](const std::string &var_name,
                                       const std::string &var_value) {
             if (var_name == "Ssl_cipher") {
@@ -2462,13 +2500,6 @@ shcore::Value Status::execute() {
   return shcore::Value(dict);
 }
 
-void Status::rollback() {
-  // Do nothing right now, but it might be used in the future when
-  // transactional command execution feature will be available.
-}
-
-void Status::finish() {}
-
 }  // namespace cluster
 }  // namespace dba
 }  // namespace mysqlsh
