@@ -294,6 +294,15 @@ inline constexpr const char kCertIssuer[] = "certIssuer";
 inline constexpr const char kCertSubject[] = "certSubject";
 inline constexpr const char kReplicationSslMode[] = "replicationSslMode";
 inline constexpr const char kPaxosSingleLeader[] = "paxosSingleLeader";
+inline constexpr const char kReplicationConnectRetry[] = "ConnectRetry";
+inline constexpr const char kReplicationRetryCount[] = "RetryCount";
+inline constexpr const char kReplicationHeartbeatPeriod[] = "HeartbeatPeriod";
+inline constexpr const char kReplicationCompressionAlgorithms[] =
+    "CompressionAlgorithms";
+inline constexpr const char kReplicationZstdCompressionLevel[] =
+    "ZstdCompressionLevel";
+inline constexpr const char kReplicationBind[] = "Bind";
+inline constexpr const char kReplicationNetworkNamespace[] = "NetworkNamespace";
 inline constexpr const char kReplicationSources[] = "replicationSources";
 inline constexpr const char kReplicationSourcesAutoPrimary[] = "primary";
 inline constexpr const char kReplicationSourcesAutoSecondary[] = "secondary";
@@ -308,15 +317,6 @@ struct Option_availability {
   mysqlshdk::utils::Version support_in_57;
 };
 
-/**
- * Map of the global Cluster configuration options of the AdminAPI
- * <sysvar, name>
- */
-inline const std::map<std::string, std::string> k_global_cluster_options{
-    {kGroupName, kGrGroupName},
-    {kMemberSslMode, kGrMemberSslMode},
-    {kTransactionSizeLimit, kGrTransactionSizeLimit}};
-
 /**
  * Map of the supported global cluster configuration options in the
  * AdminAPI <sysvar, name>
@@ -511,8 +511,7 @@ bool SHCORE_PUBLIC validate_cluster_group_name(
     const mysqlshdk::mysql::IInstance &instance, const std::string &group_name);
 
 bool validate_super_read_only(const mysqlshdk::mysql::IInstance &instance,
-                              mysqlshdk::null_bool clear_read_only,
-                              bool interactive);
+                              std::optional<bool> clear_read_only);
 
 enum class Instance_rejoinability {
   REJOINABLE,
@@ -536,8 +535,6 @@ bool is_sandbox(const mysqlshdk::mysql::IInstance &instance,
 // AdminAPI interactive handling specific methods
 std::string prompt_cnf_path(const mysqlshdk::mysql::IInstance &instance);
 int prompt_menu(const std::vector<std::string> &options, int defopt);
-bool prompt_super_read_only(const mysqlshdk::mysql::IInstance &instance,
-                            bool throw_on_error = false);
 void dump_table(const std::vector<std::string> &column_names,
                 const std::vector<std::string> &column_labels,
                 shcore::Value::Array_type_ref documents);
@@ -817,9 +814,17 @@ void validate_local_address_ip_compatibility(
     const std::string &local_address, const std::string &group_seeds,
     mysqlshdk::utils::Version lowest_cluster_version);
 
+/**
+ * Validate that the local_address is part of the range of addresses that are
+ * part of the automatic allowList
+ */
+void validate_local_address_allowed_ip_compatibility(
+    const std::string &local_address, bool create_cluster);
+
 void validate_read_replica_version(
     mysqlshdk::utils::Version target_instance_version,
     mysqlshdk::utils::Version lowest_cluster_version);
+
 }  // namespace cluster_topology_executor_ops
 
 }  // namespace dba
