@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2019, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2019, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -759,26 +757,6 @@ Server *Server_global_topology::scan_instance_recursive(
     auto slave_it = next_it++;
     const auto &slave = *slave_it;
 
-    if (!slave.has_valid_endpoint()) {
-      console->print_warning(shcore::str_format(
-          "Instance '%s' (a replica of '%s') doesn't have the 'report_host' "
-          "variable properly configured: '%s'",
-          slave.uuid.c_str(), instance->descr().c_str(),
-          mysqlshdk::utils::make_host_and_port(slave.host, slave.port)
-              .c_str()));
-
-      console->print_info(shcore::str_format(
-          "In order to discover all available replicas, each one must have the "
-          "'report_host' variable set, otherwise they can't be uniquely "
-          "identified and reached from '%s'. Please configure the "
-          "'report_host' variable of instance '%s'.",
-          instance->descr().c_str(), slave.uuid.c_str()));
-
-      member->invalid_replicas.push_back(slave);
-      member->unmanaged_replicas.erase(slave_it);
-      continue;
-    }
-
     std::string endpoint =
         mysqlshdk::utils::make_host_and_port(slave.host, slave.port);
 
@@ -878,22 +856,19 @@ void Server_global_topology::show_raw() const {
 
 // -----------------------------------------------------------------------------
 
-Global_topology *scan_global_topology(MetadataStorage *metadata,
-                                      const Cluster_metadata &cmd,
-                                      const std::string &channel_name,
-                                      bool deep) {
-  if (cmd.type == Cluster_type::GROUP_REPLICATION) {
+std::unique_ptr<Global_topology> scan_global_topology(
+    MetadataStorage *metadata, const Cluster_metadata &cmd,
+    const std::string &channel_name, bool deep) {
+  if (cmd.type == Cluster_type::GROUP_REPLICATION)
     throw std::logic_error("internal error");
-  } else {
-    std::unique_ptr<Server_global_topology> topo(
-        new Server_global_topology(channel_name));
 
-    topo->load_cluster(metadata, cmd);
-    topo->check_servers(deep);
-    if (deep) topo->check_gtid_consistency();
+  auto topo = std::make_unique<Server_global_topology>(channel_name);
 
-    return topo.release();
-  }
+  topo->load_cluster(metadata, cmd);
+  topo->check_servers(deep);
+  if (deep) topo->check_gtid_consistency();
+
+  return topo;
 }
 
 }  // namespace topology
