@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2019, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2019, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -55,9 +53,6 @@ constexpr const char *k_default_sql_mode =
 constexpr char k_lock[] = "AdminAPI_lock";
 constexpr char k_lock_name_instance[] = "AdminAPI_instance";
 
-// default wait_timeout
-constexpr uint64_t k_default_wait_timeout = 28800;
-
 int64_t default_adminapi_connect_timeout() {
   return mysqlsh::current_shell_options()->get().dba_connect_timeout * 1000;
 }
@@ -93,9 +88,9 @@ std::shared_ptr<Instance> Instance::connect_raw(
     const mysqlshdk::db::Connection_options &opts, bool interactive) {
   mysqlshdk::db::Connection_options op(opts);
 
-  if (!op.has_value(mysqlshdk::db::kConnectTimeout)) {
-    op.set(mysqlshdk::db::kConnectTimeout,
-           std::to_string(default_adminapi_connect_timeout()));
+  if (!op.has_connect_timeout()) {
+    op.set_connect_timeout(
+        static_cast<int>(default_adminapi_connect_timeout()));
   }
 
   return std::make_shared<Instance>(connect_session(op, interactive));
@@ -163,20 +158,6 @@ void Instance::prepare_session() {
   set_sysvar("group_concat_max_len", static_cast<int64_t>(1024 * 1024 * 1024),
              mysqlshdk::mysql::Var_qualifier::SESSION);
 
-  // Ensure the default value for 'wait_timeout' is kept for the AdminAPI
-  // accounts, avoiding any possible timeouts in command execution due to
-  // user-configured low values.
-  // NOTE: set directly to 28800, instead of using DEFAULT, because the user
-  // might have configured directly on the configuration file the value for the
-  // timeout and that becomes the compiled DEFAULT value.
-  // Also, only set if the instance has a value set that is lower than 28800.
-  // This is important to ensure higher values set by the user are honored.
-  if (get_sysvar_int("wait_timeout", mysqlshdk::mysql::Var_qualifier::SESSION) <
-      k_default_wait_timeout) {
-    set_sysvar("wait_timeout", static_cast<int64_t>(k_default_wait_timeout),
-               mysqlshdk::mysql::Var_qualifier::SESSION);
-  }
-
   // Cache the hostname, port, and UUID to avoid errors accessing this data if
   // the instance fails during an operation.
   get_canonical_address();
