@@ -246,9 +246,14 @@ class MetadataStorage {
                                std::string_view attribute,
                                shcore::Value *out_value) const;
 
+  void remove_cluster_attribute(const Cluster_id &cluster_id,
+                                std::string_view attribute);
+
   void update_cluster_attribute(const Cluster_id &cluster_id,
                                 std::string_view attribute,
-                                const shcore::Value &value);
+                                const shcore::Value &value,
+                                bool store_null = false);
+
   void update_clusters_attribute(std::string_view attribute,
                                  const shcore::Value &value);
 
@@ -258,7 +263,7 @@ class MetadataStorage {
       const std::set<std::string> &allowed_operations);
 
   bool query_cluster_capability(const Cluster_id &cluster_id,
-                                const std::string &capability,
+                                std::string_view capability,
                                 shcore::Value *out_value) const;
 
   void update_cluster_set_attribute(const Cluster_set_id &clusterset_id,
@@ -273,9 +278,13 @@ class MetadataStorage {
                                 std::string_view attribute,
                                 shcore::Value *out_value) const;
 
+  void remove_instance_attribute(std::string_view uuid,
+                                 std::string_view attribute);
+
   void update_instance_attribute(std::string_view uuid,
                                  std::string_view attribute,
                                  const shcore::Value &value,
+                                 bool store_null = false,
                                  Transaction_undo *undo = nullptr);
 
   void update_instance_addresses(std::string_view uuid,
@@ -321,12 +330,12 @@ class MetadataStorage {
    * of the instance with the given uuid is dropped from the metadata.
    * @param recovery_account_host string with the host of the recovery user.
    */
-  void update_instance_repl_account(const std::string &instance_uuid,
+  void update_instance_repl_account(std::string_view instance_uuid,
                                     Cluster_type type,
                                     Replica_type replica_type,
-                                    const std::string &recovery_account_user,
-                                    const std::string &recovery_account_host,
-                                    Transaction_undo *undo = nullptr);
+                                    std::string_view recovery_account_user,
+                                    std::string_view recovery_account_host,
+                                    Transaction_undo *undo = nullptr) const;
   /**
    * Fetch from the metadata the recovery account being used by the instance
    * with the given uuid.
@@ -340,6 +349,10 @@ class MetadataStorage {
       const std::string &instance_uuid, Cluster_type type,
       Replica_type replica_type);
 
+  std::string get_instance_repl_account_user(std::string_view instance_uuid,
+                                             Cluster_type type,
+                                             Replica_type replica_type);
+
   void update_cluster_repl_account(const Cluster_id &cluster_id,
                                    const std::string &repl_account_user,
                                    const std::string &repl_account_host,
@@ -348,6 +361,8 @@ class MetadataStorage {
   std::pair<std::string, std::string> get_cluster_repl_account(
       const Cluster_id &cluster_id) const;
 
+  std::string get_cluster_repl_account_user(const Cluster_id &cluster_id) const;
+
   std::pair<std::string, std::string> get_read_replica_repl_account(
       const std::string &instance_uuid) const;
 
@@ -371,9 +386,6 @@ class MetadataStorage {
 
   std::vector<std::string> get_recovery_account_users();
 
-  std::string get_recovery_account_user(const Cluster_id &cluster_id,
-                                        const std::string &address);
-
   size_t iterate_recovery_account(
       const std::function<bool(uint32_t, std::string)> &cb);
 
@@ -434,7 +446,9 @@ class MetadataStorage {
       const std::string &uuid, const Cluster_id &cluster_id = "") const;
 
   Instance_metadata get_instance_by_address(
-      const std::string &instance_address) const;
+      std::string_view instance_address) const;
+
+  Instance_metadata get_instance_by_label(std::string_view label) const;
 
   std::vector<Instance_metadata> get_replica_set_instances(
       const Cluster_id &rs_id);
