@@ -21,28 +21,18 @@
  * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#include <iomanip>
-#include <iostream>
+#include "modules/adminapi/mod_dba_cluster.h"
+
 #include <map>
 #include <memory>
-#include <sstream>
 #include <string>
-#include <vector>
-
-#include "modules/adminapi/cluster_set/cluster_set_impl.h"
 
+#include "db/utils_connection.h"
 #include "modules/adminapi/common/common.h"
-#include "modules/adminapi/common/dba_errors.h"
-#include "modules/adminapi/common/sql.h"
-#include "modules/adminapi/mod_dba_cluster.h"
 #include "modules/adminapi/mod_dba_cluster_set.h"
-#include "modules/mysqlxtest_utils.h"
-#include "mysqlshdk/include/scripting/type_info/custom.h"
-#include "mysqlshdk/include/scripting/type_info/generic.h"
 #include "mysqlshdk/include/shellcore/utils_help.h"
 #include "mysqlshdk/libs/utils/debug.h"
 #include "mysqlshdk/libs/utils/utils_general.h"
-#include "mysqlshdk/shellcore/shell_console.h"
 
 using std::placeholders::_1;
 
@@ -50,8 +40,28 @@ DEBUG_OBJ_ENABLE(Cluster);
 
 namespace mysqlsh {
 namespace dba {
+
+namespace {
+void validate_instance_label(const std::optional<std::string> &label,
+                             const Cluster_impl &impl) {
+  if (!label.has_value()) return;
+
+  mysqlsh::dba::validate_label(*label);
+
+  const auto &md = impl.get_metadata_storage();
+  if (md->is_instance_label_unique(impl.get_id(), *label)) return;
+
+  auto instance_md = md->get_instance_by_label(*label);
+
+  throw shcore::Exception::argument_error(
+      shcore::str_format("Instance '%s' is already using label '%s'.",
+                         instance_md.address.c_str(), label->c_str()));
+}
+}  // namespace
+
 using mysqlshdk::db::uri::formats::only_transport;
 using mysqlshdk::db::uri::formats::user_transport;
+
 // Documentation of the Cluster Class
 REGISTER_HELP_CLASS_KW(
     Cluster, adminapi,
@@ -209,7 +219,9 @@ The options dictionary may contain the following attributes:
 @li recoveryMethod: Preferred method of state recovery. May be auto, clone or
 incremental. Default is auto.
 @li waitRecovery: Integer value to indicate if the command shall wait for the
-recovery process to finish and its verbosity level.
+recovery process to finish and its verbosity level. Deprecated.
+@li recoveryProgress: Integer value to indicate the recovery process verbosity
+level.
 @li password: the instance connection password
 @li memberSslMode: SSL mode used on the instance
 ${CLUSTER_OPT_IP_WHITELIST}
@@ -249,6 +261,12 @@ The waitRecovery option supports the following values:
 @li 3: block until the recovery process finishes and show progress using
 progress bars.
 
+The recoveryProgress option supports the following values:
+
+@li 0: do not show any progress information.
+@li 1: show detailed static progress information.
+@li 2: show detailed dynamic progress information using progress bars.
+
 By default, if the standard output on which the Shell is running refers to a
 terminal, the waitRecovery option has the value of 3. Otherwise, it has the
 value of 2.
@@ -278,6 +296,11 @@ ${CLUSTER_OPT_AUTO_REJOIN_TRIES_EXTRA}
 Please use the ipAllowlist option instead.
 
 @attention The groupSeeds option will be removed in a future release.
+
+@attention The waitRecovery option will be removed in a future release.
+Please use the recoveryProgress option instead.
+
+@attention The interactive option will be removed in a future release.
 )*");
 
 /**
@@ -302,17 +325,7 @@ void Cluster::add_instance(
     instance_def.set_password(*(options->password));
   }
 
-  // Validate the label value.
-  if (options->label.has_value()) {
-    mysqlsh::dba::validate_label(*options->label);
-
-    if (!impl()->get_metadata_storage()->is_instance_label_unique(
-            impl()->get_id(), *options->label)) {
-      throw shcore::Exception::argument_error(
-          "An instance with label '" + *(options->label) +
-          "' is already part of this InnoDB cluster");
-    }
-  }
+  validate_instance_label(options->label, *impl());
 
   return execute_with_pool(
       [&]() {
@@ -352,11 +365,12 @@ ${CLUSTER_OPT_IP_ALLOWLIST}
 ${CLUSTER_OPT_LOCAL_ADDRESS}
 @li dryRun: boolean if true, all validations and steps for rejoining the
 instance are executed, but no changes are actually made.
-${CLUSTER_OPT_CLONE_DONOR}
+@li cloneDonor: The Cluster member to be used as donor when performing
+clone-based recovery. Available only for Read Replicas.
 @li timeout: maximum number of seconds to wait for the instance to sync up
 with the PRIMARY after it's provisioned and the replication channel is
 established. If reached, the operation is rolled-back. Default is 0 (no
-timeout).
+timeout). Available only for Read Replicas.
 
 The password may be contained on the instance definition, however, it can be
 overwritten if it is specified on the options.
@@ -365,7 +379,7 @@ The recoveryMethod option supports the following values:
 
 @li incremental: uses distributed state recovery, which applies missing
 transactions copied from another cluster member. Clone will be disabled.
-@li clone: clone: uses built-in MySQL clone support, which completely replaces
+@li clone: uses built-in MySQL clone support, which completely replaces
 the state of the target instance with a full snapshot of another cluster member
 before distributed recovery starts. Requires MySQL 8.0.17 or newer.
 @li auto: let Group Replication choose whether or not a full snapshot has to be
@@ -398,6 +412,8 @@ ${CLUSTER_OPT_LOCAL_ADDRESS_EXTRA}
 
 @attention The ipWhitelist option will be removed in a future release.
 Please use the ipAllowlist option instead.
+
+@attention The interactive option will be removed in a future release.
 )*");
 
 /**
@@ -468,6 +484,8 @@ a cluster. This allows to remove from the metadata an instance than can no
 longer be recovered. Otherwise, the instance must be brought back ONLINE and
 removed without the force option to avoid errors trying to add it back to a
 cluster.
+
+@attention The interactive option will be removed in a future release.
 )*");
 
 /**
@@ -668,6 +686,8 @@ from the metadata, including instances than can no longer be recovered.
 Otherwise, the instances must be brought back ONLINE and the cluster dissolved
 without the force option to avoid errors trying to reuse the instances and add
 them back to a cluster.
+
+@attention The interactive option will be removed in a future release.
 )*");
 
 /**
@@ -722,6 +742,8 @@ if really needed when instances are permanently not available (no longer
 reachable) or never going to be reused again in a cluster. Prefer to bring the
 non available instances back ONLINE or remove them from the cluster if they will
 no longer be used.
+
+@attention The interactive option will be removed in a future release.
 )*");
 
 /**
@@ -786,6 +808,8 @@ options in order to automatically add or remove the instances in the metadata,
 without having to explicitly specify them.
 
 @attention The updateTopologyMode option will be removed in a future release.
+
+@attention The interactive option will be removed in a future release.
 )*");
 
 /**
@@ -872,6 +896,13 @@ void Cluster::force_quorum_using_partition_of(
   auto instance_def = instance_def_;
   set_password_from_string(&instance_def, password);
 
+  if (password) {
+    handle_deprecated_option(mysqlshdk::db::kPassword, "");
+
+    DBUG_EXECUTE_IF("dba_deprecated_option_fail",
+                    { throw std::logic_error("debug"); });
+  }
+
   // Throw an error if the cluster has already been dissolved
   assert_valid("forceQuorumUsingPartitionOf");
 
@@ -898,6 +929,9 @@ Verifies the instance gtid state in relation to the cluster.
 
 @returns resultset A JSON object with the status.
 
+@attention This function is deprecated and will be removed in a future release
+of MySQL Shell.
+
 Analyzes the instance executed GTIDs with the executed/purged GTIDs on the
 cluster to determine if the instance is valid for the cluster.
 
@@ -941,6 +975,10 @@ shcore::Value Cluster::check_instance_state(
     const Connection_options &instance_def) {
   assert_valid("checkInstanceState");
 
+  mysqlsh::current_console()->print_warning(
+      "This function is deprecated and will be removed in a future release of "
+      "MySQL Shell.");
+
   return execute_with_pool(
       [&]() { return impl()->check_instance_state(instance_def); }, false);
 }
@@ -1103,12 +1141,26 @@ ${CLUSTER_OPT_IP_ALLOWLIST}
 internal replication accounts. Existing accounts will be re-created with the new
 value.
 ${CLUSTER_OPT_TRANSACTION_SIZE_LIMIT}
+${CLUSTER_OPT_REPLICATION_OPTION_CONNECT_RETRY}
+${CLUSTER_OPT_REPLICATION_OPTION_RETRY_COUNT}
+${CLUSTER_OPT_REPLICATION_OPTION_HEARTBEAT_PERIOD}
+${CLUSTER_OPT_REPLICATION_OPTION_COMPRESSION_ALGORITHMS}
+${CLUSTER_OPT_REPLICATION_OPTION_ZSTD_COMPRESSION_LEVEL}
+${CLUSTER_OPT_REPLICATION_OPTION_BIND}
+${CLUSTER_OPT_REPLICATION_OPTION_NETWORK_NAMESPACE}
 
 @attention The failoverConsistency option will be removed in a future release.
 Please use the consistency option instead.
 
 @attention The transactionSizeLimit option is not supported on Replica Clusters of InnoDB ClusterSets.
 
+@note Changing any of the "clusterSetReplication*" options won't immediately
+update the replication channel. ClusterSet.rejoinCluster() must be used to to reconfigure
+and restart the replication channel of that Cluster.
+@note Any of the "clusterSetReplication*" options accepts 'null', which resets
+the corresponding option to its default value on the next call to
+ClusterSet.rejoinCluster().
+
 The value for the configuration option is used to set the Group Replication
 system variable that corresponds to it.
 
@@ -1173,7 +1225,7 @@ ${CLUSTER_OPT_EXIT_STATE_ACTION}
 ${CLUSTER_OPT_MEMBER_WEIGHT}
 ${CLUSTER_OPT_AUTO_REJOIN_TRIES}
 ${CLUSTER_OPT_IP_ALLOWLIST}
-@li label a string identifier of the instance.
+@li label: a string identifier of the instance.
 @li replicationSources: The list of sources for a Read Replica Instance.
 
 ${CLUSTER_OPT_EXIT_STATE_ACTION_DETAIL}
@@ -1263,6 +1315,8 @@ the Cluster metadata.
 instance. Default is 'secondaries'.
 @li stats_updates_frequency: Number of seconds between updates that the Router
 is to make to its statistics in the InnoDB Cluster metadata.
+@li unreachable_quorum_allowed_traffic: Routing policy to define Router's behavior
+regarding traffic destinations (ports) when it loses access to the Cluster's quorum.
 
 The read_only_targets option supports the following values:
 
@@ -1287,6 +1341,28 @@ seconds; TTL=5, stats_updates_frequency=13, effective frequency is 15 seconds.
 
 If the value is null, the option value is cleared and the default value (0)
 takes effect.
+
+The unreachable_quorum_allowed_traffic option allows configuring Router's behavior
+in the event of a loss of quorum on the only reachable Cluster partition. By
+default, Router will disconnect all existing connections and refuse new ones,
+but that can be configured using the following options:
+
+@li read: Router will keep using ONLINE members as Read-Only destination, leaving
+the RO and RW-split ports open.
+@li all: Router will keep ONLINE members as Read/Write destinations, leaving all
+ports (RW, RO, and RW-split), open.
+@li none: All current connections are disconnected and new ones are refused (default behavior).
+
+@attention Setting this option to a different value other than the default may have unwanted
+consequences: the consistency guarantees provided by InnoDB Cluster are broken
+since the data read can be stale; different Routers may be accessing different
+partitions, thus return different data; and different Routers may also have different
+behavior (i.e. some provide only read traffic while others read and write traffic). Note that
+writes on a partition with no quorum will block until quorum is restored.
+
+This option has no practical effect if group_replication_unreachable_majority_timeout
+is set to a positive value and group_replication_exit_state_action is either
+OFFLINE_MODE or ABORT_SERVER.
 )*");
 
 #if DOXYGEN_JS
@@ -1729,6 +1805,8 @@ void Cluster::add_replica_instance(
         &options) {
   assert_valid("addReplicaInstance");
 
+  validate_instance_label(options->label, *impl());
+
   return execute_with_pool(
       [&]() { return impl()->add_replica_instance(instance_def, *options); },
       false);
