@@ -209,10 +209,7 @@ For the detailed list of requirements to create an InnoDB Cluster, please use
 
 The options dictionary can contain the following values:
 
-@li interactive: boolean value used to disable/enable the wizards in the
-command execution, i.e. prompts and confirmations will be provided or
-not according to the value set. The default value is equal to MySQL
-Shell wizard mode.
+${OPT_INTERACTIVE}
 @li dryRun: boolean if true, all validations and steps for creating a
 Replica Cluster are executed, but no changes are actually made. An
 exception will be thrown when finished.
@@ -243,6 +240,13 @@ any other member using accounts with this hostname value.
 ${CLUSTER_OPT_COMM_STACK}
 ${CLUSTER_OPT_TRANSACTION_SIZE_LIMIT}
 ${CLUSTER_OPT_PAXOS_SINGLE_LEADER}
+${CLUSTER_OPT_REPLICATION_OPTION_CONNECT_RETRY}
+${CLUSTER_OPT_REPLICATION_OPTION_RETRY_COUNT}
+${CLUSTER_OPT_REPLICATION_OPTION_HEARTBEAT_PERIOD}
+${CLUSTER_OPT_REPLICATION_OPTION_COMPRESSION_ALGORITHMS}
+${CLUSTER_OPT_REPLICATION_OPTION_ZSTD_COMPRESSION_LEVEL}
+${CLUSTER_OPT_REPLICATION_OPTION_BIND}
+${CLUSTER_OPT_REPLICATION_OPTION_NETWORK_NAMESPACE}
 
 The recoveryMethod option supports the following values:
 
@@ -306,6 +310,8 @@ ${CLUSTER_OPT_COMM_STACK_EXTRA}
 ${CLUSTER_OPT_TRANSACTION_SIZE_LIMIT_EXTRA}
 
 ${CLUSTER_OPT_PAXOS_SINGLE_LEADER_EXTRA}
+
+@attention The interactive option will be removed in a future release.
 )*");
 /**
  * $(CLUSTERSET_CREATEREPLICACLUSTER_BRIEF)
@@ -811,8 +817,20 @@ Lists the Router instances of the ClusterSet, or a single Router instance.
 
 @returns A JSON object listing the Router instances registered in the ClusterSet.
 
-This function lists and provides information about all Router instances registered
-on the Clusters members of the ClusterSet.
+This function lists and provides information about all Router instances
+registered on the Clusters members of the ClusterSet.
+
+For each router, the following information is provided, when available:
+
+@li hostname: Hostname.
+@li lastCheckIn: Timestamp of the last statistics update (check-in).
+@li roPort: Read-only port (Classic protocol).
+@li roXPort: Read-only port (X protocol).
+@li rwPort: Read-write port (Classic protocol).
+@li rwSplitPort: Read-write split port (Classic protocol).
+@li rwXPort: Read-write port (X protocol).
+@li targetCluster: Target Cluster for Router routing operations.
+@li version: Version.
 )*");
 
 /**
@@ -854,7 +872,7 @@ is to make to its statistics in the InnoDB Cluster metadata.
 Disabled by default.
 @li tags: Associates an arbitrary JSON object with custom key/value pairs with
 the ClusterSet metadata.
-@li read_replicas_policy: Routing policy to define Router's usage of Read
+@li read_only_targets: Routing policy to define Router's usage of Read
 Replicas. Default is 'append'.
 
 The target_cluster option supports the following values:
