@@ -220,6 +220,8 @@ status()
 incremental. Default is auto.
 @li waitRecovery: Integer value to indicate the recovery process verbosity
 level.
+@li recoveryProgress: Integer value to indicate the recovery process verbosity
+level.
 @li cloneDonor: host:port of an existing replicaSet member to clone from.
 IPv6 addresses are not supported for this option.
 ${OPT_INTERACTIVE}
@@ -227,6 +229,23 @@ ${OPT_INTERACTIVE}
 timeout and force the Shell to wait until the transaction sync finishes.
 Defaults to 0.
 ${OPT_CERT_SUBJECT}
+@li replicationConnectRetry: integer that specifies the interval in seconds
+between the reconnection attempts that the replica makes after the connection
+to the source times out.
+@li replicationRetryCount: integer that sets the maximum number of reconnection
+attempts that the replica makes after the connection to the source times out.
+@li replicationHeartbeatPeriod: decimal that controls the heartbeat interval,
+which stops the connection timeout occurring in the absence of data if the
+connection is still good.
+@li replicationCompressionAlgorithms: string that specifies the permitted
+compression algorithms for connections to the replication source.
+@li replicationZstdCompressionLevel: integer that specifies the compression
+level to use for connections to the replication source server that use the
+zstd compression algorithm.
+@li replicationBind: string that determines which of the replica's network
+interfaces is chosen for connecting to the source.
+@li replicationNetworkNamespace: string that specifies the network namespace
+to use for TCP/IP connections to the replication source server.
 
 The recoveryMethod option supports the following values:
 
@@ -250,6 +269,12 @@ The waitRecovery option supports the following values:
 @li 2: show detailed static progress information.
 @li 3: show detailed dynamic progress information using progress bars.
 
+The recoveryProgress option supports the following values:
+
+@li 0: do not show any progress information.
+@li 1: show detailed static progress information.
+@li 2: show detailed dynamic progress information using progress bars.
+
 By default, if the standard output on which the Shell is running refers to a
 terminal, the waitRecovery option has the value of 3. Otherwise, it has the
 value of 2.
@@ -259,6 +284,11 @@ be used when clone is selected as the recovery method. By default, a SECONDARY
 member will be chosen as donor. If no SECONDARY members are available the
 PRIMARY will be selected. The option accepts values in the format: 'host:port'.
 IPv6 addresses are not supported.
+
+@attention The waitRecovery option will be removed in a future release.
+Please use the recoveryProgress option instead.
+
+@attention The interactive option will be removed in a future release.
 )*");
 
 /**
@@ -280,24 +310,17 @@ void ReplicaSet::add_instance(
   // this validates the instance_def
   (void)get_connection_options(shcore::Value(instance_def));
 
-  // Init progress_style
-  Recovery_progress_style progress_style = Recovery_progress_style::TEXTUAL;
-
-  if (options->wait_recovery == 1)
-    progress_style = Recovery_progress_style::NOINFO;
-  else if (options->wait_recovery == 2)
-    progress_style = Recovery_progress_style::TEXTUAL;
-  else if (options->wait_recovery == 3)
-    progress_style = Recovery_progress_style::PROGRESSBAR;
-
   // TODO(anyone): The implementation should be updated to receive the options
   // object
+  auto opts = options;
+
   execute_with_pool(
       [&]() {
-        impl()->add_instance(
-            instance_def, options->ar_options, options->clone_options,
-            options->instance_label, options->cert_subject, progress_style,
-            options->timeout, options->interactive(), options->dry_run);
+        impl()->add_instance(instance_def, options->ar_options,
+                             options->clone_options, options->instance_label,
+                             options->cert_subject, opts->get_wait_recovery(),
+                             options->timeout, options->interactive(),
+                             options->dry_run);
         return shcore::Value();
       },
       options->interactive());
@@ -316,7 +339,9 @@ This function rejoins the given MySQL instance to the replicaset, making it a
 read-only SECONDARY replica of the current PRIMARY. Only instances previously
 added to the replicaset can be rejoined,
 otherwise the @<ReplicaSet@>.<<<addInstance>>>() function must be used to
-add a new instance.
+add a new instance. This can also be used to update the replication channel of
+instances (even if they are already ONLINE) if it does not have the expected
+state, source and settings.
 
 The PRIMARY of the replicaset must be reachable and available during this
 operation.
@@ -349,6 +374,8 @@ does not execute them
 incremental. Default is auto.
 @li waitRecovery: Integer value to indicate the recovery process verbosity
 level.
+@li recoveryProgress: Integer value to indicate the recovery process verbosity
+level.
 @li cloneDonor: host:port of an existing replicaSet member to clone from.
 IPv6 addresses are not supported for this option.
 ${OPT_INTERACTIVE}
@@ -378,6 +405,12 @@ The waitRecovery option supports the following values:
 @li 2: show detailed static progress information.
 @li 3: show detailed dynamic progress information using progress bars.
 
+The recoveryProgress option supports the following values:
+
+@li 0: do not show any progress information.
+@li 1: show detailed static progress information.
+@li 2: show detailed dynamic progress information using progress bars.
+
 By default, if the standard output on which the Shell is running refers to a
 terminal, the waitRecovery option has the value of 3. Otherwise, it has the
 value of 2.
@@ -387,6 +420,11 @@ be used when clone is selected as the recovery method. By default, a SECONDARY
 member will be chosen as donor. If no SECONDARY members are available the
 PRIMARY will be selected. The option accepts values in the format: 'host:port'.
 IPv6 addresses are not supported.
+
+@attention The waitRecovery option will be removed in a future release.
+Please use the recoveryProgress option instead.
+
+@attention The interactive option will be removed in a future release.
 )*");
 
 /**
@@ -412,19 +450,12 @@ void ReplicaSet::rejoin_instance(
   (void)get_connection_options(shcore::Value(instance_def));
 
   // Init progress_style
-  Recovery_progress_style progress_style = Recovery_progress_style::TEXTUAL;
-
-  if (options->wait_recovery == 1)
-    progress_style = Recovery_progress_style::NOINFO;
-  else if (options->wait_recovery == 2)
-    progress_style = Recovery_progress_style::TEXTUAL;
-  else if (options->wait_recovery == 3)
-    progress_style = Recovery_progress_style::PROGRESSBAR;
+  auto opts = options;
 
   execute_with_pool(
       [&]() {
         impl()->rejoin_instance(instance_def, options->clone_options,
-                                progress_style, options->timeout,
+                                opts->get_wait_recovery(), options->timeout,
                                 options->interactive(), options->dry_run);
         return shcore::Value();
       },
@@ -955,6 +986,29 @@ This function changes an option for a member of the ReplicaSet.
 
 The accepted options are:
 ${NAMESPACE_TAG}
+@li replicationConnectRetry: integer that specifies the interval in seconds
+between the reconnection attempts that the replica makes after the connection
+to the source times out.
+@li replicationRetryCount: integer that sets the maximum number of reconnection
+attempts that the replica makes after the connection to the source times out.
+@li replicationHeartbeatPeriod: decimal that controls the heartbeat interval,
+which stops the connection timeout occurring in the absence of data if the
+connection is still good.
+@li replicationCompressionAlgorithms: string that specifies the permitted
+compression algorithms for connections to the replication source.
+@li replicationZstdCompressionLevel: integer that specifies the compression
+level to use for connections to the replication source server that use the zstd
+compression algorithm.
+@li replicationBind: string that determines which of the replica's network
+interfaces is chosen for connecting to the source.
+@li replicationNetworkNamespace: string that specifies the network namespace
+to use for TCP/IP connections to the replication source server.
+
+@note Changing any of the "replication*" options won't immediately update the
+replication channel. Only on the next call to rejoinInstance() will the updated
+options take effect.
+@note Any of the "replication*" options accepts 'null', which sets the
+corresponding option to its default value on the next call to rejoinInstance().
 
 ${NAMESPACE_TAG_DETAIL_REPLICASET}
 
