@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2020, 2025, Oracle and/or its affiliates.
+ * Copyright (c) 2020, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -57,7 +55,6 @@ const std::set<std::string> k_mysqlaas_allowed_privileges = {
     "INSERT",
     "LOCK TABLES",
     "PROCESS",
-    "PROXY",  // this privilege is granted to the initial user account itself
     "REFERENCES",
     "REPLICATION CLIENT",
     "REPLICATION SLAVE",
@@ -72,15 +69,11 @@ const std::set<std::string> k_mysqlaas_allowed_privileges = {
     "BACKUP_ADMIN",
     "CONNECTION_ADMIN",
     "FLUSH_OPTIMIZER_COSTS",
-    "FLUSH_PRIVILEGES",
     "FLUSH_STATUS",
     "FLUSH_TABLES",
     "FLUSH_USER_RESOURCES",
-    "OPTION_TRACKER_OBSERVER",
     "REPLICATION_APPLIER",
     "ROLE_ADMIN",
-    "SHOW_ROUTINE",
-    "TRANSACTION_GTID_TAG",
     "XA_RECOVER_ADMIN",
 };
 
@@ -90,6 +83,11 @@ const std::set<std::string> k_mysqlaas_allowed_authentication_plugins = {
     "sha256_password",
 };
 
+const std::unordered_set<std::string> k_mds_users_with_system_user_priv = {
+    "mysql.infoschema", "mysql.session", "mysql.sys",
+    "ociadmin",         "ocidbm",        "ocirpl",
+};
+
 namespace {
 using Offset = std::pair<std::size_t, std::size_t>;
 using Offsets = std::vector<Offset>;
@@ -311,7 +309,8 @@ std::vector<std::string> check_privileges(
     if (next.empty() || shcore::str_caseeq(next, "ON", "TO", "FROM")) break;
   }
 
-  if (out_rewritten_grant) {
+  // update output variable only if there are restricted grants
+  if (!res.empty() && out_rewritten_grant) {
     if (remaining_priv == 0)
       out_rewritten_grant->clear();
     else
@@ -1710,118 +1709,75 @@ bool parse_grant_statement(const std::string &statement,
   }
 
   bool object_is_routine = false;
-  bool is_role = false;
-  std::vector<std::string> privileges;
 
   {
     bool all_privileges_done = false;
     bool privilege_done = false;
 
     do {
-      std::string privilege{it.next_token()};
+      auto privilege = shcore::str_upper(it.next_token());
 
       do {
-        if (!it.valid()) {
+        auto token = it.next_token();
+
+        if (shcore::str_caseeq(token, result.grant ? "TO" : "FROM")) {
+          // this is GRANT role, we're not interested in these
           return false;
         }
 
-        auto token = it.next_token();
+        if (shcore::str_caseeq(token, "(")) {
+          // column-level privilege, move past column_list
+          do {
+            token = it.next_token();
+          } while (!shcore::str_caseeq(token, ")"));
 
-        if (!is_role && shcore::str_caseeq(token, "@")) {
-          is_role = true;
+          // read next token (either , or ON)
+          token = it.next_token();
         }
 
-        if (is_role) {
-          if (shcore::str_caseeq(token, "@")) {
-            privilege += '@';
-            privilege += it.next_token();
+        privilege_done = shcore::str_caseeq(token, ",");
+        all_privileges_done = shcore::str_caseeq(token, "ON");
 
-            token = it.next_token();
-          }
-
-          privilege_done = true;
-          all_privileges_done =
-              shcore::str_caseeq(token, result.grant ? "TO" : "FROM");
+        if (!privilege_done && !all_privileges_done) {
+          privilege += ' ';
+          privilege += shcore::str_upper(token);
         } else {
-          if (shcore::str_caseeq(token, "(")) {
-            // column-level privilege, move past column_list
-            do {
-              token = it.next_token();
-            } while (!shcore::str_caseeq(token, ")"));
-
-            // read next token (either , or ON)
-            token = it.next_token();
+          if (privilege == "EXECUTE" || privilege == "ALTER ROUTINE") {
+            object_is_routine = true;
           }
 
-          privilege_done = shcore::str_caseeq(token, ",");
-
-          if (shcore::str_caseeq(token, result.grant ? "TO" : "FROM")) {
-            // this is GRANT/REVOKE role
-            all_privileges_done = is_role = true;
-          } else {
-            all_privileges_done = shcore::str_caseeq(token, "ON");
-          }
-
-          if (!privilege_done && !all_privileges_done) {
-            privilege += ' ';
-            privilege += token;
-          } else {
-            if (shcore::str_caseeq(privilege, "EXECUTE") ||
-                shcore::str_caseeq(privilege, "ALTER ROUTINE")) {
-              object_is_routine = true;
-            }
-          }
-        }
-
-        if (privilege_done || all_privileges_done) {
-          privileges.emplace_back(std::move(privilege));
+          result.privileges.emplace(std::move(privilege));
         }
       } while (!privilege_done && !all_privileges_done);
     } while (!all_privileges_done);
   }
 
-  if (!it.valid()) {
+  if (!it.valid() || result.privileges.count("PROXY")) {
     return false;
   }
 
-  if (is_role) {
-    result.level = Privilege_level_info::Level::ROLE;
-  } else {
-    for (auto &p : privileges) {
-      if (shcore::str_caseeq(p, "PROXY")) {
-        return false;
-      }
+  auto priv_level = it.next_token();
 
-      p = shcore::str_upper(p);
-    }
-
-    auto priv_level = it.next_token();
-
-    if (shcore::str_caseeq(priv_level, "TABLE")) {
-      object_is_routine = false;
-      // priv_level follows
-      priv_level = it.next_token();
-    } else if (shcore::str_caseeq(priv_level, "FUNCTION", "PROCEDURE")) {
-      object_is_routine = true;
-      // priv_level follows
-      priv_level = it.next_token();
-    }
-
-    shcore::split_priv_level(std::string{priv_level}, &result.schema,
-                             &result.object);
-
-    if ("*" == result.schema) {
-      result.level = Privilege_level_info::Level::GLOBAL;
-    } else if ("*" == result.object) {
-      result.level = Privilege_level_info::Level::SCHEMA;
-    } else {
-      result.level = object_is_routine ? Privilege_level_info::Level::ROUTINE
-                                       : Privilege_level_info::Level::TABLE;
-    }
+  if (shcore::str_caseeq(priv_level, "TABLE")) {
+    object_is_routine = false;
+    // priv_level follows
+    priv_level = it.next_token();
+  } else if (shcore::str_caseeq(priv_level, "FUNCTION", "PROCEDURE")) {
+    object_is_routine = true;
+    // priv_level follows
+    priv_level = it.next_token();
   }
 
-  for (auto &p : privileges) {
-    result.privileges.emplace(std::move(p));
+  shcore::split_priv_level(std::string{priv_level}, &result.schema,
+                           &result.object);
+
+  if ("*" == result.schema) {
+    result.level = Privilege_level_info::Level::GLOBAL;
+  } else if ("*" == result.object) {
+    result.level = Privilege_level_info::Level::SCHEMA;
+  } else {
+    result.level = object_is_routine ? Privilege_level_info::Level::ROUTINE
+                                     : Privilege_level_info::Level::TABLE;
   }
 
   *info = std::move(result);
@@ -1829,5 +1785,34 @@ bool parse_grant_statement(const std::string &statement,
   return true;
 }
 
+bool supports_set_any_definer_privilege(const mysqlshdk::utils::Version &v) {
+  return v >= mysqlshdk::utils::Version(8, 2, 0);
+}
+
+bool replace_keyword(std::string_view stmt, std::string_view from,
+                     std::string_view to, std::string *result) {
+  mysqlshdk::utils::SQL_iterator it(stmt);
+  std::pair<std::string_view, size_t> token;
+
+  while (it) {
+    token = it.next_token_and_offset();
+
+    if (shcore::str_caseeq(token.first, from)) {
+      if (result) {
+        // use an additional variable in case of &stmt == result
+        std::string output{stmt.substr(0, token.second)};
+        output += to;
+        output += stmt.substr(token.second + token.first.length());
+
+        *result = std::move(output);
+      }
+
+      return true;
+    }
+  }
+
+  return false;
+}
+
 }  // namespace compatibility
 }  // namespace mysqlsh
