@@ -84,6 +84,21 @@ class Profiler final {
   mysqlshdk::utils::Duration m_duration;
 };
 
+std::vector<std::unique_ptr<mysqlshdk::db::Warning>> fetch_warnings(
+    const std::shared_ptr<mysqlshdk::db::IResult> &result) {
+  std::vector<std::unique_ptr<mysqlshdk::db::Warning>> warnings;
+
+  if (const auto count = result->get_warning_count()) {
+    warnings.resize(count);
+
+    for (std::size_t i = 0; i < count; ++i) {
+      warnings[i] = result->fetch_one_warning();
+    }
+  }
+
+  return warnings;
+}
+
 }  // namespace
 
 void Instance_cache::Index::reset() {
@@ -682,7 +697,7 @@ void Instance_cache_builder::fetch_columns() {
     return column;
   };
 
-  iterate_tables_and_views(
+  const auto warnings = iterate_tables_and_views(
       info,
       [&table_columns, &create_column](
           const std::string &schema_name, const std::string &table_name,
@@ -734,6 +749,23 @@ void Instance_cache_builder::fetch_columns() {
       }
     }
   }
+
+  // BUG#35415976 - detect invalid views
+  if (!warnings.empty()) {
+    const auto console = current_console();
+    bool has_invalid_view = false;
+
+    for (const auto &warning : warnings) {
+      if (ER_VIEW_INVALID == warning->code) {
+        has_invalid_view = true;
+        console->print_error(warning->msg);
+      }
+    }
+
+    if (has_invalid_view) {
+      THROW_ERROR0(SHERR_DUMP_IC_INVALID_VIEWS);
+    }
+  }
 }
 
 void Instance_cache_builder::fetch_table_indexes() {
@@ -1067,7 +1099,8 @@ void Instance_cache_builder::iterate_schemas(
   }
 }
 
-void Instance_cache_builder::iterate_tables_and_views(
+std::vector<std::unique_ptr<mysqlshdk::db::Warning>>
+Instance_cache_builder::iterate_tables_and_views(
     const Iterate_table &info,
     const std::function<void(const std::string &, const std::string &,
                              Instance_cache::Table *,
@@ -1140,26 +1173,30 @@ void Instance_cache_builder::iterate_tables_and_views(
       view_callback(current_schema, current_object, view, row);
     }
   }
+
+  return fetch_warnings(result);
 }
 
-void Instance_cache_builder::iterate_tables(
+std::vector<std::unique_ptr<mysqlshdk::db::Warning>>
+Instance_cache_builder::iterate_tables(
     const Iterate_table &info,
     const std::function<void(const std::string &, const std::string &,
                              Instance_cache::Table *,
                              const mysqlshdk::db::IRow *)> &callback) {
   Profiler profiler{"iterating tables"};
 
-  iterate_tables_and_views(info, callback, {});
+  return iterate_tables_and_views(info, callback, {});
 }
 
-void Instance_cache_builder::iterate_views(
+std::vector<std::unique_ptr<mysqlshdk::db::Warning>>
+Instance_cache_builder::iterate_views(
     const Iterate_table &info,
     const std::function<void(const std::string &, const std::string &,
                              Instance_cache::View *,
                              const mysqlshdk::db::IRow *)> &callback) {
   Profiler profiler{"iterating views"};
 
-  iterate_tables_and_views(info, {}, callback);
+  return iterate_tables_and_views(info, {}, callback);
 }
 
 void Instance_cache_builder::set_schema_filter() {
