@@ -79,7 +79,7 @@ int local_infile_error_nop(void * /* userdata */, char * /* error_msg */,
 
 }  // namespace
 
-Transaction_buffer::Transaction_buffer(Dialect dialect,
+Transaction_buffer::Transaction_buffer(const Dialect &dialect,
                                        mysqlshdk::storage::IFile *file,
                                        uint64_t max_transaction_size,
                                        uint64_t skip_bytes)
@@ -87,7 +87,11 @@ Transaction_buffer::Transaction_buffer(Dialect dialect,
   m_options.max_trx_size = max_transaction_size;
   m_options.skip_bytes = skip_bytes;
 
-  if (m_dialect == Dialect::default_()) {
+  if (m_dialect.lines_terminated_by.empty() ||
+      m_dialect.fields_terminated_by == m_dialect.lines_terminated_by) {
+    // we're unable to sub-chunk properly in this case
+    m_options.max_trx_size = 0;
+  } else if (m_dialect == Dialect::default_()) {
     find_first_row_boundary_after =
         &Transaction_buffer::find_first_row_boundary_after_impl_default;
     find_last_row_boundary_before =
@@ -179,7 +183,6 @@ int Transaction_buffer::consume(char *buffer, unsigned int length) {
     }
 
     m_trx_size += length;
-    m_current_offset += length;
 
     if (length > m_options.max_trx_size) {
       // in a single read, we got more bytes than the transaction limit, either
@@ -355,7 +358,6 @@ uint64_t Transaction_buffer::find_last_row_boundary_before_impl_default(
 
   if (p == 0) return 0;
 
-  p = adjust_line_offset(p);
   p = m_data.rfind(needle, p);
 
   if (p >= m_data.length()) return 0;
@@ -387,7 +389,6 @@ uint64_t Transaction_buffer::find_last_row_boundary_before_impl_no_escape(
 
   if (p < needle.size()) return 0;
 
-  p = adjust_line_offset(p);
   p = m_data.rfind(needle, p);
 
   if (p >= m_data.length()) return 0;
@@ -426,7 +427,6 @@ uint64_t Transaction_buffer::find_last_row_boundary_before_impl_escape(
 
   if (p < needle.size()) return 0;
 
-  p = adjust_line_offset(p);
   p = m_data.rfind(needle, p);
 
   while (p != std::string::npos) {
@@ -446,34 +446,6 @@ uint64_t Transaction_buffer::find_last_row_boundary_before_impl_escape(
   return 0;
 }
 
-uint64_t Transaction_buffer::adjust_line_offset(uint64_t offset) {
-  // find boundary of the last row that will fit within the given limit
-  if (m_options.offsets) {
-    const auto size = m_options.offsets->size();
-    bool index_changed = false;
-
-    for (; m_offset_index < size; ++m_offset_index, index_changed = true) {
-      const auto &o = (*m_options.offsets)[m_offset_index];
-
-      if (o > m_current_offset) {
-        const auto new_offset = o - m_current_offset;
-
-        if (new_offset > offset) {
-          if (index_changed) {
-            --m_offset_index;
-          }
-
-          break;
-        }
-
-        return new_offset;
-      }
-    }
-  }
-
-  return offset;
-}
-
 int Transaction_buffer::fast_sub_chunking(char *buffer, unsigned int length) {
   if (!m_data.empty()) {
     // if data is stored locally, then a row didn't fit into an empty buffer,
@@ -615,7 +587,14 @@ int local_infile_read(void *userdata, char *buffer,
   return bytes;
 }
 
-void local_infile_end(void *) noexcept {}
+void local_infile_end(void *userdata) noexcept {
+  assert(userdata);
+  const auto file_info = static_cast<File_info *>(userdata);
+
+  if (file_info->on_infile_read_end) {
+    file_info->on_infile_read_end();
+  }
+}
 
 int local_infile_error(void *userdata, char *error_msg,
                        unsigned int error_msg_len) noexcept {
@@ -653,7 +632,10 @@ Load_data_worker::Load_data_worker(
       m_range_queue(range_queue),
       m_thread_exception(*thread_exception),
       m_stats(*stats),
-      m_query_comment(query_comment) {}
+      m_query_comment(query_comment) {
+  m_state = Thread_state::IDLE;
+  ++m_stats.thread_states[m_state];
+}
 
 void Load_data_worker::operator()() {
   mysqlsh::Mysql_thread t;
@@ -673,7 +655,7 @@ void Load_data_worker::operator()() {
     auto const conn_opts = m_opt.connection_options();
     session->connect(conn_opts);
   } catch (...) {
-    m_thread_exception[m_thread_id] = std::current_exception();
+    handle_exception();
     return;
   }
 
@@ -694,6 +676,7 @@ void Load_data_worker::execute(
     fi.prog_file_bytes = m_prog_file_bytes;
     fi.user_interrupt = &m_interrupt;
     fi.max_rate = m_opt.max_rate();
+    fi.on_infile_read_end = [this]() { set_state(Thread_state::COMMITTING); };
     uint64_t max_trx_size = 0;
     const auto query = [&session](const auto &sql) {
       return session->query(sql);
@@ -842,9 +825,8 @@ void Load_data_worker::execute(
             fi.filehandler ? fi.filehandler->filename() + ": " : "";
         auto msg = worker_name + task + error;
 
-        if (fi.range_read) {
-          msg += " @ file bytes range [" + std::to_string(r.range.first) +
-                 ", " + std::to_string(r.range.second) + ")";
+        if (!r.context.empty()) {
+          msg += r.context;
         }
 
         if (!extra.empty()) {
@@ -863,25 +845,26 @@ void Load_data_worker::execute(
               break;
             }
 
-            fi.filehandler = m_opt.create_file_handle(r.file_path);
+            fi.filehandler = std::move(r.file);
             fi.range_read = r.range_read;
 
             if (r.range_read) {
               fi.bytes_left = r.range.second - r.range.first;
-              // TODO(pawel): maxBytesPerTransaction should not be ignored in
-              // case of a single uncompressed file imported in chunks
+              // maxBytesPerTransaction is ignored in case of a file imported in
+              // chunks, because we assume that in this case bytesPerChunk ==
+              // maxBytesPerTransaction
               max_trx_size = 0;
 
               // if fi.range_read == true, we're importing in chunks from a
-              // single uncompressed file, rows were already skipped
+              // single file, rows were already skipped
               query_ignore_lines.clear();
             } else {
               fi.bytes_left = 0;
               max_trx_size = m_opt.max_transaction_size();
 
               if (m_opt.skip_rows_count() > 0) {
-                // this handles the case when a single compressed file or
-                // multiple files are being imported and skipRows is set
+                // this handles the case when multiple files are being imported
+                // and skipRows is set
                 query_ignore_lines = " IGNORE " +
                                      std::to_string(m_opt.skip_rows_count()) +
                                      " LINES";
@@ -903,7 +886,7 @@ void Load_data_worker::execute(
           fi.bytes_left = 0;
         }
       } catch (const std::exception &e) {
-        m_thread_exception[m_thread_id] = std::current_exception();
+        handle_exception();
         mysqlsh::current_console()->print_error(format_error_message(e.what()));
         throw std::exception(e);
       }
@@ -929,8 +912,10 @@ void Load_data_worker::execute(
       });
 
       try {
+        set_state(Thread_state::READING);
         fi.buffer.before_query();
         load_result = query(m_query_comment + full_query);
+        set_state(Thread_state::IDLE);
         fi.buffer.flush_done(&fi.continuation);
         m_stats.total_data_bytes += fi.data_bytes;
         m_stats.total_file_bytes += fi.file_bytes;
@@ -940,7 +925,7 @@ void Load_data_worker::execute(
           ++m_stats.total_files_processed;
         }
       } catch (const mysqlshdk::db::Error &e) {
-        m_thread_exception[m_thread_id] = std::current_exception();
+        handle_exception();
         const auto error_msg = format_error_message(e.format(), full_query);
         mysqlsh::current_console()->print_error(error_msg);
 
@@ -953,12 +938,12 @@ void Load_data_worker::execute(
 
         throw std::runtime_error(error_msg);
       } catch (const mysqlshdk::rest::Connection_error &e) {
-        m_thread_exception[m_thread_id] = std::current_exception();
+        handle_exception();
         const auto error_msg = format_error_message(e.what());
         mysqlsh::current_console()->print_error(error_msg);
         throw std::runtime_error(error_msg);
       } catch (const std::exception &e) {
-        m_thread_exception[m_thread_id] = std::current_exception();
+        handle_exception();
         const auto error_msg = format_error_message(e.what());
         mysqlsh::current_console()->print_error(error_msg);
         throw std::exception(e);
@@ -1056,10 +1041,23 @@ void Load_data_worker::execute(
   } catch (const std::exception &e) {
     if (!m_thread_exception[m_thread_id]) {
       mysqlsh::current_console()->print_error(worker_name + e.what());
-      m_thread_exception[m_thread_id] = std::current_exception();
+      handle_exception();
     }
   } catch (...) {
-    m_thread_exception[m_thread_id] = std::current_exception();
+    handle_exception();
+  }
+}
+
+void Load_data_worker::handle_exception() {
+  set_state(Thread_state::ERROR);
+  m_thread_exception[m_thread_id] = std::current_exception();
+}
+
+void Load_data_worker::set_state(Thread_state new_state) {
+  if (m_state != new_state) {
+    --m_stats.thread_states[m_state];
+    m_state = new_state;
+    ++m_stats.thread_states[m_state];
   }
 }
 
