@@ -26,6 +26,8 @@
 #include <mysqld_error.h>
 
 #include <algorithm>
+#include <regex>
+#include <utility>
 
 #include "modules/mod_utils.h"
 #include "modules/util/common/dump/utils.h"
@@ -180,12 +182,12 @@ void Load_dump_options::set_session(
   m_target.set(mysqlshdk::db::kLocalInfile, "true");
 
   // Set long timeouts by default
-  std::string timeout = "86400000";  // 1 day in milliseconds
-  if (!m_target.has(mysqlshdk::db::kNetReadTimeout)) {
-    m_target.set(mysqlshdk::db::kNetReadTimeout, timeout);
+  constexpr auto timeout = 86400000;  // 1 day in milliseconds
+  if (!m_target.has_net_read_timeout()) {
+    m_target.set_net_read_timeout(timeout);
   }
-  if (!m_target.has(mysqlshdk::db::kNetWriteTimeout)) {
-    m_target.set(mysqlshdk::db::kNetWriteTimeout, timeout);
+  if (!m_target.has_net_write_timeout()) {
+    m_target.set_net_write_timeout(timeout);
   }
 
   // set size of max packet (~size of 1 row) we can send to server
@@ -283,6 +285,11 @@ void Load_dump_options::validate() {
     if (config && config->valid()) {
       if (mysqlshdk::oci::PAR_type::MANIFEST == config->par().type() ||
           mysqlshdk::oci::PAR_type::PREFIX == config->par().type()) {
+        if (mysqlshdk::oci::PAR_type::MANIFEST == config->par().type()) {
+          current_console()->print_warning(
+              "Support for PAR Manifest is deprecated and will be removed in a "
+              "future release. Please use a prefix PAR instead.");
+        }
         if (!m_progress_file.has_value()) {
           throw shcore::Exception::argument_error(
               "When using a PAR to load a dump, the progressFile option must "
@@ -440,10 +447,13 @@ void Load_dump_options::on_unpacked_options() {
 
 void Load_dump_options::on_log_options(const char *msg) const {
   std::string s = msg;
-  const auto pos = s.find("\"progressFile\":\"https://objectstorage.");
 
-  if (std::string::npos != pos) {
-    s = mysqlshdk::oci::hide_par_secret(s, pos);
+  static const std::regex k_par_progress_file(
+      R"("progressFile":"https://(?:[^\.]+\.)?objectstorage\.)");
+  std::smatch match;
+
+  if (std::regex_search(s, match, k_par_progress_file)) {
+    s = mysqlshdk::oci::hide_par_secret(s, match.position());
   }
 
   log_info("Load options: %s", s.c_str());
