@@ -336,7 +336,7 @@ Sql_upgrade_check::get_reserved_keywords_check(const Upgrade_info &info) {
                "'RECURSIVE', 'ROW', 'ROWS', 'ROW_NUMBER', 'SYSTEM', 'WINDOW'");
   add_keywords("8.0.14", "'LATERAL'");
   add_keywords("8.0.17", "'ARRAY' ,'MEMBER'");
-  add_keywords("8.0.31", "'FULL'");
+  add_keywords("8.0.31", "'FULL', 'INTERSECT'");
 
   keywords = "(" + keywords + ");";
   return std::make_unique<Sql_upgrade_check>(
@@ -1887,6 +1887,73 @@ bool UNUSED_VARIABLE(register_get_empty_dot_table_syntax_check) =
         Upgrade_check::Target::OBJECT_DEFINITIONS, "8.0.0");
 }
 
+std::unique_ptr<Sql_upgrade_check>
+Sql_upgrade_check::get_invalid_engine_foreign_key_check() {
+  return std::make_unique<Sql_upgrade_check>(
+      "mysqlInvalidEngineForeignKeyCheck",
+      "Check for columns that have foreign keys pointing to tables from a "
+      "diffrent database engine.",
+      std::vector<std::string>{
+          R"(select
+  info.TABLE_SCHEMA,
+  info.TABLE_NAME,
+  info.COLUMN_NAME,
+  CONCAT('column has invalid foreign key to column \'',
+    info.REF_COL_NAME,
+    '\' from table \'',
+    info.REF_NAME,
+    '\' that is from a different database engine (',
+    info.REF_ENGINE,
+    ').'
+  ) as DESCRIPTION
+from
+  (
+    select
+      info_t.TABLE_SCHEMA,
+      info_t.TABLE_NAME,
+      inno_c.FOR_COL_NAME as COLUMN_NAME,
+      info_t.ENGINE,
+      inno_t.REF_NAME,
+      inno_c.REF_COL_NAME,
+      (
+        select
+          ENGINE
+        from
+          information_schema.tables
+        where
+          CONCAT(
+            TABLE_SCHEMA,
+            '/',
+            TABLE_NAME
+          ) = inno_t.REF_NAME) as REF_ENGINE
+    from
+      information_schema.innodb_sys_foreign_cols inno_c,
+      information_schema.innodb_sys_foreign inno_t,
+      information_schema.tables info_t
+    where
+      inno_c.ID = inno_t.ID and
+      inno_t.FOR_NAME = CONCAT(
+        info_t.TABLE_SCHEMA,
+        '/',
+        info_t.TABLE_NAME
+      ) and
+      info_t.TABLE_SCHEMA not in ('sys', 'mysql', 'information_schema', 'performance_schema')
+  ) info
+where
+  info.ENGINE != info.REF_ENGINE;)"},
+      Upgrade_issue::ERROR,
+      "The following columns have foreign keys pointing to tables from "
+      "diffrent database engines than originating table. This is invalid and "
+      "probably a mistake done when FOREIGN_KEY_CHECKS was turned OFF:\n");
+}
+
+namespace {
+bool UNUSED_VARIABLE(register_get_invalid_engine_foreign_key_check) =
+    Upgrade_check::register_check(
+        std::bind(&Sql_upgrade_check::get_invalid_engine_foreign_key_check),
+        Upgrade_check::Target::OBJECT_DEFINITIONS, "8.0.0");
+}
+
 Upgrade_check_config::Upgrade_check_config(const Upgrade_check_options &options)
     : m_output_format(options.output_format) {
   m_upgrade_info.target_version = options.target_version;
@@ -1981,6 +2048,10 @@ bool check_for_upgrade(const Upgrade_check_config &config) {
     }
   };
 
+  // Workaround for 5.7 "No database selected/Corrupted" UPGRADE bug present up
+  // to 5.7.39
+  config.session()->execute("USE mysql;");
+
   for (const auto &check : checklist)
     if (check->is_runnable()) {
       try {
