@@ -122,55 +122,55 @@ std::string to_string(Replication_channel::Applier::Status status) {
 }
 
 std::string to_string(const Replication_channel::Error &error) {
-  if (error.code != 0) {
-    return shcore::str_format("%s (%i) at %s", error.message.c_str(),
-                              error.code, error.timestamp.c_str());
-  }
-  return "";
+  if (error.code == 0) return {};
+  return shcore::str_format("%s (%i) at %s", error.message.c_str(), error.code,
+                            error.timestamp.c_str());
 }
 
 std::string format_status(const Replication_channel &channel, bool verbose) {
   // This follows the KVP format
 
   std::string msg;
+  msg.reserve(128);  // better than nothing
 
   msg += shcore::make_kvp(
-      "source", channel.host + ":" + std::to_string(channel.port), '"');
-  msg += " " + shcore::make_kvp("channel", channel.channel_name);
-  msg += " " + shcore::make_kvp("status", to_string(channel.status()));
+      "source", shcore::str_format("%s:%d", channel.host.c_str(), channel.port),
+      '"');
+  msg.append(" ").append(shcore::make_kvp("channel", channel.channel_name));
+  msg.append(" ").append(
+      shcore::make_kvp("status", to_string(channel.status())));
 
-  if (verbose || channel.status() != Replication_channel::OFF) {
-    msg +=
-        " " + shcore::make_kvp("receiver", to_string(channel.receiver.state));
-    if (channel.receiver.last_error.code != 0)
-      msg +=
-          " " + shcore::make_kvp("last_error",
-                                 to_string(channel.receiver.last_error), '"');
+  if (!verbose && channel.status() == Replication_channel::OFF) return msg;
 
-    if (channel.coordinator.state != Replication_channel::Coordinator::NONE) {
-      msg += " " + shcore::make_kvp("coordinator",
-                                    to_string(channel.coordinator.state));
-      if (channel.coordinator.last_error.code != 0)
-        msg += " " + shcore::make_kvp("last_error",
-                                      to_string(channel.coordinator.last_error),
-                                      '"');
-    }
-    if (channel.appliers.size() == 1) {
-      msg += " " + shcore::make_kvp("applier",
-                                    to_string(channel.appliers.front().state));
-      if (channel.appliers.front().last_error.code != 0)
-        msg += " " + shcore::make_kvp(
-                         "last_error",
-                         to_string(channel.appliers.front().last_error), '"');
-    } else {
-      int i = 0;
-      for (const auto &a : channel.appliers) {
-        msg += " " + shcore::make_kvp(("applier" + std::to_string(i)).c_str(),
-                                      to_string(a.state));
-        if (a.last_error.code != 0)
-          msg += " " + shcore::make_kvp("last_error", to_string(a.last_error));
-        ++i;
-      }
+  msg += " " + shcore::make_kvp("receiver", to_string(channel.receiver.state));
+  if (channel.receiver.last_error.code != 0)
+    msg += " " + shcore::make_kvp("last_error",
+                                  to_string(channel.receiver.last_error), '"');
+
+  if (channel.coordinator.state != Replication_channel::Coordinator::NONE) {
+    msg += " " + shcore::make_kvp("coordinator",
+                                  to_string(channel.coordinator.state));
+    if (channel.coordinator.last_error.code != 0)
+      msg += " " + shcore::make_kvp("last_error",
+                                    to_string(channel.coordinator.last_error),
+                                    '"');
+  }
+
+  if (channel.appliers.size() == 1) {
+    msg += " " + shcore::make_kvp("applier",
+                                  to_string(channel.appliers.front().state));
+    if (channel.appliers.front().last_error.code != 0)
+      msg += " " + shcore::make_kvp(
+                       "last_error",
+                       to_string(channel.appliers.front().last_error), '"');
+  } else {
+    int i = 0;
+    for (const auto &a : channel.appliers) {
+      msg += " " + shcore::make_kvp(("applier" + std::to_string(i)).c_str(),
+                                    to_string(a.state));
+      if (a.last_error.code != 0)
+        msg += " " + shcore::make_kvp("last_error", to_string(a.last_error));
+      ++i;
     }
   }
 
@@ -257,7 +257,7 @@ void unserialize_channel_applier_info(const mysqlshdk::db::Row_ref_by_name &row,
   if (row.is_null("w_state")) return;
 
   Replication_channel::Applier applier;
-  if (std::string state = row.get_string("w_state"); state == "ON")
+  if (auto state = row.get_string("w_state"); state == "ON")
     applier.state = Replication_channel::Applier::ON;
   else if (state == "OFF")
     applier.state = Replication_channel::Applier::OFF;
@@ -392,7 +392,7 @@ std::vector<std::string> get_incoming_channel_names(
 }
 
 bool get_channel_status(const mysqlshdk::mysql::IInstance &instance,
-                        const std::string &channel_name,
+                        std::string_view channel_name,
                         Replication_channel *out_channel) {
   auto result = instance.queryf(
       std::string(k_base_channel_query) + "WHERE c.channel_name = ?",
@@ -414,7 +414,7 @@ bool get_channel_status(const mysqlshdk::mysql::IInstance &instance,
 }
 
 bool get_channel_state(const mysqlshdk::mysql::IInstance &instance,
-                       const std::string &channel_name,
+                       std::string_view channel_name,
                        Replication_channel::Receiver::State *out_io_state,
                        Replication_channel::Applier::State *out_sql_state) {
   auto result =
@@ -450,7 +450,7 @@ bool get_channel_state(const mysqlshdk::mysql::IInstance &instance,
 }
 
 bool get_channel_state(const mysqlshdk::mysql::IInstance &instance,
-                       const std::string &channel_name,
+                       std::string_view channel_name,
                        Replication_channel::Receiver::State *out_io_state,
                        Replication_channel::Error *out_io_error,
                        Replication_channel::Applier::State *out_sql_state,
@@ -501,6 +501,7 @@ bool get_channel_state(const mysqlshdk::mysql::IInstance &instance,
 }
 
 namespace {
+
 void unserialize_channel_master_info(
     const mysqlshdk::db::Row_ref_by_name &row,
     Replication_channel_master_info *out_master_info) {
@@ -518,7 +519,7 @@ void unserialize_channel_master_info(
   out_master_info->ssl_key = row.get_string("Ssl_key");
   out_master_info->ssl_verify_server_cert =
       row.get_int("Ssl_verify_server_cert");
-  out_master_info->heartbeat = row.get_double("Heartbeat");
+  out_master_info->heartbeat_period = row.get_double("Heartbeat");
   out_master_info->bind = row.get_string("Bind");
   out_master_info->ignored_server_ids = row.get_string("Ignored_server_ids");
   out_master_info->uuid = row.get_string("Uuid");
@@ -537,11 +538,11 @@ void unserialize_channel_master_info(
     out_master_info->network_namespace = row.get_string("Network_namespace");
   if (row.has_field("Master_compression_algorithm") &&
       !row.is_null("Master_compression_algorithm"))
-    out_master_info->master_compression_algorithm =
+    out_master_info->compression_algorithm =
         row.get_string("Master_compression_algorithm");
   if (row.has_field("Master_zstd_compression_level") &&
       !row.is_null("Master_zstd_compression_level"))
-    out_master_info->master_zstd_compression_level =
+    out_master_info->zstd_compression_level =
         row.get_uint("Master_zstd_compression_level");
   if (row.has_field("Tls_ciphersuites") && !row.is_null("Tls_ciphersuites"))
     out_master_info->tls_ciphersuites = row.get_string("Tls_ciphersuites");
@@ -576,9 +577,9 @@ bool get_channel_info(const mysqlshdk::mysql::IInstance &instance,
                       const std::string &channel_name,
                       Replication_channel_master_info *out_master_info,
                       Replication_channel_relay_log_info *out_relay_log_info) {
-  assert(out_master_info && out_relay_log_info);
+  if (!out_master_info && !out_relay_log_info) return false;
 
-  {
+  if (out_master_info) {
     auto result = instance.queryf(
         "SELECT * FROM mysql.slave_master_info"
         " WHERE channel_name = ?",
@@ -590,7 +591,7 @@ bool get_channel_info(const mysqlshdk::mysql::IInstance &instance,
     }
   }
 
-  {
+  if (out_relay_log_info) {
     auto result = instance.queryf(
         "SELECT * FROM mysql.slave_relay_log_info"
         " WHERE channel_name = ?",
@@ -613,7 +614,7 @@ std::vector<Slave_host> get_slaves(
     host.host = row.get_string("Host");
     host.port = row.get_uint("Port");
     host.uuid = row.get_string("Slave_UUID");
-    slaves.push_back(host);
+    slaves.push_back(std::move(host));
   }
 
   // Sort by host/name to ensure deterministic output
@@ -774,11 +775,12 @@ size_t estimate_gtid_set_size(const std::string &gtid_set) {
   size_t count = 0;
   shcore::str_itersplit(
       gtid_set,
-      [&count](const std::string &s) {
+      [&count](std::string_view s) {
         size_t p = s.find(':');
         if (p != std::string::npos) {
+          std::string range{s};
           size_t begin, end;
-          switch (sscanf(&s[p + 1], "%zu-%zu", &begin, &end)) {
+          switch (sscanf(&range[p + 1], "%zu-%zu", &begin, &end)) {
             case 2:
               count += end - begin + 1;
               break;
@@ -803,42 +805,63 @@ std::string get_purged_gtid_set(const mysqlshdk::mysql::IInstance &server) {
 }
 
 std::string get_received_gtid_set(const mysqlshdk::mysql::IInstance &server,
-                                  const std::string &channel_name) {
+                                  std::string_view channel_name) {
+  // In the query, GTID_SUBTRACT is used, not to subtract GTIDs from the set,
+  // but to actually clean the set, by removing duplicates, etc.
   return server.queryf_one_string(
       0, "",
-      "SELECT GTID_SUBTRACT(GROUP_CONCAT(received_transaction_set), '')"
-      "   FROM performance_schema.replication_connection_status"
-      "   WHERE channel_name = ?",
+      "SELECT received_transaction_set FROM "
+      "performance_schema.replication_connection_status WHERE channel_name = ?",
       channel_name);
 }
 
-std::string get_total_gtid_set(
-    const mysqlshdk::mysql::IInstance &server,
-    const std::vector<std::string> &known_channel_names) {
+std::string get_total_gtid_set(const mysqlshdk::mysql::IInstance &server,
+                               std::string_view channel_name) {
+  // In the query, GTID_SUBTRACT is used, not to subtract GTIDs from the set,
+  // but to actually clean the set, by removing duplicates, etc.
   return server.queryf_one_string(
       0, "",
-      "SELECT GTID_SUBTRACT(CONCAT(@@GLOBAL.GTID_EXECUTED, ',', ("
-      "   SELECT GROUP_CONCAT(received_transaction_set)"
-      "       FROM performance_schema.replication_connection_status"
-      "       WHERE channel_name IN (" +
-          shcore::str_join(known_channel_names, ",", shcore::quote_sql_string) +
-          "))), '')");
+      "SELECT GTID_SUBTRACT(CONCAT(@@GLOBAL.GTID_EXECUTED, ',', (SELECT "
+      "received_transaction_set FROM "
+      "performance_schema.replication_connection_status WHERE channel_name = "
+      "?)), '')",
+      channel_name);
+}
+
+std::string get_total_gtid_set(const mysqlshdk::mysql::IInstance &server,
+                               const std::vector<std::string> &channel_names) {
+  if (channel_names.empty()) return {};
+  if (channel_names.size() == 1)
+    return get_total_gtid_set(server, channel_names.front());
+
+  // In the query, GTID_SUBTRACT is used, not to subtract GTIDs from the set,
+  // but to actually clean the set, by removing duplicates, etc.
+  return server.queryf_one_string(
+      0, "",
+      shcore::str_format(
+          "SELECT GTID_SUBTRACT(CONCAT(@@GLOBAL.GTID_EXECUTED, ',', (SELECT "
+          "GROUP_CONCAT(received_transaction_set) FROM "
+          "performance_schema.replication_connection_status WHERE channel_name "
+          "IN (%s))), '')",
+          shcore::str_join(channel_names, ",", shcore::quote_sql_string)
+              .c_str()));
 }
 
 Gtid_set_relation compare_gtid_sets(const mysqlshdk::mysql::IInstance &server,
-                                    const std::string &gtidset_a,
-                                    const std::string &gtidset_b,
+                                    std::string_view gtidset_a,
+                                    std::string_view gtidset_b,
                                     std::string *out_missing_from_a,
                                     std::string *out_missing_from_b) {
-  if (out_missing_from_a) *out_missing_from_a = gtidset_b;
-  if (out_missing_from_b) *out_missing_from_b = gtidset_a;
+  if (gtidset_a.empty() || gtidset_b.empty()) {
+    if (out_missing_from_a) *out_missing_from_a = std::string{gtidset_b};
+    if (out_missing_from_b) *out_missing_from_b = std::string{gtidset_a};
 
-  if (gtidset_a.empty()) {
-    if (gtidset_b.empty())
-      return Gtid_set_relation::EQUAL;
-    else
-      return Gtid_set_relation::CONTAINED;
-  } else if (gtidset_b.empty()) {
+    if (gtidset_a.empty()) {
+      return gtidset_b.empty() ? Gtid_set_relation::EQUAL
+                               : Gtid_set_relation::CONTAINED;
+    }
+
+    assert(gtidset_b.empty());
     return Gtid_set_relation::CONTAINS;
   }
 
