@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2018, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2018, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -849,7 +847,7 @@ bool check_indicator_tag(const mysql::IInstance &instance,
  * @return mysqlshdk::db::Ssl_options
  */
 mysqlshdk::db::Ssl_options read_ssl_client_options(
-    const mysqlshdk::mysql::IInstance &instance, bool set_cert) {
+    const mysqlshdk::mysql::IInstance &instance, bool set_cert, bool set_ca) {
   mysqlshdk::db::Ssl_options ssl_options;
 
   auto res = instance.query(
@@ -861,8 +859,10 @@ mysqlshdk::db::Ssl_options read_ssl_client_options(
   log_debug("SSL options for %s: %s", instance.descr().c_str(),
             mysqlshdk::db::to_string(*row).c_str());
 
-  if (!row->is_null(0)) ssl_options.set_ca(row->get_string(0));
-  if (!row->is_null(1)) ssl_options.set_capath(row->get_string(1));
+  if (set_ca) {
+    if (!row->is_null(0)) ssl_options.set_ca(row->get_string(0));
+    if (!row->is_null(1)) ssl_options.set_capath(row->get_string(1));
+  }
   if (set_cert) {
     if (!row->is_null(2)) ssl_options.set_cert(row->get_string(2));
     if (!row->is_null(3)) ssl_options.set_key(row->get_string(3));
