@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2015, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -818,41 +816,27 @@ Value Python_context::execute_interactive(const std::string &code,
   orig_hook.reset();
 
   if (!py_result) {
-#if PY_VERSION_HEX >= 0x030c0000
-    py::Release exc_value{PyErr_GetRaisedException()};
-#else
-    PyObject *type, *value, *tb;
-
-    PyErr_Fetch(&type, &value, &tb);
-    PyErr_NormalizeException(&type, &value, &tb);
-
-    py::Release exc_type{type}, exc_value{value}, exc_tb{tb};
-#endif
-
+    PyObject *exc, *value, *tb;
     // check whether this is a SyntaxError: unexpected EOF while parsing
     // that would indicate that the command is not complete and needs more
     // input til it's completed
-    if (PyErr_GivenExceptionMatches(exc_value.get(), PyExc_SyntaxError) ||
-        PyErr_GivenExceptionMatches(exc_value.get(), PyExc_IndentationError)) {
+    PyErr_Fetch(&exc, &value, &tb);
+    if (PyErr_GivenExceptionMatches(exc, PyExc_SyntaxError) ||
+        PyErr_GivenExceptionMatches(exc, PyExc_IndentationError)) {
       // If there's no more input then the interpreter should not continue in
       // continued mode so any error should bubble up
       if (!flush) {
         const char *msg;
         PyObject *obj;
-        const py::Release args{PyObject_GetAttrString(exc_value.get(), "args")};
-
-        if (args && PyTuple_Check(args.get()) &&
-            PyArg_ParseTuple(args.get(), "sO", &msg, &obj)) {
+        if (PyArg_ParseTuple(value, "sO", &msg, &obj)) {
           using namespace std::literals;
 
           constexpr auto unexpected_character =
               "unexpected character after line continuation character"sv;
           constexpr auto eof_while_scanning =
               "EOF while scanning triple-quoted string literal"sv;
-          // unterminated triple-quoted string literal, or
-          // unterminated triple-quoted f-string literal
           constexpr auto unterminated_triple_quoted =
-              "unterminated triple-quoted "sv;
+              "unterminated triple-quoted string literal"sv;
           // "'%c' was never closed"
           constexpr auto was_never_closed = "was never closed"sv;
           constexpr auto unexpected_eof = "unexpected EOF while parsing"sv;
@@ -890,13 +874,7 @@ Value Python_context::execute_interactive(const std::string &code,
         }
       }
     }
-
-#if PY_VERSION_HEX >= 0x030c0000
-    PyErr_SetRaisedException(exc_value.release());
-#else
-    PyErr_Restore(exc_type.release(), exc_value.release(), exc_tb.release());
-#endif
-
+    PyErr_Restore(exc, value, tb);
     if (r_state != Input_state::Ok)
       PyErr_Clear();
     else
@@ -925,7 +903,7 @@ void Python_context::get_members_of(
 
   if (!members || !PySequence_Check(members.get())) return;
 
-  for (int i = 0, c = PySequence_Size(members.get()); i < c; i++) {
+  for (Py_ssize_t i = 0, c = PySequence_Size(members.get()); i < c; i++) {
     py::Release m{PySequence_ITEM(members.get(), i)};
     std::string s;
 
@@ -995,16 +973,16 @@ void Python_context::set_python_error(const shcore::Exception &exc,
                                       const std::string &location) {
   std::string error_message;
 
-  std::string type = exc.error()->get_string("type", "");
-  std::string message = exc.error()->get_string("message", "");
   int64_t code = exc.error()->get_int("code", -1);
-  std::string error_location = exc.error()->get_string("location", "");
-
   if (code > 0) {
     set_shell_error(exc);
     return;
   }
 
+  auto type = exc.error()->get_string("type", "");
+  auto message = exc.error()->get_string("message", "");
+  auto error_location = exc.error()->get_string("location", "");
+
   if (error_location.empty()) error_location = location;
 
   PyObject *exctype = PyExc_RuntimeError;
@@ -1055,6 +1033,29 @@ void Python_context::set_python_error(PyObject *obj,
   PyErr_SetString(obj, location.c_str());
 }
 
+void Python_context::set_python_error(const std::string &module,
+                                      const std::string &exception,
+                                      const std::string &location) {
+  py::Release py_module{PyImport_ImportModule(module.c_str())};
+  if (!py_module) {
+    PyErr_Clear();
+    throw std::runtime_error(shcore::str_format(
+        "Could not import Python '%s' module", module.c_str()));
+  }
+
+  PyObject *py_module_dict = PyModule_GetDict(py_module.get());
+
+  PyObject *except_item =
+      PyDict_GetItemString(py_module_dict, exception.c_str());
+  if (!except_item) {
+    throw std::runtime_error(
+        shcore::str_format("Could not find type '%s' in '%s' module",
+                           exception.c_str(), module.c_str()));
+  }
+
+  set_python_error(except_item, location);
+}
+
 bool Python_context::pystring_to_string(PyObject *strobject,
                                         std::string *result, bool convert) {
   if (PyUnicode_Check(strobject)) {
@@ -1190,9 +1191,19 @@ PyObject *Python_context::shell_stdout(PyObject *self, PyObject *args) {
 }
 
 PyObject *Python_context::shell_stdout_isatty(PyObject *, PyObject *) {
-  PyObject *r = Py_False;
-  Py_INCREF(r);
-  return r;
+  Py_INCREF(Py_False);
+  return Py_False;
+}
+
+PyObject *Python_context::shell_stdout_fileno(PyObject *, PyObject *) {
+  try {
+    Python_context::set_python_error("io", "UnsupportedOperation",
+                                     "Method not supported.");
+  } catch (...) {
+    set_python_error(PyExc_IOError, "Method not supported.");
+  }
+
+  return nullptr;
 }
 
 PyObject *Python_context::shell_stderr(PyObject *self, PyObject *args) {
@@ -1200,9 +1211,19 @@ PyObject *Python_context::shell_stderr(PyObject *self, PyObject *args) {
 }
 
 PyObject *Python_context::shell_stderr_isatty(PyObject *, PyObject *) {
-  PyObject *r = Py_False;
-  Py_INCREF(r);
-  return r;
+  Py_INCREF(Py_False);
+  return Py_False;
+}
+
+PyObject *Python_context::shell_stderr_fileno(PyObject *, PyObject *) {
+  try {
+    Python_context::set_python_error("io", "UnsupportedOperation",
+                                     "Method not supported.");
+  } catch (...) {
+    set_python_error(PyExc_IOError, "Method not supported.");
+  }
+
+  return nullptr;
 }
 
 PyObject *Python_context::shell_flush_stderr(PyObject *, PyObject *) {
@@ -1274,18 +1295,15 @@ PyObject *Python_context::shell_stdin_readline(PyObject *, PyObject *) {
 }
 
 PyObject *Python_context::shell_stdin_isatty(PyObject *, PyObject *) {
-  PyObject *r = Py_False;
-  Py_INCREF(r);
-  return r;
+  Py_INCREF(Py_False);
+  return Py_False;
 }
 
 PyObject *Python_context::shell_interactive_eval_hook(PyObject *,
                                                       PyObject *args) {
-  Python_context *ctx;
-  std::string text;
-
   shcore::Scoped_naming_style ns(shcore::NamingStyle::LowerCaseUnderscores);
 
+  Python_context *ctx;
   if (!(ctx = Python_context::get_and_check())) return nullptr;
 
   if (PyTuple_Size(args) == 1) {
@@ -1308,6 +1326,7 @@ PyMethodDef Python_context::ShellStdErrMethods[] = {
      "Write an error string in the SHELL shell."},
     {"flush", &Python_context::shell_flush_stderr, METH_NOARGS, ""},
     {"isatty", &Python_context::shell_stderr_isatty, METH_NOARGS, ""},
+    {"fileno", &Python_context::shell_stderr_fileno, METH_NOARGS, ""},
     {NULL, NULL, 0, NULL} /* Sentinel */
 };
 
@@ -1316,6 +1335,7 @@ PyMethodDef Python_context::ShellStdOutMethods[] = {
      "Write a string in the SHELL shell."},
     {"flush", &Python_context::shell_flush, METH_NOARGS, ""},
     {"isatty", &Python_context::shell_stdout_isatty, METH_NOARGS, ""},
+    {"fileno", &Python_context::shell_stdout_fileno, METH_NOARGS, ""},
     {NULL, NULL, 0, NULL} /* Sentinel */
 };
 
@@ -1333,11 +1353,9 @@ PyMethodDef Python_context::ShellPythonSupportMethods[] = {
      METH_VARARGS,
      "Custom displayhook to capture interactive expr evaluation results."},
     {"raw_input", &Python_context::shell_raw_input, METH_VARARGS,
-     "raw_input([prompt]) -> string\n"
-     "\n"
-     "Read a string from standard input.  The trailing newline is stripped.\n"
-     "If the user hits EOF (Unix: Ctl-D, Windows: Ctl-Z+Return), raise "
-     "EOFError.\n"},
+     "raw_input([prompt]) -> string\n\nRead a string from standard input.  The "
+     "trailing newline is stripped.\nIf the user hits EOF (Unix: Ctl-D, "
+     "Windows: Ctl-Z+Return), raise EOFError.\n"},
     {NULL, NULL, 0, NULL} /* Sentinel */
 };
 
@@ -1732,46 +1750,40 @@ namespace {
 bool get_code_and_msg(int *out_code, std::string *out_msg) {
   bool ret = false;
 
-#if PY_VERSION_HEX >= 0x030c0000
-  py::Release exc_value{PyErr_GetRaisedException()};
-#else
-  PyObject *type, *value, *tb;
-
-  PyErr_Fetch(&type, &value, &tb);
-  PyErr_NormalizeException(&type, &value, &tb);
-
-  py::Release exc_type{type}, exc_value{value}, exc_tb{tb};
-#endif
+  PyObject *exc = nullptr;
+  PyObject *value = nullptr;
+  PyObject *tb = nullptr;
 
+  PyErr_Fetch(&exc, &value, &tb);
   {
-    py::Release args{PyObject_GetAttrString(exc_value.get(), "args")};
+    PyErr_NormalizeException(&exc, &value, &tb);
 
-    if (args && PyTuple_Check(args.get()) &&
-        PyTuple_GET_SIZE(args.get()) == 2) {
+    PyObject *args = PyObject_GetAttrString(value, "args");
+    if (args && PyTuple_Check(args) && PyTuple_GET_SIZE(args) == 2) {
       const char *msg;
 
-      if (PyTuple_GetItem(args.get(), 0) == Py_None) {
+      if (PyTuple_GetItem(args, 0) == Py_None) {
         PyObject *dummy;
         *out_code = 0;
-        if (PyArg_ParseTuple(args.get(), "Os", &dummy, &msg) && msg) {
+        if (PyArg_ParseTuple(args, "Os", &dummy, &msg)) {
           ret = true;
           *out_msg = msg;
         }
       } else {
-        if (PyArg_ParseTuple(args.get(), "is", out_code, &msg) && msg) {
+        if (PyArg_ParseTuple(args, "is", out_code, &msg) && msg) {
           ret = true;
-          *out_msg = msg;
+          *out_msg = std::string(msg);
         }
       }
     }
   }
 
-  if (!ret) {
-#if PY_VERSION_HEX >= 0x030c0000
-    PyErr_SetRaisedException(exc_value.release());
-#else
-    PyErr_Restore(exc_type.release(), exc_value.release(), exc_tb.release());
-#endif
+  if (ret) {
+    Py_XDECREF(exc);
+    Py_XDECREF(value);
+    Py_XDECREF(tb);
+  } else {
+    PyErr_Restore(exc, value, tb);
   }
 
   return ret;
@@ -1804,7 +1816,15 @@ void Python_context::throw_if_mysqlsh_error() {
   }
 }
 
-void Python_context::clear_exception() { PyErr_Clear(); }
+void Python_context::clear_exception() {
+  PyObject *exc, *value, *tb;
+
+  PyErr_Fetch(&exc, &value, &tb);
+
+  Py_XDECREF(exc);
+  Py_XDECREF(value);
+  Py_XDECREF(tb);
+}
 
 std::string Python_context::fetch_and_clear_exception() {
   if (!PyErr_Occurred()) return {};
@@ -1812,61 +1832,53 @@ std::string Python_context::fetch_and_clear_exception() {
   std::string exception;
   shcore::Scoped_naming_style ns(shcore::NamingStyle::LowerCaseUnderscores);
 
-#if PY_VERSION_HEX >= 0x030c0000
-  py::Release exc_value{PyErr_GetRaisedException()};
-  py::Release exc_tb{PyException_GetTraceback(exc_value.get())};
-#else
-  PyObject *type, *value, *tb;
+  PyObject *exc = nullptr;
+  PyObject *value = nullptr;
+  PyObject *tb = nullptr;
 
-  PyErr_Fetch(&type, &value, &tb);
-  PyErr_NormalizeException(&type, &value, &tb);
-
-  py::Release exc_type{type}, exc_value{value}, exc_tb{tb};
-#endif
+  PyErr_Fetch(&exc, &value, &tb);
+  PyErr_NormalizeException(&exc, &value, &tb);
 
   {
-    py::Release str{PyObject_Str(exc_value.get())};
+    PyObject *str = PyObject_Str(value);
     pystring_to_string(str, &exception);
+    Py_XDECREF(str);
   }
 
-  if (!exc_tb) {
-    return exception;
-  }
+  if (nullptr != tb) {
+    PyObject *traceback_module = PyImport_ImportModule("traceback");
 
-#if PY_VERSION_HEX >= 0x030c0000
-  // docs for traceback.print_exception()/format_exception() say:
-  // Since Python 3.10, instead of passing value and tb, an exception object can
-  // be passed as the first argument.
-  // in our case, the first argument is exc_type
-  py::Release exc_type = std::move(exc_value);
-  exc_tb.reset();
-#endif
+    if (nullptr != traceback_module) {
+      PyObject *format_exception =
+          PyObject_GetAttrString(traceback_module, "format_exception");
 
-  py::Release traceback_module{PyImport_ImportModule("traceback")};
+      if (nullptr != format_exception && PyCallable_Check(format_exception)) {
+        PyObject *backtrace = PyObject_CallFunctionObjArgs(
+            format_exception, exc, value, tb, nullptr);
 
-  if (!traceback_module) {
-    return exception;
-  }
+        if (nullptr != backtrace && PyList_Check(backtrace)) {
+          exception = "\n";
 
-  py::Release format_exception{
-      PyObject_GetAttrString(traceback_module.get(), "format_exception")};
+          for (Py_ssize_t c = PyList_Size(backtrace), i = 0; i < c; ++i) {
+            std::string item;
+            pystring_to_string(PyList_GetItem(backtrace, i), &item);
+            exception += item;
+          }
+        }
 
-  if (format_exception && PyCallable_Check(format_exception.get())) {
-    py::Release backtrace{
-        PyObject_CallFunctionObjArgs(format_exception.get(), exc_type.get(),
-                                     exc_value.get(), exc_tb.get(), nullptr)};
-
-    if (backtrace && PyList_Check(backtrace.get())) {
-      exception = "\n";
-
-      for (Py_ssize_t c = PyList_Size(backtrace.get()), i = 0; i < c; ++i) {
-        std::string item;
-        pystring_to_string(PyList_GetItem(backtrace.get(), i), &item);
-        exception += item;
+        Py_XDECREF(backtrace);
       }
+
+      Py_XDECREF(format_exception);
     }
+
+    Py_XDECREF(traceback_module);
   }
 
+  Py_XDECREF(exc);
+  Py_XDECREF(value);
+  Py_XDECREF(tb);
+
   return exception;
 }
 
