@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2015, 2025, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -72,10 +70,8 @@ using Reverse_iterator = Iterator_base<Map_reverse_iterator>;
 ////////////////////////////////////////////////////////////////////////////////
 
 struct View {
-  // clang-format off
-  PyObject_HEAD
+  _PyDictViewObject base;
   py::Store o;
-  // clang-format on
 };
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -217,12 +213,13 @@ PyObject *set_default(dict::Object *self, PyObject *args);
 PyObject *update(dict::Object *self, PyObject *args, PyObject *kwds);
 PyObject *values(dict::Object *self);
 
-#ifdef __GNUC__
-// -Wcast-function-type needs to be suppressed here, because we're casting
-// functions with different number of parameters to PyCFunction
+#if __GNUC__ > 7 && !defined(__clang__)
+// -Wcast-function-type was added in GCC 8.0, needs to be suppressed here,
+// because we're casting functions with different number of parameters to
+// PyCFunction
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 PyMethodDef methods[] = {
     {"__contains__", (PyCFunction)has_key, METH_O | METH_COEXIST, contains_doc},
@@ -247,9 +244,9 @@ PyMethodDef methods[] = {
     {nullptr, nullptr, 0, nullptr},
 };
 
-#ifdef __GNUC__
+#if __GNUC__ > 7 && !defined(__clang__)
 #pragma GCC diagnostic pop
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 ////////////////////////////////////////////////////////////////////////////////
 // dict::Type
@@ -377,14 +374,6 @@ PyTypeObject Type = {
     0  // tp_print
 #endif
 #endif
-#if PY_VERSION_HEX >= 0x030C0000
-    ,
-    0  // tp_watched
-#endif
-#if PY_VERSION_HEX >= 0x030D0000
-    ,
-    0  // tp_versions_used
-#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -467,12 +456,13 @@ PyObject *length(dict::Iterator_base<It> *self);
 template <typename It>
 PyObject *reduce(dict::Iterator_base<It> *self);
 
-#ifdef __GNUC__
-// -Wcast-function-type needs to be suppressed here, because we're casting
-// functions with different number of parameters to PyCFunction
+#if __GNUC__ > 7 && !defined(__clang__)
+// -Wcast-function-type was added in GCC 8.0, needs to be suppressed here,
+// because we're casting functions with different number of parameters to
+// PyCFunction
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 template <typename It>
 PyMethodDef methods[] = {
@@ -481,9 +471,9 @@ PyMethodDef methods[] = {
     {nullptr, nullptr, 0, nullptr},
 };
 
-#ifdef __GNUC__
+#if __GNUC__ > 7 && !defined(__clang__)
 #pragma GCC diagnostic pop
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 }  // namespace iter
 
@@ -735,12 +725,13 @@ PyDoc_STRVAR(reversed_keys_doc,
 PyObject *iterator(dict::View *self);
 PyObject *reversed(dict::View *self, PyObject *);
 
-#ifdef __GNUC__
-// -Wcast-function-type needs to be suppressed here, because we're casting
-// functions with different number of parameters to PyCFunction
+#if __GNUC__ > 7 && !defined(__clang__)
+// -Wcast-function-type was added in GCC 8.0, needs to be suppressed here,
+// because we're casting functions with different number of parameters to
+// PyCFunction
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 PyMethodDef methods[] = {
     {"isdisjoint", (PyCFunction)isdisjoint, METH_O, isdisjoint_doc},
@@ -748,9 +739,9 @@ PyMethodDef methods[] = {
     {nullptr, nullptr, 0, nullptr},
 };
 
-#ifdef __GNUC__
+#if __GNUC__ > 7 && !defined(__clang__)
 #pragma GCC diagnostic pop
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 }  // namespace view::keys
 
@@ -865,14 +856,6 @@ PyTypeObject Type = {
     0  // tp_print
 #endif
 #endif
-#if PY_VERSION_HEX >= 0x030C0000
-    ,
-    0  // tp_watched
-#endif
-#if PY_VERSION_HEX >= 0x030D0000
-    ,
-    0  // tp_versions_used
-#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -932,21 +915,22 @@ PyDoc_STRVAR(reversed_values_doc,
 PyObject *iterator(dict::View *self);
 PyObject *reversed(dict::View *self, PyObject *);
 
-#ifdef __GNUC__
-// -Wcast-function-type needs to be suppressed here, because we're casting
-// functions with different number of parameters to PyCFunction
+#if __GNUC__ > 7 && !defined(__clang__)
+// -Wcast-function-type was added in GCC 8.0, needs to be suppressed here,
+// because we're casting functions with different number of parameters to
+// PyCFunction
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 PyMethodDef methods[] = {
     {"__reversed__", (PyCFunction)reversed, METH_NOARGS, reversed_values_doc},
     {nullptr, nullptr, 0, nullptr},
 };
 
-#ifdef __GNUC__
+#if __GNUC__ > 7 && !defined(__clang__)
 #pragma GCC diagnostic pop
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 }  // namespace view::values
 
@@ -1061,14 +1045,6 @@ PyTypeObject Type = {
     0  // tp_print
 #endif
 #endif
-#if PY_VERSION_HEX >= 0x030C0000
-    ,
-    0  // tp_watched
-#endif
-#if PY_VERSION_HEX >= 0x030D0000
-    ,
-    0  // tp_versions_used
-#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -1130,12 +1106,13 @@ PyDoc_STRVAR(reversed_items_doc,
 PyObject *iterator(dict::View *self);
 PyObject *reversed(dict::View *self, PyObject *);
 
-#ifdef __GNUC__
-// -Wcast-function-type needs to be suppressed here, because we're casting
-// functions with different number of parameters to PyCFunction
+#if __GNUC__ > 7 && !defined(__clang__)
+// -Wcast-function-type was added in GCC 8.0, needs to be suppressed here,
+// because we're casting functions with different number of parameters to
+// PyCFunction
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 PyMethodDef methods[] = {
     {"isdisjoint", (PyCFunction)isdisjoint, METH_O, isdisjoint_doc},
@@ -1143,9 +1120,9 @@ PyMethodDef methods[] = {
     {nullptr, nullptr, 0, nullptr},
 };
 
-#ifdef __GNUC__
+#if __GNUC__ > 7 && !defined(__clang__)
 #pragma GCC diagnostic pop
-#endif  // __GNUC__
+#endif  // __GNUC__ > 7 && !defined(__clang__)
 
 }  // namespace view::items
 
@@ -1260,14 +1237,6 @@ PyTypeObject Type = {
     0  // tp_print
 #endif
 #endif
-#if PY_VERSION_HEX >= 0x030C0000
-    ,
-    0  // tp_watched
-#endif
-#if PY_VERSION_HEX >= 0x030D0000
-    ,
-    0  // tp_versions_used
-#endif
 };
 
 #if PY_VERSION_HEX >= 0x03080000 && PY_VERSION_HEX < 0x03090000
@@ -1682,6 +1651,7 @@ PyObject *size_of(dict::Object *self) {
  */
 PyObject *clear(dict::Object *self) {
   self->dict->get()->clear();
+  self->base.ma_used = 0;
   Py_RETURN_NONE;
 }
 
@@ -1743,6 +1713,11 @@ PyObject *from_keys(PyTypeObject *type, PyObject *args) {
     }
   }
 
+  if (is_shell_dict) {
+    const auto shdict = reinterpret_cast<dict::Object *>(dict.get());
+    shdict->base.ma_used = length(shdict);
+  }
+
   return dict.release();
 }
 
@@ -1830,6 +1805,7 @@ PyObject *pop(dict::Object *self, PyObject *args) {
         auto ret = py::convert(result->second);
 
         self->dict->get()->erase(result);
+        --self->base.ma_used;
 
         return ret.release();
       }
@@ -1871,6 +1847,7 @@ PyObject *pop_item(dict::Object *self) {
   }
 
   self->dict->get()->erase(item);
+  --self->base.ma_used;
 
   return result.release();
 }
@@ -1897,6 +1874,7 @@ PyObject *set_default(dict::Object *self, PyObject *args) {
         return py::convert(result->second).release();
       } else {
         self->dict->get()->set(key_to_find, py::convert(default_value));
+        ++self->base.ma_used;
 
         Py_INCREF(default_value);
         return default_value;
@@ -1924,6 +1902,7 @@ PyObject *set_default(dict::Object *self, PyObject *args) {
 PyObject *update(dict::Object *self, PyObject *args, PyObject *kwds) {
   try {
     if (update(self, args, kwds, "update")) {
+      self->base.ma_used = length(self);
       Py_RETURN_NONE;
     }
   } catch (const std::exception &exc) {
@@ -2054,6 +2033,7 @@ int init(dict::Object *self, PyObject *args, PyObject *kwds) {
 
   try {
     if (update(self, args, kwds, "Dict")) {
+      self->base.ma_used = length(self);
       return 0;
     }
   } catch (const std::exception &exc) {
@@ -2625,6 +2605,7 @@ py::Release wrap(const Dictionary_t &map) {
 
   assert(!wrapper->dict);
   wrapper->dict = new Dictionary_t(map);
+  wrapper->base.ma_used = length(wrapper);
 
   return py::Release{reinterpret_cast<PyObject *>(wrapper)};
 }
