@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2014, 2025, Oracle and/or its affiliates.
+ * Copyright (c) 2014, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -32,14 +30,11 @@
 #include <unistd.h>
 #endif
 #include "mysqlshdk/include/shellcore/base_shell.h"
-#ifdef HAVE_JIT_EXECUTOR
-#include "mysqlshdk/include/shellcore/shell_polyglot.h"
-#include "mysqlshdk/scripting/polyglot/utils/polyglot_utils.h"
-#endif
 #include "mysqlshdk/include/shellcore/utils_help.h"
 #include "scripting/lang_base.h"
 #include "scripting/object_registry.h"
 #include "shellcore/base_session.h"
+#include "shellcore/shell_jscript.h"
 #include "shellcore/shell_python.h"
 #include "shellcore/shell_sql.h"
 #include "utils/base_tokenizer.h"
@@ -178,14 +173,8 @@ bool Shell_core::switch_mode(Mode mode) {
   m_help.set_mode(mode);
 
   if (_mode != mode) {
-    Mode backup_mode = _mode;
     _mode = mode;
-    try {
-      init_mode(_mode);
-    } catch (...) {
-      _mode = backup_mode;
-      throw;
-    }
+    init_mode(_mode);
     return true;
   }
   return false;
@@ -212,19 +201,16 @@ void Shell_core::init_mode(Mode mode) {
 void Shell_core::init_sql() { _langs[Mode::SQL] = new Shell_sql(this); }
 
 void Shell_core::init_js() {
-#ifdef HAVE_JS
+#ifdef HAVE_V8
+  Shell_javascript *js;
+  _langs[Mode::JavaScript] = js = new Shell_javascript(this);
 
-  if (_langs.find(Mode::JavaScript) == _langs.end()) {
-    Shell_polyglot *js;
-    _langs[Mode::JavaScript] = js =
-        new Shell_polyglot(this, polyglot::Language::JAVASCRIPT);
-
-    for (const auto &global : _globals) {
-      if (global.second.first.is_set(Mode::JavaScript))
-        js->set_global(global.first, global.second.second);
-    }
+  for (std::map<std::string, std::pair<Mode_mask, Value>>::const_iterator iter =
+           _globals.begin();
+       iter != _globals.end(); ++iter) {
+    if (iter->second.first.is_set(Mode::JavaScript))
+      js->set_global(iter->first, iter->second.second);
   }
-
 #endif
 }
 
@@ -291,16 +277,16 @@ std::vector<std::string> Shell_core::get_all_globals() {
 void Shell_core::clear_input() { _langs[interactive_mode()]->clear_input(); }
 
 bool Shell_core::handle_shell_command(const std::string &line) {
-  if (!_langs[_mode]->command_handler()->process(line)) {
-    return m_command_handler.process(line);
+  if (!_langs[_mode]->command_handler()->process(line, _mode)) {
+    return m_command_handler.process(line, _mode);
   }
   return false;
 }
 
 size_t Shell_core::handle_inline_shell_command(const std::string &line) {
-  size_t skip = _langs[_mode]->command_handler()->process_inline(line);
+  size_t skip = _langs[_mode]->command_handler()->process_inline(line, _mode);
   if (skip == 0) {
-    skip = m_command_handler.process_inline(line);
+    skip = m_command_handler.process_inline(line, _mode);
   }
   return skip;
 }
@@ -347,14 +333,11 @@ bool Shell_core::load_plugin(Mode mode, const Plugin_definition &plugin) {
 
 //------------------ COMMAND HANDLER FUNCTIONS ------------------//
 std::vector<std::string> Shell_command_handler::split_command_line(
-    const std::string &command_line) {
+    const std::string &command_line, const std::string &allowed_quotes) {
   shcore::BaseTokenizer _tokenizer;
 
-  static constexpr auto k_quote = "\"";
-
-  _tokenizer.set_complex_token("escaped-quote",
-                               std::vector<std::string>{"\\", k_quote});
-  _tokenizer.set_complex_token("quote", k_quote);
+  _tokenizer.set_complex_token("escaped-quote", {"\\", allowed_quotes});
+  _tokenizer.set_complex_token("quote", allowed_quotes);
   _tokenizer.set_complex_token_callback(
       "space",
       [](const std::string &input, size_t &index, std::string &text) -> bool {
@@ -393,11 +376,17 @@ std::vector<std::string> Shell_command_handler::split_command_line(
       if (quote.length() == 1) {
         // only one quote character, beginning of a quoted parameter
         param = quote;
+        auto quote_char = quote[0];
 
-        // read till the end of string or till next token is a quote
-        while (_tokenizer.tokens_available() &&
-               !_tokenizer.cur_token_type_is("quote")) {
-          param += _tokenizer.consume_any_token().get_text();
+        // read till the end of string or till next token is a closing quote
+        bool closed_quote = false;
+        while (_tokenizer.tokens_available() && !closed_quote) {
+          if (!_tokenizer.cur_token_type_is("quote") ||
+              _tokenizer.peek_token().get_text() != quote) {
+            param += _tokenizer.consume_any_token().get_text();
+          } else {
+            closed_quote = true;
+          }
         }
 
         if (!_tokenizer.tokens_available()) {
@@ -415,7 +404,7 @@ std::vector<std::string> Shell_command_handler::split_command_line(
               // string has finished or quoted parameter was followed by space
               // -> end of quoted parameter
               param += quote;
-              ret_val.emplace_back(unquote_string(param, k_quote[0]));
+              ret_val.emplace_back(unquote_string(param, quote_char));
             } else {
               // quote was not followed by a space, two parameters were not
               // properly separated
@@ -457,7 +446,7 @@ std::vector<std::string> Shell_command_handler::split_command_line(
         } else if (_tokenizer.cur_token_type_is("escaped-quote")) {
           // escaped quotes need to have the '\' character removed
           const auto quotes = _tokenizer.consume_any_token().get_text();
-          param += std::string(quotes.length() / 2, k_quote[0]);
+          param += quotes.substr(1);
         } else {
           param += _tokenizer.consume_any_token().get_text();
         }
@@ -470,7 +459,8 @@ std::vector<std::string> Shell_command_handler::split_command_line(
   return ret_val;
 }
 
-bool Shell_command_handler::process(const std::string &command_line) {
+bool Shell_command_handler::process(const std::string &command_line,
+                                    IShell_core::Mode mode) {
   bool ret_val = false;
   std::vector<std::string> tokens;
 
@@ -491,10 +481,12 @@ bool Shell_command_handler::process(const std::string &command_line) {
 
     // Srearch on the registered command list and processes it if it exists
     Command_registry::iterator item = _command_dict.find(command);
-    if (item != _command_dict.end() && item->second->function) {
+    if (item != _command_dict.end() && item->second->mode.is_set(mode) &&
+        item->second->function) {
       // Parses the command
       if (item->second->auto_parse_arguments)
-        tokens = split_command_line(command_line);
+        tokens =
+            split_command_line(command_line, item->second->argument_quotes);
       else
         tokens.resize(1);
 
@@ -508,7 +500,8 @@ bool Shell_command_handler::process(const std::string &command_line) {
   return ret_val;
 }
 
-size_t Shell_command_handler::process_inline(const std::string &command) {
+size_t Shell_command_handler::process_inline(const std::string &command,
+                                             IShell_core::Mode mode) {
   auto cmd = _command_dict.find(command.substr(0, 2));
   if (cmd != _command_dict.end()) {
     // currently there are no inline \X commands that accept params, but when
@@ -516,22 +509,21 @@ size_t Shell_command_handler::process_inline(const std::string &command) {
     // of consumed chars from the original input
     bool has_params = false;
     if (!has_params) {
-      if (process(command.substr(0, 2))) return 2;
+      if (process(command.substr(0, 2), mode)) return 2;
     } else {
-      if (process(command.substr(0, 2) + " " + command.substr(3)))
+      if (process(command.substr(0, 2) + " " + command.substr(3), mode))
         return command.size();
     }
   }
   return 0;
 }
 
-void Shell_command_handler::add_command(const std::string &triggers,
-                                        const std::string &help_tag,
-                                        Shell_command_function function,
-                                        bool case_sensitive_help,
-                                        Mode_mask mode,
-                                        bool auto_parse_arguments) {
-  Shell_command command = {triggers, function, auto_parse_arguments};
+void Shell_command_handler::add_command(
+    const std::string &triggers, const std::string &help_tag,
+    Shell_command_function function, bool case_sensitive_help, Mode_mask mode,
+    bool auto_parse_arguments, const std::string &argument_quotes) {
+  Shell_command command = {triggers, function, auto_parse_arguments, mode,
+                           argument_quotes};
   _commands.push_back(command);
 
   std::vector<std::string> tokens;
@@ -579,15 +571,17 @@ void Shell_command_handler::add_command(const std::string &triggers,
 }
 
 std::vector<std::string> Shell_command_handler::get_command_names_matching(
-    const std::string &prefix) const {
+    const std::string &prefix, IShell_core::Mode mode) const {
   std::vector<std::string> names;
 
   for (auto cmd : _commands) {
-    std::vector<std::string> tokens;
-    tokens = split_string(cmd.triggers, "|", true);
-    if (!tokens.empty()) {
-      if (shcore::str_beginswith(tokens.front(), prefix)) {
-        names.push_back(tokens.front());
+    if (cmd.mode.is_set(mode)) {
+      std::vector<std::string> tokens;
+      tokens = split_string(cmd.triggers, "|", true);
+      if (!tokens.empty()) {
+        if (shcore::str_beginswith(tokens.front(), prefix)) {
+          names.push_back(tokens.front());
+        }
       }
     }
   }
