@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2017, 2025, Oracle and/or its affiliates.
+ * Copyright (c) 2017, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -540,7 +538,7 @@ TEST_F(Completer_frontend, builtin_others) {
                       "\\show",    "\\source",     "\\sql",        "\\status",
                       "\\system",  "\\use",        "\\warnings",   "\\watch"});
 
-#ifndef HAVE_JS
+#ifndef HAVE_V8
   expect.erase(std::find(expect.begin(), expect.end(), "\\js"));
 #endif
 
@@ -623,7 +621,7 @@ TEST_F(Completer_frontend, sql_table_o3) {
   EXPECT_AFTER_TAB("describe `pl", "describe `plugin`");
 }
 
-#ifdef HAVE_JS
+#ifdef HAVE_V8
 TEST_F(Completer_frontend, js_keywords) {
   execute("\\js");
 
@@ -1156,6 +1154,7 @@ TEST_F(Completer_frontend, js_devapi_members_classic) {
       {"help", ""},
       {"close", ""},
       {"runSql", "('select 1')"},
+      {"setQueryAttributes", "({})"},
       {"query", "('select 1')"},
       {"_getSocketFd", ""}};
   CHECK_OBJECT_MEMBER_COMPLETIONS("session", session_calls);
@@ -2422,9 +2421,4 @@ TEST_F(Completer_frontend, bug_34365581) {
   execute("DROP SCHEMA ogÓrek;");
 }
 
-TEST_F(Completer_frontend, bug_37528585) {
-  execute("\\js");
-  EXPECT_NO_THROW(complete("shell.unexisting."));
-}
-
 }  // namespace mysqlsh
