@@ -1,18 +1,16 @@
 /*
- * Copyright (c) 2015, 2024, Oracle and/or its affiliates.
+ * Copyright (c) 2015, 2023, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is designed to work with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms,
- * as designated in a particular file or component or in included license
+ * This program is also distributed with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms, as
+ * designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have either included with
- * the program or referenced in the documentation.
- *
+ * separately licensed software that they have included with MySQL.
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -38,6 +36,17 @@
 #include "my_config.h"
 
 namespace shcore {
+TEST(utils_general, compare_floating_point) {
+  EXPECT_TRUE(compare_floating_point(12.3, 12.3, 0.01));
+  EXPECT_TRUE(compare_floating_point(-12.3, -12.3, 0.01));
+  EXPECT_FALSE(compare_floating_point(12.3, -12.3, 0.01));
+  EXPECT_FALSE(compare_floating_point(-12.3, 12.3, 0.01));
+
+  EXPECT_TRUE(compare_floating_point(12.345, 12.346, 0.01));
+  EXPECT_TRUE(compare_floating_point(12.345, 12.346, 0.001));
+  EXPECT_FALSE(compare_floating_point(12.345, 12.346, 0.0009));
+}
+
 TEST(utils_general, split_account) {
   std::string a, b;
 
