@@ -27,11 +27,31 @@
 #include "mysqlshdk/libs/utils/utils_net.h"
 
 #include <algorithm>
+#include <cstdlib>
 #include <iterator>
 
 namespace mysqlshdk {
 namespace utils {
 
+namespace {
+template <class TCallback>
+void iterate_hosts(TCallback &&host_cb) {
+  auto hosts = std::getenv("MYSQLSH_TEST_HOSTS");
+  if (!hosts) return;
+
+  shcore::str_itersplit(
+      hosts,
+      [&host_cb](auto host) {
+        auto clear_host = shcore::str_strip_view(host);
+        if (clear_host.empty()) return true;
+
+        host_cb(std::string{clear_host});
+        return true;
+      },
+      ";");
+}
+}  // namespace
+
 TEST(utils_net, resolve_hostname_ipv4) {
   EXPECT_EQ("0.0.0.0", Net::resolve_hostname_ipv4("0.0.0.0"));
   EXPECT_EQ("0.0.0.0", Net::resolve_hostname_ipv4("000.000.000.000"));
@@ -42,7 +62,8 @@ TEST(utils_net, resolve_hostname_ipv4) {
   EXPECT_EQ("127.0.0.1", Net::resolve_hostname_ipv4("0x7F.0.0.1"));
 
   EXPECT_NO_THROW(Net::resolve_hostname_ipv4("localhost"));
-  EXPECT_NO_THROW(Net::resolve_hostname_ipv4("google.pl"));
+  iterate_hosts(
+      [](auto host) { EXPECT_NO_THROW(Net::resolve_hostname_ipv4(host)); });
 
 #ifdef WIN32
   // On Windows, using an empty string will resolve to any registered
@@ -70,18 +91,17 @@ TEST(utils_net, resolve_hostname_ipv4_all) {
     }
   }
 
-  {
+  iterate_hosts([](auto host) {
     try {
-      std::vector<std::string> addrs =
-          Net::resolve_hostname_ipv4_all("oracle.com");
+      std::vector<std::string> addrs = Net::resolve_hostname_ipv4_all(host);
       for (const auto &a : addrs) {
-        std::cout << "oracle.com: " << a << "\n";
+        std::cout << host << ": " << a << "\n";
       }
     } catch (const std::runtime_error &err) {
-      std::cout << "Unable to resolve hostname oracle.com as IPv4 address: "
-                << err.what() << std::endl;
+      std::cout << "Unable to resolve hostname '" << host
+                << "' as IPv4 address: " << err.what() << std::endl;
     }
-  }
+  });
 
   {
     try {
@@ -112,18 +132,17 @@ TEST(utils_net, resolve_hostname_ipv6_all) {
     }
   }
 
-  {
+  iterate_hosts([](auto host) {
     try {
-      std::vector<std::string> addrs =
-          Net::resolve_hostname_ipv6_all("google.com");
+      std::vector<std::string> addrs = Net::resolve_hostname_ipv6_all(host);
       for (const auto &a : addrs) {
-        std::cout << "google.com: " << a << "\n";
+        std::cout << host << ": " << a << "\n";
       }
     } catch (const std::runtime_error &err) {
-      std::cout << "Unable to resolve hostname google.com as IPv6 address: "
-                << err.what() << std::endl;
+      std::cout << "Unable to resolve hostname ´" << host
+                << "' as IPv6 address: " << err.what() << std::endl;
     }
-  }
+  });
 
   {
     try {
@@ -152,17 +171,17 @@ TEST(utils_net, get_hostname_ips) {
     }
   }
 
-  {
+  iterate_hosts([](auto host) {
     try {
-      std::vector<std::string> addrs = Net::get_hostname_ips("oracle.com");
+      std::vector<std::string> addrs = Net::get_hostname_ips(host);
       for (const auto &a : addrs) {
-        std::cout << "google.com: " << a << "\n";
+        std::cout << host << ": " << a << "\n ";
       }
     } catch (const std::runtime_error &err) {
-      std::cout << "Unable to resolve hostname oracle.com: " << err.what()
+      std::cout << "Unable to resolve hostname '" << host << "': " << err.what()
                 << std::endl;
     }
-  }
+  });
 
   {
     try {
@@ -188,7 +207,6 @@ TEST(utils_net, is_ipv4) {
 
   EXPECT_FALSE(Net::is_ipv4(""));
   EXPECT_FALSE(Net::is_ipv4("localhost"));
-  EXPECT_FALSE(Net::is_ipv4("google.pl"));
   EXPECT_FALSE(Net::is_ipv4("unknown_host"));
   EXPECT_FALSE(Net::is_ipv4("::8.8.8.8"));
   EXPECT_FALSE(Net::is_ipv4("255.255.255.256"));
@@ -219,7 +237,6 @@ TEST(utils_net, is_ipv6) {
 
   EXPECT_FALSE(Net::is_ipv6(""));
   EXPECT_FALSE(Net::is_ipv6("localhost"));
-  EXPECT_FALSE(Net::is_ipv6("google.pl"));
   EXPECT_FALSE(Net::is_ipv6("unknown_host"));
   EXPECT_FALSE(Net::is_ipv6("127.0.0.1"));
   EXPECT_FALSE(Net::is_ipv6("FEDC:BA98:7654:3210:FEDC:BA98:7654:3210:"));
@@ -238,7 +255,6 @@ TEST(utils_net, is_loopback) {
   EXPECT_TRUE(Net::is_loopback("localhost"));
 
   EXPECT_FALSE(Net::is_loopback("192.168.1.1"));
-  EXPECT_FALSE(Net::is_loopback("127.bing.com"));
 }
 
 TEST(utils_net, is_local_address) {
@@ -249,8 +265,7 @@ TEST(utils_net, is_local_address) {
   EXPECT_TRUE(
       Net::is_local_address(Net::resolve_hostname_ipv4(Net::get_hostname())));
 
-  EXPECT_FALSE(Net::is_local_address("127.bing.com"));
-  EXPECT_FALSE(Net::is_local_address("oracle.com"));
+  iterate_hosts([](auto host) { EXPECT_FALSE(Net::is_local_address(host)); });
   EXPECT_FALSE(Net::is_local_address("bogus-host"));
   EXPECT_FALSE(Net::is_local_address("8.8.8.8"));
 }
@@ -263,21 +278,24 @@ TEST(utils_net, is_externally_addressable) {
   EXPECT_FALSE(Net::is_externally_addressable("127.0.2.1"));
   EXPECT_FALSE(Net::is_externally_addressable("127.1.2.1"));
 
-  const auto hostname = Net::get_hostname();
-  const auto self_fqdn = Net::get_fqdn(hostname);
-  const std::string domain{".oracle.com"};
+  iterate_hosts([](auto host) {
+    const auto hostname = Net::get_hostname();
+    const auto self_fqdn = Net::get_fqdn(hostname);
+    const auto domain = shcore::str_format(".%s", host.c_str());
 
-  auto contains_domain = std::search(self_fqdn.begin(), self_fqdn.end(),
-                                     domain.begin(), domain.end());
-  if (contains_domain != self_fqdn.end()) {
-    std::advance(contains_domain, domain.size());
-    if (contains_domain == self_fqdn.end()) {
-      EXPECT_TRUE(Net::is_externally_addressable(self_fqdn));
+    auto contains_domain = std::search(self_fqdn.begin(), self_fqdn.end(),
+                                       domain.begin(), domain.end());
+    if (contains_domain != self_fqdn.end()) {
+      std::advance(contains_domain, domain.size());
+      if (contains_domain == self_fqdn.end()) {
+        EXPECT_TRUE(Net::is_externally_addressable(self_fqdn));
+      }
     }
-  }
-  EXPECT_TRUE(Net::is_externally_addressable("oracle.com"));
+
+    EXPECT_TRUE(Net::is_externally_addressable(host));
+  });
+
   EXPECT_TRUE(Net::is_externally_addressable("8.8.4.4"));
-  EXPECT_TRUE(Net::is_externally_addressable("127.bing.com"));
 }
 
 TEST(utils_net, is_port_listening) {
@@ -359,6 +377,100 @@ TEST(utils_net, make_host_and_port) {
             make_host_and_port("fe80::7a7b:8aff:feb8:ed32%utun1", 3232));
 }
 
+TEST(utils_net, check_ipv4_is_in_range) {
+  // IPv4: 10.0.0.0 - 10.255.255.255 (i.e.: 10.0.0.0/8)
+  {
+    auto res = check_ipv4_is_in_range("10.0.0.0", "10.255.255.255", 8);
+    EXPECT_TRUE(res.has_value() && res.value());
+
+    res = check_ipv4_is_in_range("10.255.255.255", "10.1.2.3", 8);
+    EXPECT_TRUE(res.has_value() && res.value());
+
+    res = check_ipv4_is_in_range("11.0.0.0", "10.0.0.0", 8);
+    EXPECT_TRUE(res.has_value() && !res.value());
+
+    res = check_ipv4_is_in_range("1.1.1.1", "10.0.0.0", 8);
+    EXPECT_TRUE(res.has_value() && !res.value());
+
+    res = check_ipv4_is_in_range("-", "10.0.0.0", 8);
+    EXPECT_TRUE(!res.has_value());
+  }
+
+  // IPv4: 172.16.0.0 - 172.31.255.255 (i.e.: 172.16.0.0/12)
+  {
+    auto res = mysqlshdk::utils::check_ipv4_is_in_range("172.16.0.0",
+                                                        "172.16.0.0", 12);
+    EXPECT_TRUE(res.has_value() && res.value());
+
+    res = mysqlshdk::utils::check_ipv4_is_in_range("172.31.255.255",
+                                                   "172.31.255.255", 12);
+    EXPECT_TRUE(res.has_value() && res.value());
+
+    res = mysqlshdk::utils::check_ipv4_is_in_range("172.15.255.255",
+                                                   "172.16.0.0", 12);
+    EXPECT_TRUE(res.has_value() && !res.value());
+
+    res = mysqlshdk::utils::check_ipv4_is_in_range("172.32.0.0", "172.16.0.0",
+                                                   12);
+    EXPECT_TRUE(res.has_value() && !res.value());
+  }
+
+  // IPv4: 192.168.0.0 - 192.168.255.255 (i.e.: 192.168.0.0/16)
+  {
+    auto res = check_ipv4_is_in_range("192.168.0.0", "192.168.255.255", 16);
+    EXPECT_TRUE(res.has_value() && res.value());
+
+    res = check_ipv4_is_in_range("192.168.255.255", "192.168.0.0", 16);
+    EXPECT_TRUE(res.has_value() && res.value());
+
+    res = check_ipv4_is_in_range("10.0.0.0", "192.168.0.0", 16);
+    EXPECT_TRUE(res.has_value() && !res.value());
+
+    res = check_ipv4_is_in_range("-", "192.168.0.0", 16);
+    EXPECT_TRUE(!res.has_value());
+  }
+}
+
+TEST(utils_net, check_ipv6_is_in_range) {
+  // IPv6: fc00::/7
+  {
+    auto res = check_ipv6_is_in_range("fc00::", "fc00:ffff::", 7);
+    EXPECT_TRUE(res.has_value() && res.value());
+
+    res = check_ipv6_is_in_range("fc00:ffff::", "fc00::", 7);
+    EXPECT_TRUE(res.has_value() && res.value());
+
+    res = check_ipv6_is_in_range("fdff:ffff:ffff:ffff:ffff:ffff:ffff:ffff",
+                                 "fc00::", 7);
+    EXPECT_TRUE(res.has_value() && res.value());
+
+    res = check_ipv6_is_in_range("fd0::", "fc00::", 7);
+    EXPECT_TRUE(res.has_value() && !res.value());
+
+    res = check_ipv6_is_in_range("--", "fc00::", 7);
+    EXPECT_TRUE(!res.has_value());
+  }
+
+  // IPv6: fe80::/10
+  {
+    auto res = check_ipv6_is_in_range("fe80::", "fe80:ffff::", 10);
+    EXPECT_TRUE(res.has_value() && res.value());
+
+    res = check_ipv6_is_in_range("fe80:ffff::", "fe80::", 10);
+    EXPECT_TRUE(res.has_value() && res.value());
+
+    res = check_ipv6_is_in_range("febf:ffff:ffff:ffff:ffff:ffff:ffff:ffff",
+                                 "fe80::", 10);
+    EXPECT_TRUE(res.has_value() && res.value());
+
+    res = check_ipv6_is_in_range("fec0::", "fe80::", 10);
+    EXPECT_TRUE(res.has_value() && !res.value());
+
+    res = check_ipv6_is_in_range("--", "fe80::", 10);
+    EXPECT_TRUE(!res.has_value());
+  }
+}
+
 TEST(utils_net, split_host_and_port) {
   EXPECT_EQ("a", split_host_and_port("a:1").first);
   EXPECT_EQ(1, split_host_and_port("a:1").second);
