@@ -220,8 +220,8 @@ cluster.addInstance(__sandbox_uri3, {recoveryMethod: "incremental"});
 // FR1.3.2: `label`: an identifier for the Read Replica being added, used in the output of status() and describe().
 
 //@<> addReplicaInstance() - using different combinations of 'label'
-var label_1 = "läbel";
-var label_2 = "! la?be1";
+var label_1 = "label1";
+var label_2 = "label2";
 
 EXPECT_NO_THROWS(function() { cluster.addReplicaInstance(__sandbox_uri4, {label: label_1}); });
 testutil.waitMemberTransactions(__mysql_sandbox_port4, __mysql_sandbox_port1);
@@ -247,6 +247,24 @@ EXPECT_EQ(label_2, label);
 
 reset_read_replica(__sandbox_uri4, cluster);
 
+//@<> addReplicaInstance() - check for invalid 'label' values
+
+EXPECT_THROWS(function() { cluster.addReplicaInstance(__sandbox_uri4, {label: "läbel"}); }, "The label can only contain alphanumerics or the '_', '.', '-', ':' characters.");
+EXPECT_THROWS(function() { cluster.addReplicaInstance(__sandbox_uri4, {label: "! la?be1"}); }, "The label can only start with an alphanumeric or the '_' character.");
+EXPECT_THROWS(function() { cluster.addReplicaInstance(__sandbox_uri4, {label: "la bel"}); }, "The label can only contain alphanumerics or the '_', '.', '-', ':' characters.");
+
+//@<> addReplicaInstance() - check for duplicate 'label' values
+
+EXPECT_NO_THROWS(function() { cluster.setInstanceOption(__sandbox_uri3, "label", "foo"); });
+EXPECT_THROWS(function() { cluster.addReplicaInstance(__sandbox_uri4, {label: "foo"}); }, `Instance '${hostname}:${__mysql_sandbox_port3}' is already using label 'foo'.`);
+
+EXPECT_NO_THROWS(function() { cluster.addReplicaInstance(__sandbox_uri4, {label: "bar"}); });
+CHECK_READ_REPLICA(__sandbox_uri4, cluster, "primary", __endpoint1);
+
+EXPECT_THROWS(function() { cluster.setInstanceOption(__sandbox_uri4, "label", "foo"); }, `Instance '${hostname}:${__mysql_sandbox_port3}' is already using label 'foo'.`);
+
+reset_read_replica(__sandbox_uri4, cluster);
+
 // FR1.3.3: replicationSources: The list of sources for the Read Replica. All sources must be ONLINE Cluster members.
 // FR1.3.1.1: If set to "primary", the list is automatically managed by Group Replication and the primary member is used as source; This is the default behaviour.
 // FR1.3.1.2: If set to "secondary", the list is automatically managed by Group Replication and a secondary member is used as source.
@@ -271,9 +289,27 @@ CHECK_READ_REPLICA(__sandbox_uri4, cluster, "secondary", [__endpoint2, __endpoin
 shell.connect(__sandbox_uri4);
 EXPECT_NO_THROWS(function() { cluster = dba.getCluster(); });
 
-reset_read_replica(__sandbox_uri4, cluster);
+//@<> getCluster() while connected to a read-replica and the cluster lost quorum
+shell.connect(__sandbox_uri1);
+testutil.killSandbox(__mysql_sandbox_port2);
+testutil.killSandbox(__mysql_sandbox_port3);
+testutil.waitMemberState(__mysql_sandbox_port2, "UNREACHABLE");
+testutil.waitMemberState(__mysql_sandbox_port3, "UNREACHABLE");
+
+shell.connect(__sandbox_uri4);
+EXPECT_NO_THROWS(function() { cluster = dba.getCluster(); });
+
+// Restore quorum
+testutil.startSandbox(__mysql_sandbox_port2);
+testutil.startSandbox(__mysql_sandbox_port3);
+EXPECT_NO_THROWS(function() { cluster.forceQuorumUsingPartitionOf(__sandbox_uri1); });
+
+EXPECT_NO_THROWS(function() { cluster.rejoinInstance(__endpoint2); });
+EXPECT_NO_THROWS(function() { cluster.rejoinInstance(__endpoint3); });
 
 //@<> addReplicaInstance() - using 'replicationSources: "[__endpoint3, __endpoint1]]'
+reset_read_replica(__sandbox_uri4, cluster);
+
 EXPECT_NO_THROWS(function() { cluster.addReplicaInstance(__sandbox_uri4, {replicationSources: [__endpoint3, __endpoint1]}); });
 testutil.waitMemberTransactions(__mysql_sandbox_port4, __mysql_sandbox_port3);
 CHECK_READ_REPLICA(__sandbox_uri4, cluster, [__endpoint3, __endpoint1], [__endpoint3]);
