@@ -272,31 +272,6 @@ var member_address3 = hostname + ":" + __mysql_sandbox_port3;
 cluster.rescan({addInstances: [member_address2, member_address3]});
 
 //@<> WL10644 - TSF2_1: Validate that the instances were added.
-validate_status(cluster.status(), [[__mysql_sandbox_port1, "OK"],
-                                [__mysql_sandbox_port2, "OK"],
-                                [__mysql_sandbox_port3, "OK"]]);
-
-//@<> Rescan must change the recovery username if it doesn't have the correct format
-session.runSql("CREATE USER IF NOT EXISTS mysql_innodb_cluster_11foo22@'%' IDENTIFIED BY 'password'");
-session.runSql("GRANT ALL ON *.* TO mysql_innodb_cluster_11foo22@'%'");
-session.runSql("FLUSH PRIVILEGES");
-
-session2 = mysql.getSession(__sandbox_uri2);
-session2.runSql(`CHANGE MASTER TO MASTER_USER='mysql_innodb_cluster_11foo22', MASTER_PASSWORD='password' FOR CHANNEL 'group_replication_recovery'`);
-session2.close();
-
-var recovery_account = session.runSql("SELECT (attributes->>'$.recoveryAccountUser') FROM mysql_innodb_cluster_metadata.instances WHERE address = ?", [`${hostname}:${__mysql_sandbox_port2}`]).fetchOne()[0];
-session.runSql("DROP USER ?", [recovery_account]);
-
-WIPE_SHELL_LOG();
-
-EXPECT_NO_THROWS(function(){ cluster.rescan(); });
-
-EXPECT_OUTPUT_CONTAINS(`Fixing incorrect recovery account 'mysql_innodb_cluster_11foo22' in instance '${hostname}:${__mysql_sandbox_port2}'`);
-EXPECT_OUTPUT_CONTAINS(`A new recovery user for instance '${hostname}:${__mysql_sandbox_port2}' was created, which leaves the previous user, 'mysql_innodb_cluster_11foo22', unused, so it should be removed.`);
-EXPECT_SHELL_LOG_CONTAINS(`Recovery account '${recovery_account}' does not exist in the cluster.`);
-EXPECT_SHELL_LOG_NOT_CONTAINS(`Updating recovery account '${recovery_account}' in metadata.`);
-
 validate_status(cluster.status(), [[__mysql_sandbox_port1, "OK"],
                                    [__mysql_sandbox_port2, "OK"],
                                    [__mysql_sandbox_port3, "OK"]]);
@@ -917,9 +892,6 @@ EXPECT_EQ(hostname_ip+":"+__mysql_sandbox_port3, row.address);
 EXPECT_EQ(hostname_ip+":"+__mysql_sandbox_port3, row.instance_name);
 EXPECT_EQ( {"mysqlX": hostname_ip+":"+__mysql_sandbox_port3+"0", "grLocal": hostname_ip+":"+__mysql_sandbox_gr_port3, "mysqlClassic": hostname_ip+":"+__mysql_sandbox_port3}, JSON.parse(row.addresses));
 
-//@<> setPrimary is expected to throw b/c metadata doesn't match {VER(>=8.0.27)}
-EXPECT_THROWS(function(){c.setPrimaryInstance(__sandbox_uri3);}, `The instance 'localhost:${__mysql_sandbox_port3}' does not belong to the cluster: 'cluster'.`);
-
 //@<> rescan to repair metadata according to new report_host {VER(>=8.0.27)}
 
 // sb3 address should be fixed now
@@ -1041,7 +1013,6 @@ EXPECT_NO_THROWS(function() { c.rescan(); });
 EXPECT_OUTPUT_CONTAINS_MULTILINE(`
 Result of the rescanning operation for the 'cluster' cluster:
 {
-    "metadataConsistent": true,
     "name": "cluster",
     "newTopologyMode": null,
     "newlyDiscoveredInstances": [],
@@ -1090,7 +1061,6 @@ EXPECT_NO_THROWS(function() { c.rescan(); });
 EXPECT_OUTPUT_CONTAINS_MULTILINE(`
 Result of the rescanning operation for the 'cluster' cluster:
 {
-    "metadataConsistent": true,
     "name": "cluster",
     "newTopologyMode": null,
     "newlyDiscoveredInstances": [],
@@ -1129,7 +1099,6 @@ Rescanning the cluster...
 
 Result of the rescanning operation for the 'cluster' cluster:
 {
-    "metadataConsistent": true,
     "name": "cluster",
     "newTopologyMode": null,
     "newlyDiscoveredInstances": [],
@@ -1156,7 +1125,6 @@ EXPECT_NO_THROWS(function() { c.rescan(); });
 EXPECT_OUTPUT_CONTAINS_MULTILINE(`
 Result of the rescanning operation for the 'cluster' cluster:
 {
-    "metadataConsistent": true,
     "name": "cluster",
     "newTopologyMode": null,
     "newlyDiscoveredInstances": [],
@@ -1195,7 +1163,6 @@ Rescanning the cluster...
 
 Result of the rescanning operation for the 'cluster' cluster:
 {
-    "metadataConsistent": true,
     "name": "cluster",
     "newTopologyMode": null,
     "newlyDiscoveredInstances": [],
