@@ -27,6 +27,9 @@ FUNCTIONS
       checkInstanceState(instance)
             Verifies the instance gtid state in relation to the cluster.
 
+            ATTENTION: This function is deprecated and will be removed in a
+                       future release of MySQL Shell.
+
       createClusterSet(domainName[, options])
             Creates a MySQL InnoDB ClusterSet from an existing standalone
             InnoDB Cluster.
@@ -149,7 +152,9 @@ DESCRIPTION
       - recoveryMethod: Preferred method of state recovery. May be auto, clone
         or incremental. Default is auto.
       - waitRecovery: Integer value to indicate if the command shall wait for
-        the recovery process to finish and its verbosity level.
+        the recovery process to finish and its verbosity level. Deprecated.
+      - recoveryProgress: Integer value to indicate the recovery process
+        verbosity level.
       - password: the instance connection password
       - memberSslMode: SSL mode used on the instance
       - ipWhitelist: The list of hosts allowed to connect to the instance for
@@ -164,7 +169,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - exitStateAction: string value indicating the group replication exit
         state action.
       - memberWeight: integer value with a percentage weight for automatic
@@ -203,6 +208,12 @@ DESCRIPTION
       - 3: block until the recovery process finishes and show progress using
         progress bars.
 
+      The recoveryProgress option supports the following values:
+
+      - 0: do not show any progress information.
+      - 1: show detailed static progress information.
+      - 2: show detailed dynamic progress information using progress bars.
+
       By default, if the standard output on which the Shell is running refers
       to a terminal, the waitRecovery option has the value of 3. Otherwise, it
       has the value of 2.
@@ -284,6 +295,11 @@ DESCRIPTION
 
       ATTENTION: The groupSeeds option will be removed in a future release.
 
+      ATTENTION: The waitRecovery option will be removed in a future release.
+                 Please use the recoveryProgress option instead.
+
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Check Instance State
 NAME
       checkInstanceState - Verifies the instance gtid state in relation to the
@@ -299,6 +315,9 @@ RETURNS
       resultset A JSON object with the status.
 
 DESCRIPTION
+      ATTENTION: This function is deprecated and will be removed in a future
+                 release of MySQL Shell.
+
       Analyzes the instance executed GTIDs with the executed/purged GTIDs on
       the cluster to determine if the instance is valid for the cluster.
 
@@ -402,7 +421,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
 
       The force option (set to true) must only be used to dissolve a cluster
       with instances that are permanently not available (no longer reachable)
@@ -412,6 +431,8 @@ DESCRIPTION
       and the cluster dissolved without the force option to avoid errors trying
       to reuse the instances and add them back to a cluster.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Force Quorum Using Partition Of
 NAME
       forceQuorumUsingPartitionOf - Restores the cluster from quorum loss.
@@ -481,6 +502,19 @@ DESCRIPTION
       This function lists and provides information about all Router instances
       registered for the Cluster.
 
+      For each router, the following information is provided, when available:
+
+      - hostname: Hostname.
+      - lastCheckIn: Timestamp of the last statistics update (check-in).
+      - roPort: Read-only port (Classic protocol).
+      - roXPort: Read-only port (X protocol).
+      - rwPort: Read-write port (Classic protocol).
+      - rwSplitPort: Read-write split port (Classic protocol).
+      - rwXPort: Read-write port (X protocol).
+      - upgradeRequired: If true, it indicates Router is incompatible with the
+        Cluster's metadata version and must be upgraded.
+      - version: Version.
+
       Whenever a Metadata Schema upgrade is necessary, the recommended process
       is to upgrade MySQL Router instances to the latest version before
       upgrading the Metadata itself, in order to minimize service disruption.
@@ -567,7 +601,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - ipWhitelist: The list of hosts allowed to connect to the instance for
         group replication. Deprecated.
       - ipAllowlist: The list of hosts allowed to connect to the instance for
@@ -577,11 +611,11 @@ DESCRIPTION
       - dryRun: boolean if true, all validations and steps for rejoining the
         instance are executed, but no changes are actually made.
       - cloneDonor: The Cluster member to be used as donor when performing
-        clone-based recovery.
+        clone-based recovery. Available only for Read Replicas.
       - timeout: maximum number of seconds to wait for the instance to sync up
         with the PRIMARY after it's provisioned and the replication channel is
         established. If reached, the operation is rolled-back. Default is 0 (no
-        timeout).
+        timeout). Available only for Read Replicas.
 
       The password may be contained on the instance definition, however, it can
       be overwritten if it is specified on the options.
@@ -591,10 +625,10 @@ DESCRIPTION
       - incremental: uses distributed state recovery, which applies missing
         transactions copied from another cluster member. Clone will be
         disabled.
-      - clone: clone: uses built-in MySQL clone support, which completely
-        replaces the state of the target instance with a full snapshot of
-        another cluster member before distributed recovery starts. Requires
-        MySQL 8.0.17 or newer.
+      - clone: uses built-in MySQL clone support, which completely replaces the
+        state of the target instance with a full snapshot of another cluster
+        member before distributed recovery starts. Requires MySQL 8.0.17 or
+        newer.
       - auto: let Group Replication choose whether or not a full snapshot has
         to be taken, based on what the target server supports and the
         group_replication_clone_threshold sysvar. This is the default value. A
@@ -643,6 +677,8 @@ DESCRIPTION
       ATTENTION: The ipWhitelist option will be removed in a future release.
                  Please use the ipAllowlist option instead.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Remove Instance
 NAME
       removeInstance - Removes an Instance from the cluster.
@@ -673,7 +709,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - dryRun: boolean if true, all validations and steps for removing the
         instance are executed, but no changes are actually made. An exception
         will be thrown when finished.
@@ -691,6 +727,8 @@ DESCRIPTION
       back ONLINE and removed without the force option to avoid errors trying
       to add it back to a cluster.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> SetInstanceOption
 NAME
       setInstanceOption - Changes the value of an option in a Cluster member.
@@ -725,7 +763,7 @@ DESCRIPTION
         instance will attempt to rejoin the cluster after being expelled.
       - ipAllowlist: The list of hosts allowed to connect to the instance for
         group replication. Only valid if communicationStack=XCOM.
-      - label a string identifier of the instance.
+      - label: a string identifier of the instance.
       - replicationSources: The list of sources for a Read Replica Instance.
 
       The exitStateAction option supports the following values:
@@ -856,6 +894,27 @@ DESCRIPTION
         with the new value.
       - transactionSizeLimit: integer value to configure the maximum
         transaction size in bytes which the Cluster accepts
+      - clusterSetReplicationConnectRetry: integer that specifies the interval
+        in seconds between the reconnection attempts that the replica makes
+        after the connection to the source times out.
+      - clusterSetReplicationRetryCount: integer that sets the maximum number
+        of reconnection attempts that the replica makes after the connection to
+        the source times out.
+      - clusterSetReplicationHeartbeatPeriod: decimal that controls the
+        heartbeat interval, which stops the connection timeout occurring in the
+        absence of data if the connection is still good.
+      - clusterSetReplicationCompressionAlgorithms: string that specifies the
+        permitted compression algorithms for connections to the replication
+        source.
+      - clusterSetReplicationZstdCompressionLevel: integer that specifies the
+        compression level to use for connections to the replication source
+        server that use the zstd compression algorithm.
+      - clusterSetReplicationBind: string that determines which of the
+        replica's network interfaces is chosen for connecting to the source.
+      - clusterSetReplicationNetworkNamespace: string that specifies the
+        network namespace to use for TCP/IP connections to the replication
+        source server or, if the MySQL communication stack is in use, for Group
+        Replication’s group communication connections.
 
       ATTENTION: The failoverConsistency option will be removed in a future
                  release. Please use the consistency option instead.
@@ -863,6 +922,15 @@ DESCRIPTION
       ATTENTION: The transactionSizeLimit option is not supported on Replica
                  Clusters of InnoDB ClusterSets.
 
+      NOTE: Changing any of the "clusterSetReplication*" options won't
+            immediately update the replication channel.
+            ClusterSet.rejoinCluster() must be used to to reconfigure and
+            restart the replication channel of that Cluster.
+
+      NOTE: Any of the "clusterSetReplication*" options accepts 'null', which
+            resets the corresponding option to its default value on the next
+            call to ClusterSet.rejoinCluster().
+
       The value for the configuration option is used to set the Group
       Replication system variable that corresponds to it.
 
@@ -1035,7 +1103,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - update: boolean value that must be enabled to allow updating the
         privileges and/or password of existing accounts. Default value is
         False.
@@ -1057,6 +1125,8 @@ DESCRIPTION
       options or vice-versa but certificate options can only be changed
       together.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> setupRouterAccount
 NAME
       setupRouterAccount - Create or upgrade a MySQL account to use with MySQL
@@ -1098,7 +1168,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - update: boolean value that must be enabled to allow updating the
         privileges and/or password of existing accounts. Default value is
         False.
@@ -1120,6 +1190,8 @@ DESCRIPTION
       options or vice-versa but certificate options can only be changed
       together.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Rescan
 NAME
       rescan - Rescans the cluster.
@@ -1146,7 +1218,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - removeInstances: List with the connection data of the obsolete
         instances to remove from the metadata, or "auto" to automatically
         remove obsolete instances from the metadata.
@@ -1169,6 +1241,8 @@ DESCRIPTION
       ATTENTION: The updateTopologyMode option will be removed in a future
                  release.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Status
 NAME
       status - Describe the status of the cluster.
@@ -1311,7 +1385,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
 
       The use of the force option (set to true) is not recommended. Use it only
       if really needed when instances are permanently not available (no longer
@@ -1319,6 +1393,8 @@ DESCRIPTION
       bring the non available instances back ONLINE or remove them from the
       cluster if they will no longer be used.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> createClusterSet
 NAME
       createClusterSet - Creates a MySQL InnoDB ClusterSet from an existing
@@ -1629,6 +1705,9 @@ DESCRIPTION
         instance. Default is 'secondaries'.
       - stats_updates_frequency: Number of seconds between updates that the
         Router is to make to its statistics in the InnoDB Cluster metadata.
+      - unreachable_quorum_allowed_traffic: Routing policy to define Router's
+        behavior regarding traffic destinations (ports) when it loses access to
+        the Cluster's quorum.
 
       The read_only_targets option supports the following values:
 
@@ -1654,3 +1733,31 @@ DESCRIPTION
 
       If the value is null, the option value is cleared and the default value
       (0) takes effect.
+
+      The unreachable_quorum_allowed_traffic option allows configuring Router's
+      behavior in the event of a loss of quorum on the only reachable Cluster
+      partition. By default, Router will disconnect all existing connections
+      and refuse new ones, but that can be configured using the following
+      options:
+
+      - read: Router will keep using ONLINE members as Read-Only destination,
+        leaving the RO and RW-split ports open.
+      - all: Router will keep ONLINE members as Read/Write destinations,
+        leaving all ports (RW, RO, and RW-split), open.
+      - none: All current connections are disconnected and new ones are refused
+        (default behavior).
+
+      ATTENTION: Setting this option to a different value other than the
+                 default may have unwanted consequences: the consistency
+                 guarantees provided by InnoDB Cluster are broken since the
+                 data read can be stale; different Routers may be accessing
+                 different partitions, thus return different data; and
+                 different Routers may also have different behavior (i.e. some
+                 provide only read traffic while others read and write
+                 traffic). Note that writes on a partition with no quorum will
+                 block until quorum is restored.
+
+      This option has no practical effect if
+      group_replication_unreachable_majority_timeout is set to a positive value
+      and group_replication_exit_state_action is either OFFLINE_MODE or
+      ABORT_SERVER.
