@@ -160,6 +160,12 @@ Creating user repl_admin@%.
 Account repl_admin@% was successfully created.
 
 Configuring instance...
+?{}
+?{VER(>=8.2.0) && !__replaying}
+
+WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
+?{}
+?{VER(>=8.0.27)}
 The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB cluster.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 ?{}
