@@ -59,6 +59,10 @@ FUNCTIONS
             Validates and configures a local instance for MySQL InnoDB Cluster
             usage.
 
+            ATTENTION: This function is deprecated and will be removed in a
+                       future release of MySQL Shell, use
+                       dba.configureInstance() instead.
+
       configureReplicaSetInstance([instance][, options])
             Validates and configures an instance for use in an InnoDB
             ReplicaSet.
@@ -167,7 +171,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
 
       The connection password may be contained on the instance definition,
       however, it can be overwritten if it is specified on the options.
@@ -190,6 +194,8 @@ DESCRIPTION
       - Update the server variable.
       - Restart the server.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Configure Instance
 NAME
       configureInstance - Validates and configures an instance for MySQL InnoDB
@@ -230,13 +236,13 @@ DESCRIPTION
       - clusterAdminCertSubject: Optional SSL certificate subject for the
         account.
       - clearReadOnly: boolean value used to confirm that super_read_only must
-        be disabled.
+        be disabled. Deprecated and default value is true.
       - restart: boolean value used to indicate that a remote restart of the
         target instance should be performed to finalize the operation.
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - applierWorkerThreads: Number of threads used for applying replicated
         transactions. The default value is 4.
 
@@ -265,6 +271,12 @@ DESCRIPTION
         variable.
       - Required Value: the required value for the configuration variable.
 
+      ATTENTION: The clearReadOnly option will be removed in a future release
+                 and it's no longer needed, super_read_only is automatically
+                 cleared.
+
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Configure Local Instance
 NAME
       configureLocalInstance - Validates and configures a local instance for
@@ -281,6 +293,9 @@ RETURNS
       Nothing
 
 DESCRIPTION
+      ATTENTION: This function is deprecated and will be removed in a future
+                 release of MySQL Shell, use dba.configureInstance() instead.
+
       This function reviews the instance configuration to identify if it is
       valid for usage in an InnoDB cluster, making configuration changes if
       necessary.
@@ -306,13 +321,13 @@ DESCRIPTION
       - clusterAdminCertSubject: Optional SSL certificate subject for the
         account.
       - clearReadOnly: boolean value used to confirm that super_read_only must
-        be disabled.
+        be disabled. Deprecated and default value is true.
       - restart: boolean value used to indicate that a remote restart of the
         target instance should be performed to finalize the operation.
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
 
       If the outputMycnfPath option is used, only that file is updated and
       mycnfPath is treated as read-only.
@@ -339,6 +354,12 @@ DESCRIPTION
         variable.
       - Required Value: the required value for the configuration variable.
 
+      ATTENTION: The clearReadOnly option will be removed in a future release
+                 and it's no longer needed, super_read_only is automatically
+                 cleared.
+
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Configure ReplicaSet Instance
 NAME
       configureReplicaSetInstance - Validates and configures an instance for
@@ -389,7 +410,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - restart: boolean value used to indicate that a remote restart of the
         target instance should be performed to finalize the operation.
       - applierWorkerThreads: Number of threads used for applying replicated
@@ -410,6 +431,8 @@ DESCRIPTION
         variable.
       - Required Value: the required value for the configuration variable.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Create Cluster
 NAME
       createCluster - Creates a MySQL InnoDB cluster.
@@ -443,7 +466,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - adoptFromGR: boolean value used to create the InnoDB cluster based on
         existing replication group.
       - memberSslMode: SSL mode for communication channels opened by Group
@@ -490,8 +513,8 @@ DESCRIPTION
         be disabled. Deprecated.
       - multiMaster: boolean value used to define an InnoDB cluster with
         multiple writable instances. Deprecated.
-      - communicationStack: The Group Replication protocol stack to be used in
-        the Cluster: XCom (legacy) or MySQL.
+      - communicationStack: The Group Replication communication stack to be
+        used in the Cluster: XCom (legacy) or MySQL.
       - transactionSizeLimit: integer value to configure the maximum
         transaction size in bytes which the Cluster accepts
       - paxosSingleLeader: boolean value used to enable/disable the Group
@@ -765,6 +788,8 @@ DESCRIPTION
 
       ATTENTION: The groupSeeds option will be removed in a future release.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Create ReplicaSet
 NAME
       createReplicaSet - Creates a MySQL InnoDB ReplicaSet.
@@ -861,7 +886,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - memberAuthType: controls the authentication type to use for the
         internal replication accounts.
       - certIssuer: common certificate issuer to use when 'memberAuthType'
@@ -904,6 +929,8 @@ DESCRIPTION
       although VERIFY_CA or VERIFY_IDENTITY are recommended for additional
       security.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Delete Sandbox
 NAME
       deleteSandboxInstance - Deletes an existing MySQL Server instance on
@@ -998,7 +1025,11 @@ DESCRIPTION
 
       - force: boolean, confirms that the drop operation must be executed.
       - clearReadOnly: boolean value used to confirm that super_read_only must
-        be disabled
+        be disabled. Deprecated and default value is true.
+
+      ATTENTION: The clearReadOnly option will be removed in a future release
+                 and it's no longer needed, super_read_only is automatically
+                 cleared.
 
 //@<OUT> Get Cluster
 NAME
@@ -1137,13 +1168,13 @@ DESCRIPTION
         will be thrown when finished.
       - primary: Instance definition representing the instance that must be
         selected as the primary.
-      - switchCommunicationStack: The Group Replication protocol stack to be
-        used by the Cluster after the reboot.
-      - ipAllowList: The list of hosts allowed to connect to the instance for
-        Group Replication traffic when using the 'XCOM' protocol stack.
+      - switchCommunicationStack: The Group Replication communication stack to
+        be used by the Cluster after the reboot.
+      - ipAllowlist: The list of hosts allowed to connect to the instance for
+        Group Replication traffic when using the 'XCOM' communication stack.
       - localAddress: string value with the Group Replication local address to
         be used instead of the automatically generated one when using the
-        'XCOM' protocol stack.
+        'XCOM' communication stack.
       - timeout: integer value with the maximum number of seconds to wait for
         pending transactions to be applied in each instance of the cluster
         (default value is retrieved from the 'dba.gtidWaitTimeout' shell
@@ -1306,7 +1337,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
 
       If dryRun is used, the function will determine whether a metadata upgrade
       or restore is required and inform the user without actually executing the
@@ -1338,3 +1369,4 @@ DESCRIPTION
       this function ended unexpectedly, this function will restore the metadata
       to the state it was before the failed upgrade operation.
 
+      ATTENTION: The interactive option will be removed in a future release.
