@@ -143,6 +143,9 @@ group_replication_start_on_boot = ON
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
 
+WARNING: The interactive option is deprecated and will be removed in a future release.
+
+WARNING: This function is deprecated and will be removed in a future release of MySQL Shell, use dba.configureInstance() instead.
 The instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' belongs to an InnoDB cluster.
 Calling this function on a cluster member is only required for MySQL versions 8.0.4 or earlier.
 
@@ -164,6 +167,9 @@ This instance reports its own address as <<<hostname>>>:<<<__mysql_sandbox_port1
 Instance configuration is suitable.
 NOTE: Group Replication will communicate with other members using '<<<hostname>>>:<<<__mysql_sandbox_gr_port1>>>'. Use the localAddress option to override.
 
+NOTE: The 'localAddress' "<<<hostname>>>" is [[*]], which is compatible with the Group Replication automatically generated list of IPs.
+See https://dev.mysql.com/doc/refman/en/group-replication-ip-address-permissions.html for more details.
+NOTE: When adding more instances to the Cluster, be aware that the subnet masks dictate whether the instance's address is automatically added to the allowlist or not. Please specify the 'ipAllowlist' accordingly if needed.
 * Checking connectivity and SSL configuration...
 
 WARNING: Instance '<<<hostname>>>:<<<__mysql_sandbox_port1>>>' cannot persist Group Replication configuration since MySQL version <<<__version>>> does not support the SET PERSIST command (MySQL version >= 8.0.11 required). Please use the dba.configureLocalInstance() command locally to persist the changes.
@@ -554,6 +560,11 @@ group_replication_transaction_size_limit = 150000000
 ?{VER(>=8.0.25)}
 group_replication_view_change_uuid = <<<__gr_view_change_uuid>>>
 ?{}
+WARNING: The interactive option is deprecated and will be removed in a future release.
+
+WARNING: The clearReadOnly option is deprecated and will be removed in a future release.
+
+WARNING: This function is deprecated and will be removed in a future release of MySQL Shell, use dba.configureInstance() instead.
 The instance '<<<hostname>>>:<<<__mysql_sandbox_port2>>>' belongs to an InnoDB cluster.
 Calling this function on a cluster member is only required for MySQL versions 8.0.4 or earlier.
 
