@@ -143,17 +143,38 @@ DESCRIPTION
         or incremental. Default is auto.
       - waitRecovery: Integer value to indicate the recovery process verbosity
         level.
+      - recoveryProgress: Integer value to indicate the recovery process
+        verbosity level.
       - cloneDonor: host:port of an existing replicaSet member to clone from.
         IPv6 addresses are not supported for this option.
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - timeout: timeout in seconds for transaction sync operations; 0 disables
         timeout and force the Shell to wait until the transaction sync
         finishes. Defaults to 0.
       - certSubject: instance's certificate subject to use when
         'memberAuthType' contains "CERT_SUBJECT".
+      - replicationConnectRetry: integer that specifies the interval in seconds
+        between the reconnection attempts that the replica makes after the
+        connection to the source times out.
+      - replicationRetryCount: integer that sets the maximum number of
+        reconnection attempts that the replica makes after the connection to
+        the source times out.
+      - replicationHeartbeatPeriod: decimal that controls the heartbeat
+        interval, which stops the connection timeout occurring in the absence
+        of data if the connection is still good.
+      - replicationCompressionAlgorithms: string that specifies the permitted
+        compression algorithms for connections to the replication source.
+      - replicationZstdCompressionLevel: integer that specifies the compression
+        level to use for connections to the replication source server that use
+        the zstd compression algorithm.
+      - replicationBind: string that determines which of the replica's network
+        interfaces is chosen for connecting to the source.
+      - replicationNetworkNamespace: string that specifies the network
+        namespace to use for TCP/IP connections to the replication source
+        server.
 
       The recoveryMethod option supports the following values:
 
@@ -177,6 +198,12 @@ DESCRIPTION
       - 2: show detailed static progress information.
       - 3: show detailed dynamic progress information using progress bars.
 
+      The recoveryProgress option supports the following values:
+
+      - 0: do not show any progress information.
+      - 1: show detailed static progress information.
+      - 2: show detailed dynamic progress information using progress bars.
+
       By default, if the standard output on which the Shell is running refers
       to a terminal, the waitRecovery option has the value of 3. Otherwise, it
       has the value of 2.
@@ -187,6 +214,11 @@ DESCRIPTION
       members are available the PRIMARY will be selected. The option accepts
       values in the format: 'host:port'. IPv6 addresses are not supported.
 
+      ATTENTION: The waitRecovery option will be removed in a future release.
+                 Please use the recoveryProgress option instead.
+
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Disconnect
 NAME
       disconnect - Disconnects all internal sessions used by the replicaset
@@ -303,6 +335,9 @@ DESCRIPTION
       it a read-only SECONDARY replica of the current PRIMARY. Only instances
       previously added to the replicaset can be rejoined, otherwise the
       <ReplicaSet>.addInstance() function must be used to add a new instance.
+      This can also be used to update the replication channel of instances
+      (even if they are already ONLINE) if it does not have the expected state,
+      source and settings.
 
       The PRIMARY of the replicaset must be reachable and available during this
       operation.
@@ -335,12 +370,14 @@ DESCRIPTION
         or incremental. Default is auto.
       - waitRecovery: Integer value to indicate the recovery process verbosity
         level.
+      - recoveryProgress: Integer value to indicate the recovery process
+        verbosity level.
       - cloneDonor: host:port of an existing replicaSet member to clone from.
         IPv6 addresses are not supported for this option.
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - timeout: timeout in seconds for transaction sync operations; 0 disables
         timeout and force the Shell to wait until the transaction sync
         finishes. Defaults to 0.
@@ -367,6 +404,12 @@ DESCRIPTION
       - 2: show detailed static progress information.
       - 3: show detailed dynamic progress information using progress bars.
 
+      The recoveryProgress option supports the following values:
+
+      - 0: do not show any progress information.
+      - 1: show detailed static progress information.
+      - 2: show detailed dynamic progress information using progress bars.
+
       By default, if the standard output on which the Shell is running refers
       to a terminal, the waitRecovery option has the value of 3. Otherwise, it
       has the value of 2.
@@ -377,6 +420,11 @@ DESCRIPTION
       members are available the PRIMARY will be selected. The option accepts
       values in the format: 'host:port'. IPv6 addresses are not supported.
 
+      ATTENTION: The waitRecovery option will be removed in a future release.
+                 Please use the recoveryProgress option instead.
+
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> Remove Instance
 NAME
       removeInstance - Removes an Instance from the replicaset.
@@ -502,7 +550,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - update: boolean value that must be enabled to allow updating the
         privileges and/or password of existing accounts. Default value is
         False.
@@ -524,6 +572,8 @@ DESCRIPTION
       options or vice-versa but certificate options can only be changed
       together.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> setupRouterAccount
 NAME
       setupRouterAccount - Create or upgrade a MySQL account to use with MySQL
@@ -565,7 +615,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - update: boolean value that must be enabled to allow updating the
         privileges and/or password of existing accounts. Default value is
         False.
@@ -587,6 +637,8 @@ DESCRIPTION
       options or vice-versa but certificate options can only be changed
       together.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> routingOptions
 NAME
       routingOptions - Lists the ReplicaSet Routers configuration options.
@@ -753,6 +805,33 @@ DESCRIPTION
 
       - tag:<option>: built-in and user-defined tags to be associated to the
         Cluster.
+      - replicationConnectRetry: integer that specifies the interval in seconds
+        between the reconnection attempts that the replica makes after the
+        connection to the source times out.
+      - replicationRetryCount: integer that sets the maximum number of
+        reconnection attempts that the replica makes after the connection to
+        the source times out.
+      - replicationHeartbeatPeriod: decimal that controls the heartbeat
+        interval, which stops the connection timeout occurring in the absence
+        of data if the connection is still good.
+      - replicationCompressionAlgorithms: string that specifies the permitted
+        compression algorithms for connections to the replication source.
+      - replicationZstdCompressionLevel: integer that specifies the compression
+        level to use for connections to the replication source server that use
+        the zstd compression algorithm.
+      - replicationBind: string that determines which of the replica's network
+        interfaces is chosen for connecting to the source.
+      - replicationNetworkNamespace: string that specifies the network
+        namespace to use for TCP/IP connections to the replication source
+        server.
+
+      NOTE: Changing any of the "replication*" options won't immediately update
+            the replication channel. Only on the next call to rejoinInstance()
+            will the updated options take effect.
+
+      NOTE: Any of the "replication*" options accepts 'null', which sets the
+            corresponding option to its default value on the next call to
+            rejoinInstance().
 
       Tags
 
@@ -790,6 +869,19 @@ DESCRIPTION
       This function lists and provides information about all Router instances
       registered for the ReplicaSet.
 
+      For each router, the following information is provided, when available:
+
+      - hostname: Hostname.
+      - lastCheckIn: Timestamp of the last statistics update (check-in).
+      - roPort: Read-only port (Classic protocol).
+      - roXPort: Read-only port (X protocol).
+      - rwPort: Read-write port (Classic protocol).
+      - rwSplitPort: Read-write split port (Classic protocol).
+      - rwXPort: Read-write port (X protocol).
+      - upgradeRequired: If true, it indicates Router is incompatible with the
+        Cluster's metadata version and must be upgraded.
+      - version: Version.
+
       Whenever a Metadata Schema upgrade is necessary, the recommended process
       is to upgrade MySQL Router instances to the latest version before
       upgrading the Metadata itself, in order to minimize service disruption.
