@@ -54,10 +54,15 @@ NOTE: Some configuration options need to be fixed:
 ?{}
 
 Some variables need to be changed, but cannot be done dynamically on the server.
+
 Creating user admin@%.
 Account admin@% was successfully created.
 
 Configuring instance...
+
+?{VER(>=8.2.0)}
+WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
+?{}
 The instance '<<<__address1>>>' was configured to be used in an InnoDB ReplicaSet.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 
@@ -74,6 +79,7 @@ applierWorkerThreads will be set to the default value of 4.
 ?{}
 
 The instance '<<<__address2>>>' is valid to be used in an InnoDB ReplicaSet.
+
 Creating user admin@%.
 Account admin@% was successfully created.
 
@@ -255,11 +261,11 @@ Incremental state recovery was selected because it seems to be safely usable.
 
 
 * Updating the Metadata...
-The instance '<<<__address3>>>' rejoined the replicaset and is replicating from 127.0.0.1:<<<__mysql_sandbox_port1>>>.
+The instance '<<<__address3>>>' rejoined the replicaset and is replicating from '127.0.0.1:<<<__mysql_sandbox_port1>>>'.
 
 //@# rejoinInstance (clone) {VER(>=8.0.17)}
 |NOTE: <<<__address3>>> is being cloned from <<<__address2>>>|
-|The instance '<<<__address3>>>' rejoined the replicaset and is replicating from 127.0.0.1:<<<__mysql_sandbox_port1>>>.|
+|The instance '<<<__address3>>>' rejoined the replicaset and is replicating from '127.0.0.1:<<<__mysql_sandbox_port1>>>'.|
 
 //@<OUT> listRouters
 {
@@ -271,6 +277,7 @@ The instance '<<<__address3>>>' rejoined the replicaset and is replicating from
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -281,6 +288,7 @@ The instance '<<<__address3>>>' rejoined the replicaset and is replicating from
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -298,6 +306,7 @@ The instance '<<<__address3>>>' rejoined the replicaset and is replicating from
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -372,7 +381,8 @@ true
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "replicationLag": null,
-                    "replicationSsl": null
+                    "replicationSsl": null,
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
             },
@@ -386,7 +396,8 @@ true
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "replicationLag": null,
-                    "replicationSsl": null
+                    "replicationSsl": null,
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
             }
