@@ -54,10 +54,15 @@ NOTE: Some configuration options need to be fixed:
 ?{}
 
 Some variables need to be changed, but cannot be done dynamically on the server.
+
 Creating user admin@%.
 Account admin@% was successfully created.
 
 Configuring instance...
+?{VER(>=8.2.0) && !__replaying}
+
+WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
+?{}
 The instance '127.0.0.1:<<<__mysql_sandbox_port1>>>' was configured to be used in an InnoDB ReplicaSet.
 
 //@<OUT> configureReplicaSetInstance
@@ -116,6 +121,10 @@ NOTE: Some configuration options need to be fixed:
 
 Some variables need to be changed, but cannot be done dynamically on the server.
 Configuring instance...
+?{VER(>=8.2.0) && !__replaying}
+
+WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
+?{}
 The instance '127.0.0.1:<<<__mysql_sandbox_port2>>>' was configured to be used in an InnoDB ReplicaSet.
 NOTE: MySQL server needs to be restarted for configuration changes to take effect.
 
@@ -290,11 +299,11 @@ Failover finished successfully.
 
 //@# rejoinInstance
 |* Rejoining instance to replicaset...|
-|The instance '127.0.0.1:<<<__mysql_sandbox_port3>>>' rejoined the replicaset and is replicating from 127.0.0.1:<<<__mysql_sandbox_port1>>>.|
+|The instance '127.0.0.1:<<<__mysql_sandbox_port3>>>' rejoined the replicaset and is replicating from '127.0.0.1:<<<__mysql_sandbox_port1>>>'.|
 
 //@# rejoinInstance (clone) {VER(>=8.0.17)}
 
-|The instance '<<<__address3>>>' rejoined the replicaset and is replicating from 127.0.0.1:<<<__mysql_sandbox_port1>>>.|
+|The instance '<<<__address3>>>' rejoined the replicaset and is replicating from '127.0.0.1:<<<__mysql_sandbox_port1>>>'.|
 
 //@<OUT> listRouters
 {
@@ -306,6 +315,7 @@ Failover finished successfully.
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -316,6 +326,7 @@ Failover finished successfully.
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -333,6 +344,7 @@ Failover finished successfully.
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
