@@ -32,7 +32,8 @@
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "replicationLag": null,
-                    "replicationSsl": "TLS_AES_256_GCM_SHA384 TLSv1.3"
+                    "replicationSsl": "TLS_[[*]]",
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
             }
@@ -78,7 +79,8 @@
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "receiverTimeSinceLastMessage": "[[*]]",
                     "replicationLag": null,
-                    "replicationSsl": "TLS_AES_256_GCM_SHA384 TLSv1.3",
+                    "replicationSsl": "TLS_[[*]]",
+                    "replicationSslMode": "REQUIRED",
                     "source": "<<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>"
                 },
                 "serverUuid": "5ef81566-9395-11e9-87e9-222222222222",
@@ -133,7 +135,8 @@
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "receiverTimeSinceLastMessage": "[[*]]",
                     "replicationLag": null,
-                    "replicationSsl": "TLS_AES_256_GCM_SHA384 TLSv1.3",
+                    "replicationSsl": "TLS_[[*]]",
+                    "replicationSslMode": "REQUIRED",
                     "source": "<<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>"
                 },
                 "serverUuid": "5ef81566-9395-11e9-87e9-222222222222",
@@ -172,7 +175,8 @@
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "replicationLag": null,
-                    "replicationSsl": "TLS_AES_256_GCM_SHA384 TLSv1.3"
+                    "replicationSsl": "TLS_[[*]]",
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
             }
@@ -225,7 +229,8 @@
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "receiverTimeSinceLastMessage": "[[*]]",
                     "replicationLag": null,
-                    "replicationSsl": "TLS_AES_256_GCM_SHA384 TLSv1.3",
+                    "replicationSsl": "TLS_[[*]]",
+                    "replicationSslMode": "REQUIRED",
                     "source": "<<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>"
                 },
                 "serverUuid": "5ef81566-9395-11e9-87e9-222222222222",
@@ -262,7 +267,8 @@
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "replicationLag": null,
-                    "replicationSsl": "TLS_AES_256_GCM_SHA384 TLSv1.3"
+                    "replicationSsl": "TLS_[[*]]",
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
             }
@@ -316,7 +322,8 @@
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "replicationLag": null,
-                    "replicationSsl": "TLS_AES_256_GCM_SHA384 TLSv1.3"
+                    "replicationSsl": "TLS_[[*]]",
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
             }
@@ -353,7 +360,8 @@
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "replicationLag": null,
-                    "replicationSsl": "TLS_AES_256_GCM_SHA384 TLSv1.3"
+                    "replicationSsl": "TLS_[[*]]",
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
             }
@@ -395,7 +403,8 @@
                     "receiverStatus": "OFF",
                     "receiverThreadState": "",
                     "replicationLag": null,
-                    "replicationSsl": "TLS_AES_256_GCM_SHA384 TLSv1.3",
+                    "replicationSsl": "TLS_[[*]]",
+                    "replicationSslMode": "REQUIRED",
                     "source": "<<<hostname_ip>>>:<<<__mysql_sandbox_port1>>>"
                 },
                 "status": "OFFLINE",
@@ -429,7 +438,8 @@
                     "receiverStatus": "ON",
                     "receiverThreadState": "[[*]]",
                     "replicationLag": null,
-                    "replicationSsl": null
+                    "replicationSsl": null,
+                    "replicationSslMode": "DISABLED"
                 },
                 "status": "ERROR"
             },
@@ -443,7 +453,8 @@
                     "receiverStatus": "ON",
                     "receiverThreadState": "Waiting for <<<__source_keyword>>> to send event",
                     "replicationLag": null,
-                    "replicationSsl": "TLS_AES_256_GCM_SHA384 TLSv1.3"
+                    "replicationSsl": "TLS_[[*]]",
+                    "replicationSslMode": "REQUIRED"
                 },
                 "status": "ONLINE"
             }
