@@ -12,12 +12,12 @@ testutil.deploySandbox(__mysql_sandbox_port6, "root", {report_host: hostname});
 
 cs = cluster.createClusterSet("domain");
 
-replicacluster = cs.createReplicaCluster(__sandbox_uri4, "replica");
-replicacluster.addInstance(__sandbox_uri5);
-replicacluster.addInstance(__sandbox_uri6);
+replica = cs.createReplicaCluster(__sandbox_uri4, "replica");
+replica.addInstance(__sandbox_uri5);
+replica.addInstance(__sandbox_uri6);
 
 CHECK_PRIMARY_CLUSTER([__sandbox_uri1, __sandbox_uri2, __sandbox_uri3], cluster);
-CHECK_REPLICA_CLUSTER([__sandbox_uri4, __sandbox_uri5, __sandbox_uri6], cluster, replicacluster);
+CHECK_REPLICA_CLUSTER([__sandbox_uri4, __sandbox_uri5, __sandbox_uri6], cluster, replica);
 CHECK_CLUSTER_SET(session);
 
 testutil.waitMemberTransactions(__mysql_sandbox_port4, __mysql_sandbox_port1);
@@ -49,14 +49,14 @@ testutil.waitMemberState(__mysql_sandbox_port2, "(MISSING)");
 
 EXPECT_NO_THROWS(function(){ old_primary = dba.rebootClusterFromCompleteOutage("cluster", {dryRun: true}); });
 EXPECT_OUTPUT_CONTAINS("NOTE: dryRun option was specified. Validations will be executed, but no changes will be applied.");
-EXPECT_OUTPUT_CONTAINS("Skipping rejoining remaining instances because the Cluster belongs to a ClusterSet and is INVALIDATED. Please add or remove the instances after the Cluster is rejoined to the ClusterSet.");
+EXPECT_OUTPUT_CONTAINS("Skipping rejoining remaining instances because the Cluster was INVALIDATED by a failover. Please add or remove the instances after the Cluster is rejoined to the ClusterSet.");
 EXPECT_OUTPUT_CONTAINS("dryRun finished.");
 EXPECT_OUTPUT_NOT_CONTAINS("The Cluster was successfully rebooted.");
 
 testutil.wipeAllOutput();
 
 EXPECT_NO_THROWS(function(){ old_primary = dba.rebootClusterFromCompleteOutage("cluster"); });
-EXPECT_OUTPUT_CONTAINS("Skipping rejoining remaining instances because the Cluster belongs to a ClusterSet and is INVALIDATED. Please add or remove the instances after the Cluster is rejoined to the ClusterSet.");
+EXPECT_OUTPUT_CONTAINS("Skipping rejoining remaining instances because the Cluster was INVALIDATED by a failover. Please add or remove the instances after the Cluster is rejoined to the ClusterSet.");
 EXPECT_OUTPUT_CONTAINS("The Cluster was successfully rebooted.");
 EXPECT_OUTPUT_NOT_CONTAINS("Rejoining Cluster into its original ClusterSet...");
 
@@ -110,7 +110,7 @@ testutil.waitMemberState(__mysql_sandbox_port6, "(MISSING)");
 
 EXPECT_THROWS(function() {
     old_primary = dba.rebootClusterFromCompleteOutage("replica", {force: true});
-}, "The 'force' option cannot be used in a Cluster that belongs to a ClusterSet and is INVALIDATED.");
+}, "The 'force' option cannot be used in a Cluster that belongs to a ClusterSet and is PRIMARY INVALIDATED.");
 
 // put the cluster back
 EXPECT_NO_THROWS(function(){ old_primary = dba.rebootClusterFromCompleteOutage("replica"); });
@@ -127,13 +127,9 @@ for (i = 0; i < 20; i++) {
     session.runSql("insert into test.data values (default, repeat('x', 4*1024*1024))");
 }
 
-shell.connect(__sandbox_uri4);
 EXPECT_NO_THROWS(function(){ old_primary.rejoinInstance(__sandbox_uri5); });
-testutil.waitMemberState(__mysql_sandbox_port5, "ONLINE");
 EXPECT_NO_THROWS(function(){ old_primary.rejoinInstance(__sandbox_uri6); });
-testutil.waitMemberState(__mysql_sandbox_port6, "ONLINE");
 
-shell.connect(__sandbox_uri1);
 cluster = dba.getCluster();
 
 CHECK_PRIMARY_CLUSTER([__sandbox_uri1, __sandbox_uri2, __sandbox_uri3], cluster);
@@ -178,7 +174,7 @@ shell.connect(__sandbox_uri1);
 
 EXPECT_THROWS(function(){
     cluster = dba.rebootClusterFromCompleteOutage("cluster", {force: true});
-}, "The 'force' option cannot be used in a Cluster that belongs to a ClusterSet and is INVALIDATED.");
+}, "The 'force' option cannot be used in a Cluster that belongs to a ClusterSet and is PRIMARY INVALIDATED.");
 
 EXPECT_NO_THROWS(function(){ cluster = dba.rebootClusterFromCompleteOutage("cluster"); });
 
@@ -191,11 +187,17 @@ cluster.rejoinInstance(__sandbox_uri3);
 shell.connect(__sandbox_uri4);
 EXPECT_NO_THROWS(function(){ replica = dba.rebootClusterFromCompleteOutage("replica"); });
 
-cs.rejoinCluster("replica");
+EXPECT_OUTPUT_CONTAINS("Skipping rejoining remaining instances because the Cluster belongs to a ClusterSet as a REPLICA Cluster but has been invalidated. Please add or remove the  instances after the Cluster is rejoined to the ClusterSet.");
+EXPECT_OUTPUT_NOT_CONTAINS("Rejoining Cluster into its original ClusterSet...");
+
+EXPECT_NO_THROWS(function(){ cs.rejoinCluster("replica"); });
 
 wait_channel_ready(session, __mysql_sandbox_port6, "clusterset_replication");
 
-replica.rejoinInstance(__sandbox_uri5);
+EXPECT_NO_THROWS(function(){ replica.rejoinInstance(__sandbox_uri5); });
+
+testutil.waitMemberTransactions(__mysql_sandbox_port4, __mysql_sandbox_port6);
+testutil.waitMemberTransactions(__mysql_sandbox_port5, __mysql_sandbox_port4);
 
 // Rejoin creates a VCLE, so let's reconcile the GTID-set already
 cs.rejoinCluster("replica");
@@ -212,10 +214,15 @@ CHECK_CLUSTER_SET(session);
 cs.setPrimaryCluster("cluster");
 cs.removeCluster("replica2");
 
+testutil.waitMemberTransactions(__mysql_sandbox_port4, __mysql_sandbox_port1);
+testutil.waitMemberState(__mysql_sandbox_port6, "OFFLINE");
+
 shell.connect(__sandbox_uri4);
 replica = dba.getCluster();
 replica.addInstance(__sandbox_uri6);
 
+testutil.waitMemberTransactions(__mysql_sandbox_port6, __mysql_sandbox_port4);
+
 shell.connect(__sandbox_uri1);
 cluster = dba.getCluster();
 
@@ -386,10 +393,6 @@ shell.connect(__sandbox_uri4);
 EXPECT_NO_THROWS(function(){ replica = dba.rebootClusterFromCompleteOutage(); });
 
 CHECK_PRIMARY_CLUSTER([__sandbox_uri1, __sandbox_uri2, __sandbox_uri3], cluster);
-
-testutil.waitMemberState(__mysql_sandbox_port5, "ONLINE");
-testutil.waitMemberState(__mysql_sandbox_port6, "ONLINE");
-
 CHECK_REPLICA_CLUSTER([__sandbox_uri4, __sandbox_uri5, __sandbox_uri6], cluster, replica);
 CHECK_CLUSTER_SET(session);
 
