@@ -146,7 +146,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - dryRun: boolean if true, all validations and steps for creating a
         Replica Cluster are executed, but no changes are actually made. An
         exception will be thrown when finished.
@@ -185,12 +185,33 @@ DESCRIPTION
         'mysql_innodb_cluster_###'@'hostname'). Default is %. It must be
         possible for any member of the Cluster to connect to any other member
         using accounts with this hostname value.
-      - communicationStack: The Group Replication protocol stack to be used in
-        the Cluster: XCom (legacy) or MySQL.
+      - communicationStack: The Group Replication communication stack to be
+        used in the Cluster: XCom (legacy) or MySQL.
       - transactionSizeLimit: integer value to configure the maximum
         transaction size in bytes which the Cluster accepts
       - paxosSingleLeader: boolean value used to enable/disable the Group
         Communication engine to operate with a single consensus leader.
+      - clusterSetReplicationConnectRetry: integer that specifies the interval
+        in seconds between the reconnection attempts that the replica makes
+        after the connection to the source times out.
+      - clusterSetReplicationRetryCount: integer that sets the maximum number
+        of reconnection attempts that the replica makes after the connection to
+        the source times out.
+      - clusterSetReplicationHeartbeatPeriod: decimal that controls the
+        heartbeat interval, which stops the connection timeout occurring in the
+        absence of data if the connection is still good.
+      - clusterSetReplicationCompressionAlgorithms: string that specifies the
+        permitted compression algorithms for connections to the replication
+        source.
+      - clusterSetReplicationZstdCompressionLevel: integer that specifies the
+        compression level to use for connections to the replication source
+        server that use the zstd compression algorithm.
+      - clusterSetReplicationBind: string that determines which of the
+        replica's network interfaces is chosen for connecting to the source.
+      - clusterSetReplicationNetworkNamespace: string that specifies the
+        network namespace to use for TCP/IP connections to the replication
+        source server or, if the MySQL communication stack is in use, for Group
+        Replication’s group communication connections.
 
       The recoveryMethod option supports the following values:
 
@@ -414,6 +435,8 @@ DESCRIPTION
       The option is available on MySQL 8.0.31 or newer and the default value is
       'OFF'.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> RemoveCluster
 NAME
       removeCluster - Removes a Replica cluster from a ClusterSet.
@@ -755,6 +778,18 @@ DESCRIPTION
       This function lists and provides information about all Router instances
       registered on the Clusters members of the ClusterSet.
 
+      For each router, the following information is provided, when available:
+
+      - hostname: Hostname.
+      - lastCheckIn: Timestamp of the last statistics update (check-in).
+      - roPort: Read-only port (Classic protocol).
+      - roXPort: Read-only port (X protocol).
+      - rwPort: Read-write port (Classic protocol).
+      - rwSplitPort: Read-write split port (Classic protocol).
+      - rwXPort: Read-write port (X protocol).
+      - targetCluster: Target Cluster for Router routing operations.
+      - version: Version.
+
 //@<OUT> routingOptions
 NAME
       routingOptions - Lists the ClusterSet Routers configuration options.
@@ -804,7 +839,7 @@ DESCRIPTION
         Clusters. Disabled by default.
       - tags: Associates an arbitrary JSON object with custom key/value pairs
         with the ClusterSet metadata.
-      - read_replicas_policy: Routing policy to define Router's usage of Read
+      - read_only_targets: Routing policy to define Router's usage of Read
         Replicas. Default is 'append'.
 
       The target_cluster option supports the following values:
@@ -933,7 +968,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - update: boolean value that must be enabled to allow updating the
         privileges and/or password of existing accounts. Default value is
         False.
@@ -955,6 +990,8 @@ DESCRIPTION
       options or vice-versa but certificate options can only be changed
       together.
 
+      ATTENTION: The interactive option will be removed in a future release.
+
 //@<OUT> setupRouterAccount
 NAME
       setupRouterAccount - Create or upgrade a MySQL account to use with MySQL
@@ -996,7 +1033,7 @@ DESCRIPTION
       - interactive: boolean value used to disable/enable the wizards in the
         command execution, i.e. prompts and confirmations will be provided or
         not according to the value set. The default value is equal to MySQL
-        Shell wizard mode.
+        Shell wizard mode. Deprecated.
       - update: boolean value that must be enabled to allow updating the
         privileges and/or password of existing accounts. Default value is
         False.
@@ -1017,3 +1054,5 @@ DESCRIPTION
       `true`. It is possible to change password without affecting certificate
       options or vice-versa but certificate options can only be changed
       together.
+
+      ATTENTION: The interactive option will be removed in a future release.
