@@ -269,7 +269,8 @@ OPTIONS
 
 --dryRun=<bool>
             Simulates a copy and prints everything that would be performed,
-            without actually doing so. Default: false.
+            without actually doing so. If target is MySQL HeatWave Service,
+            also checks for compatibility issues. Default: false.
 
 --consistent=<bool>
             Enable or disable consistent data copies. When enabled, produces a
@@ -282,7 +283,7 @@ OPTIONS
             Default: false.
 
 --compatibility=<str list>
-            Apply MySQL Database Service compatibility modifications when
+            Apply MySQL HeatWave Service compatibility modifications when
             copying the DDL. Supported values: "create_invisible_pks",
             "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
             "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
@@ -468,7 +469,8 @@ OPTIONS
 
 --dryRun=<bool>
             Simulates a copy and prints everything that would be performed,
-            without actually doing so. Default: false.
+            without actually doing so. If target is MySQL HeatWave Service,
+            also checks for compatibility issues. Default: false.
 
 --consistent=<bool>
             Enable or disable consistent data copies. When enabled, produces a
@@ -481,7 +483,7 @@ OPTIONS
             Default: false.
 
 --compatibility=<str list>
-            Apply MySQL Database Service compatibility modifications when
+            Apply MySQL HeatWave Service compatibility modifications when
             copying the DDL. Supported values: "create_invisible_pks",
             "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
             "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
@@ -649,7 +651,8 @@ OPTIONS
 
 --dryRun=<bool>
             Simulates a copy and prints everything that would be performed,
-            without actually doing so. Default: false.
+            without actually doing so. If target is MySQL HeatWave Service,
+            also checks for compatibility issues. Default: false.
 
 --consistent=<bool>
             Enable or disable consistent data copies. When enabled, produces a
@@ -662,7 +665,7 @@ OPTIONS
             Default: false.
 
 --compatibility=<str list>
-            Apply MySQL Database Service compatibility modifications when
+            Apply MySQL HeatWave Service compatibility modifications when
             copying the DDL. Supported values: "create_invisible_pks",
             "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
             "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
@@ -831,7 +834,8 @@ OPTIONS
 
 --dryRun=<bool>
             Print information about what would be dumped, but do not dump
-            anything. Default: false.
+            anything. If ocimds is enabled, also checks for compatibility
+            issues with MySQL HeatWave Service. Default: false.
 
 --consistent=<bool>
             Enable or disable consistent data dumps. When enabled, produces a
@@ -844,16 +848,20 @@ OPTIONS
             Default: false.
 
 --ocimds=<bool>
-            Enable checks for compatibility with MySQL Database Service (MDS)
+            Enable checks for compatibility with MySQL HeatWave Service.
             Default: false.
 
 --compatibility=<str list>
-            Apply MySQL Database Service compatibility modifications when
+            Apply MySQL HeatWave Service compatibility modifications when
             writing dump files. Supported values: "create_invisible_pks",
             "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
             "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
             "strip_restricted_grants", "strip_tablespaces". Default: empty.
 
+--targetVersion=<str>
+            Specifies version of the destination MySQL server. Default: current
+            version of Shell.
+
 --excludeTriggers=<str list>
             List of triggers to be excluded from the dump in the format of
             schema.table (all triggers from the specified table) or
@@ -891,14 +899,6 @@ OPTIONS
             Use the specified OCI profile instead of the default one. Default:
             not set.
 
---ociParManifest=<bool>
-            Enables the generation of the PAR manifest while the dump operation
-            is being executed. Default: not set.
-
---ociParExpireTime=<str>
-            Allows defining the expiration time for the PARs generated when
-            ociParManifest is enabled. Default: not set.
-
 --s3BucketName=<str>
             Name of the AWS S3 bucket to use. The bucket must already exist.
             Default: not set.
@@ -1072,7 +1072,8 @@ OPTIONS
 
 --dryRun=<bool>
             Print information about what would be dumped, but do not dump
-            anything. Default: false.
+            anything. If ocimds is enabled, also checks for compatibility
+            issues with MySQL HeatWave Service. Default: false.
 
 --consistent=<bool>
             Enable or disable consistent data dumps. When enabled, produces a
@@ -1085,16 +1086,20 @@ OPTIONS
             Default: false.
 
 --ocimds=<bool>
-            Enable checks for compatibility with MySQL Database Service (MDS)
+            Enable checks for compatibility with MySQL HeatWave Service.
             Default: false.
 
 --compatibility=<str list>
-            Apply MySQL Database Service compatibility modifications when
+            Apply MySQL HeatWave Service compatibility modifications when
             writing dump files. Supported values: "create_invisible_pks",
             "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
             "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
             "strip_restricted_grants", "strip_tablespaces". Default: empty.
 
+--targetVersion=<str>
+            Specifies version of the destination MySQL server. Default: current
+            version of Shell.
+
 --excludeTriggers=<str list>
             List of triggers to be excluded from the dump in the format of
             schema.table (all triggers from the specified table) or
@@ -1132,14 +1137,6 @@ OPTIONS
             Use the specified OCI profile instead of the default one. Default:
             not set.
 
---ociParManifest=<bool>
-            Enables the generation of the PAR manifest while the dump operation
-            is being executed. Default: not set.
-
---ociParExpireTime=<str>
-            Allows defining the expiration time for the PARs generated when
-            ociParManifest is enabled. Default: not set.
-
 --s3BucketName=<str>
             Name of the AWS S3 bucket to use. The bucket must already exist.
             Default: not set.
@@ -1294,7 +1291,8 @@ OPTIONS
 
 --dryRun=<bool>
             Print information about what would be dumped, but do not dump
-            anything. Default: false.
+            anything. If ocimds is enabled, also checks for compatibility
+            issues with MySQL HeatWave Service. Default: false.
 
 --consistent=<bool>
             Enable or disable consistent data dumps. When enabled, produces a
@@ -1307,16 +1305,20 @@ OPTIONS
             Default: false.
 
 --ocimds=<bool>
-            Enable checks for compatibility with MySQL Database Service (MDS)
+            Enable checks for compatibility with MySQL HeatWave Service.
             Default: false.
 
 --compatibility=<str list>
-            Apply MySQL Database Service compatibility modifications when
+            Apply MySQL HeatWave Service compatibility modifications when
             writing dump files. Supported values: "create_invisible_pks",
             "force_innodb", "ignore_missing_pks", "ignore_wildcard_grants",
             "skip_invalid_accounts", "strip_definers", "strip_invalid_grants",
             "strip_restricted_grants", "strip_tablespaces". Default: empty.
 
+--targetVersion=<str>
+            Specifies version of the destination MySQL server. Default: current
+            version of Shell.
+
 --excludeTriggers=<str list>
             List of triggers to be excluded from the dump in the format of
             schema.table (all triggers from the specified table) or
@@ -1354,14 +1356,6 @@ OPTIONS
             Use the specified OCI profile instead of the default one. Default:
             not set.
 
---ociParManifest=<bool>
-            Enables the generation of the PAR manifest while the dump operation
-            is being executed. Default: not set.
-
---ociParExpireTime=<str>
-            Allows defining the expiration time for the PARs generated when
-            ociParManifest is enabled. Default: not set.
-
 --s3BucketName=<str>
             Name of the AWS S3 bucket to use. The bucket must already exist.
             Default: not set.
