@@ -29,10 +29,22 @@ Usage: mysqlsh [OPTIONS] [URI]
                                    arguments of the processed file.
   --ssh=<value>                    Make SSH tunnel connection usingUniform
                                    Resource Identifier. Format:
-                                   [user@]host[:port]
+                                   [user[:pass]@]host[:port]
   --ssh-identity-file=<file>       File from which the private key for public
                                    key authentication is read.
   --ssh-config-file=<file>         Specify a custom path for SSH configuration.
+?{__os_type == 'windows'}
+  --plugin-authentication-kerberos-client-mode=<mode>
+                                   Allows defining the kerberos client mode
+                                   (SSPI, GSSAPI) when using kerberos
+                                   authentication.
+?{}
+  --oci-config-file=<file>         Allows defining the OCI configuration file
+                                   for OCI authentication.
+  --authentication-oci-client-config-profile=<name>
+                                   Allows defining the OCI profile used from
+                                   the configuration for client side OCI
+                                   authentication.
   --uri=<value>                    Connect to Uniform Resource Identifier.
                                    Format: [user[:pass]@]host[:port][/db]
   -h, --host=<name>                Connect to host.
