@@ -54,11 +54,12 @@ NOTE: Some configuration options need to be fixed:
 ?{}
 
 Some variables need to be changed, but cannot be done dynamically on the server.
+
 Creating user admin@%.
 Account admin@% was successfully created.
 
 Configuring instance...
-?{((VER(>=8.0.35) and VER(<8.1.0)) or VER(>=8.2.0)) and not __replaying}
+?{VER(>=8.2.0) and not __replaying}
 
 WARNING: '@@binlog_transaction_dependency_tracking' is deprecated and will be removed in a future release. (Code 1287).
 ?{}
@@ -78,6 +79,7 @@ applierWorkerThreads will be set to the default value of 4.
 
 ?{}
 The instance '127.0.0.1:<<<__mysql_sandbox_port2>>>' is valid to be used in an InnoDB ReplicaSet.
+
 Creating user admin@%.
 Account admin@% was successfully created.
 
@@ -348,6 +350,7 @@ Failover finished successfully.
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -358,6 +361,7 @@ Failover finished successfully.
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
@@ -375,6 +379,7 @@ Failover finished successfully.
             "roPort": null,
             "roXPort": null,
             "rwPort": null,
+            "rwSplitPort": null,
             "rwXPort": null,
             "upgradeRequired": true,
             "version": "8.0.18"
