@@ -1,4 +1,5 @@
 ## imports
+import json
 import pickle
 import random
 import sys
@@ -660,7 +661,7 @@ EXPECT_EQ('{"one": 1, "three": 3, "two": 2}', actual.__str__())
 
 #@<> __subclasshook__
 # __subclasshook__ comes from the object class
-EXPECT_EQ(NotImplemented, shdict.__subclasshook__(None))
+EXPECT_EQ(NotImplemented, shdict.__subclasshook__())
 
 #@<> clear
 SETUP("clear")
@@ -1345,7 +1346,7 @@ TEST_OP(set([('four', 4)]))
 #@<> items - __subclasshook__
 SETUP_VIEW("items", "__subclasshook__")
 # __subclasshook__ comes from the object class
-EXPECT_EQ(NotImplemented, actual.__class__.__subclasshook__(None))
+EXPECT_EQ(NotImplemented, actual.__class__.__subclasshook__())
 
 #@<> items - __xor__
 SETUP_VIEW("items", "__xor__")
@@ -2005,7 +2006,7 @@ TEST_OP(set(['four']))
 #@<> keys - __subclasshook__
 SETUP_VIEW("keys", "__subclasshook__")
 # __subclasshook__ comes from the object class
-EXPECT_EQ(NotImplemented, actual.__class__.__subclasshook__(None))
+EXPECT_EQ(NotImplemented, actual.__class__.__subclasshook__())
 
 #@<> keys - __xor__
 SETUP_VIEW("keys", "__xor__")
@@ -2481,7 +2482,7 @@ EXPECT_EQ("Dict_values([1, 3, 2])", actual.__str__())
 #@<> values - __subclasshook__
 SETUP_VIEW("values", "__subclasshook__")
 # __subclasshook__ comes from the object class
-EXPECT_EQ(NotImplemented, actual.__class__.__subclasshook__(None))
+EXPECT_EQ(NotImplemented, actual.__class__.__subclasshook__())
 
 #@<> values - mapping {sys.hexversion >= 0x030A0000}
 SETUP_VIEW("values", "mapping")
@@ -2502,3 +2503,6 @@ SETUP_VIEW("values", "mapping", {'one': 1, 'two': 2, 'three': 3})
 EXPECT_EQ('{"one": 1, "three": 3, "two": 2}', str(actual.mapping))
 
 EXPECT_THROWS(assign_none_to_mapping, "AttributeError: attribute 'mapping' of 'Dict_values' objects is not writable")
+
+#@<> json
+EXPECT_EQ('{"one": 1, "three": 3, "two": 2}', json.dumps(shdict({'three': 3, 'one': 1, 'two': 2})))
