@@ -351,7 +351,7 @@ function getAuthServerConfig(context) {
 
 
 function isAuthMethodSupported(context) {
-  if (['LDAP_SIMPLE', 'LDAP_SASL', 'LDAP_KERBEROS', 'KERBEROS', 'FIDO', 'OCI_AUTH'].indexOf(context) == -1) {
+  if (['LDAP_SIMPLE', 'LDAP_SASL', 'LDAP_KERBEROS', 'KERBEROS', 'FIDO', 'WEBAUTHN', 'OCI_AUTH'].indexOf(context) == -1) {
     return false;
   }
 
@@ -367,6 +367,8 @@ function isAuthMethodSupported(context) {
     plugin = 'authentication_kerberos';
   } else if (context == 'FIDO') {
     plugin = 'authentication_fido';
+  } else if (context == 'WEBAUTHN') {
+    plugin = 'authentication_webauthn';
   } else if (context == 'OCI_AUTH') {
     // we're using an external server, so this is always supported
     return true;
@@ -850,7 +852,7 @@ function begin_dba_log_sql(level) {
   var dummy = testutil.fetchDbaSqlLog(true);
 }
 
-function end_dba_log_sql(level) {
+function end_dba_log_sql() {
   var logs = testutil.fetchDbaSqlLog(false);
   shell.options["dba.logSql"] = 0;
   return logs;
@@ -1672,15 +1674,21 @@ function ClusterScenario(ports, create_cluster_options, sandboxConfiguration) {
 
   this.cluster = dba.createCluster("cluster", create_cluster_options);
 
-  var allowList = create_cluster_options["ipAllowlist"];
+  add_instance_options = {}
+  if ('ipAllowlist' in create_cluster_options) {
+    add_instance_options["ipAllowlist"] = create_cluster_options["ipAllowlist"];
+  }
+  if ('localAddress' in create_cluster_options) {
+    add_instance_options["localAddress"] = create_cluster_options["localAddress"];
+  }
 
   for (i in ports) {
     if (i > 0) {
       var uri = "mysql://root:root@localhost:" + ports[i];
-      if (allowList === undefined) {
+      if (Object.keys(add_instance_options).length === 0) {
         this.cluster.addInstance(uri);
       } else {
-        this.cluster.addInstance(uri, {ipAllowlist: allowList});
+        this.cluster.addInstance(uri, add_instance_options);
       }
       testutil.waitMemberState(ports[i], "ONLINE");
 
